#
# spec file for package terraform-provider-aws
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         terraform-providers
%global repo            terraform-provider-aws
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    aws

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-aws
Version:        3.51.0
Release:        2.10
Summary:        Terraform provider for Amazon Web Services (AWS)
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-aws
Source:         %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
# Terraform is not available for 32bit platforms
ExcludeArch:    %ix86 %arm
Requires:       terraform >= 0.12.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.14
%endif
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you provision servers on Amazon Web
Services via Terraform.

%prep
%setup -q -n %{repo}-%{version}
%setup -q -D -T -a 1 -n %{repo}-%{version}

%build
%{goprep} %{import_path}
%{gobuild} -mod=vendor ""

%install
%{goinstall}
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Wed Mar 30 2022 Dirk Müller <dmueller@suse.com>
- exclude build for 32bit targets
* Wed Jul 28 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.51.0
  FEATURES:
  * **New Data Source:** `aws_elasticache_user` (#16629)
  * **New Resource:** `aws_appconfig_deployment` (#20172)
  * **New Resource:** `aws_elasticache_user` (#16629)
  * **New Resource:** `aws_elasticache_user_group` (#16504)
  ENHANCEMENTS:
  * resource/aws_cloudwatch_event_target: Add support for Redshift event target. (#20256)
  * resource/aws_glue_crawler: Add `sample_size` argument in `s3_target` block. (#20203)
  * resource/aws_instance: Add support for configuration with Launch Template (#10807)
  * resource/aws_servicecatalog_provisioned_product: Increase timeouts to align with
    CloudFormation (30 min.) (#20254)
  * resource/aws_storagegateway_smb_file_share: Add `bucket_region`, `oplocks_enabled`
    and `vpc_endpoint_dns_name` arguments (#20234)
  BUG FIXES:
  * aws/resource_aws_lambda_event_source_mapping: Ignore `InvalidParameterValueException`
    error caused by IAM propagation when creating Lambda event source mapping with Kinesis
    stream source (#20229)
  * aws/resource_aws_route_table_association: Correctly handle `associated` as a pending
    state when waiting for deletion of an association (#20265)
- For changes from 3.24.1 through 3.50.0, see CHANGELOG.md shipped with the package
* Fri Jan 15 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 3.24.0:
  * Update CHANGELOG for #15322
  * Update CHANGELOG for #16959
  * Update CHANGELOG.md for #17112
  * Update Data Handling and Conversion guide: Fix typo and encourage error checking (#17116)
  * add prechecks for SimpleAD
  * Update CHANGELOG.md for #17012
  * tests/resource/fsx_lustre_file_system: Add partition to basic
  * tests/resource/fsx_lustre_file_system: Use composeConfig()
  * tests/resource/fsx_lustre_file_system: Adjust GovCloud compatibility
  * Adds timeouts to Global Accelerator resources
  * tests/resource/fsx_lustre_file_system: Make GovCloud compatible
  * implement account assignment sweeper
  * align account assignment resource w/service design
  * Allow additional resource types.
  * align identitystore data-sources with service design
  * Update CHANGELOG for #15023
  * additional acctests; reduce logging
  * Update CHANGELOG.md for #17043
  * Use id instead of resource id for route53_resolver_dnssec_config resource id
  * Update CHANGELOG.md for #16077
  * Update CHANGELOG.md for #16867
  * Update CHANGELOG.md for #16688
  * Update CHANGELOG.md
  * resource/instance: Fix linting
  * docs/instance: Clean up documentation
  * resource/instance: Pre-merge cleanup
  * fix autoscaling_group attribute 'instance_warmup'
  * Update CHANGELOG for #10092 #13497
  * service/apigateway: Extend retryable ConflictException handling to all operations
    and remove unreleased aws_api_gateway_method_settings mutexes
  * Update CHANGELOG for #15499
  * resource/aws_api_gateway_integration: Minor refactoring of new tls_config functionality and documentation
  * Update CHANGELOG for #16147
  * resource/aws_api_gateway_base_path_mapping: Support in-place updates
    for `stage_name`, `api_id` and `base_path` (#16147)
  * Update CHANGELOG for #16198
  * resource/aws_api_gateway_rest_api: Add `disable_execute_api_endpoint` argument (#16198)
  * Update CHANGELOG for #15258
  * resource/aws_api_gateway_domain_name: Support mutual TLS authentication  (#15258)
  * data-source/aws_api_gateway_domain_name: Add missing ignore tags configuration
  * tests/data-source/aws_api_gateway_domain_name: Remove unused function
  * Update CHANGELOG for #12489
  * data-source/aws_api_gateway_domain_name: Modernize to latest codebase
  * Update CHANGELOG for #13282
  * Update CHANGELOG for #13232
  * resource/aws_api_gateway_method: Minor refactoring and CI fixes
  * docs/resource/aws_api_gateway_gateway_response: Fix invalid JSON in response template (#12820)
  * Update CHANGELOG for #10092
  * resource/aws_api_gateway_usage_plan: Refactor out mutex in preference of client retries
  * Restores diff suppression for hashed GitHub tokens
  * Update CHANGELOG for #7374
  * resource/aws_api_gateway_rest_api: Refactor body_base_path to parameters argument
  * Add ARN support for aws_route53_resolver_dnssec_config
  * Replace %%s with %%w for the error messages
  * add new argument to resource documentation
  * Update CHANGELOG for #16827
  * docs/resource/aws_api_gateway_method_settings: Use aws_api_gateway_resource
    path attribute for deeply nested resources (#5427)
  * tests/resource/instance: Adjust naming
  * tests/resource/instance: Clean up composeConfig() use
  * resource/instance: Organize attributes
  * resource/instance: Fix linter issues
  * resource/aws_instance: Add more test cases for volume tags
  * resource/aws_instance: Add tags parameter to *_block_device block
  * test/resource/elasticache_cluster: Fix lint issue
  * Update aws/resource_aws_elasticache_parameter_group_test.go
  * Update aws/resource_aws_elasticache_parameter_group_test.go
  * Update aws/resource_aws_elasticache_parameter_group_test.go
  * Update CHANGELOG for #15592
  * Updates to aws_elasticache_replication_group.test
  * .github/workflows: Reduce goreleaser parallelism to match GitHub Actions hosted runners (#17067)
  * Update CHANGELOG for #17055
  * resource/aws_s3_bucket_inventory: Prevent crashes with empty destination,
    filter, and schedule configuration blocks (#17055)
  * isolate only new data/resources
  * fix lint
  * remove created_date
  * lint fixes
  * add sso account assignment tests
  * add permission set tag and disappear tests
  * terrafmt
  * add sso instance datasource test
  * add sso permission set datasource tests
  * make website-lint-fix
  * fix lint errors
  * resolve make lint errors
  * update sso permission set website doc
  * add sso assignment website doc
  * update to use paging with data.aws_sso_permission_set
  * add sso permisson set website docs
  * add permission set create, update, and delete test
  * permission set import bug fix
  * fix permission set provisioning wait
  * update to use paging with aws_sso_assignment
  * update to use paging with data.aws_identity_store_group and data.aws_identity_store_user
  * update to use paging with data.aws_sso_instance
  * update manage_policy_arns
  * update Create to check the assignment exists before creating it
  * fix id and import
  * add sso permission set provisioning
  * add timeouts and use resource.StateChangeConf
  * parse instance id from permission set arn
  * add sso permission set delete
  * add sso permission set update
  * add sso permission set read
  * add sso permission set create
  * fix usage of SetId
  * add sso assignment delete
  * add sso assignment Read
  * resourceAwsSsoAssignmentCreate
  * add in the sso permission set data source
  * implement aws_sso_instance data source
  * remove update from sso assignment
  * add data sources
  * add aws_sso_assignment
  * update schema
  * resource_aws_sso_permission_set scaffolding
  * tests/guardduty_filter: Simplify with data source
  * tests/resource/guardduty_filter: Fix hardcoded region
  * resource/config_aggregate_auth: Simplify test structure
  * Update CHANGELOG for #17023
  * resource/aws_route53_zone_association: Prevent deletion errors for
    missing Hosted Zone or VPC association (#17023)
  * Updates to aws_elasticache_cluster
  * resource/config_aggregate_authorization: Fix hardcoded regions
  * tests/efs_file_system: Remove arbitrary hardcoded region tag
  * tests/resource/efs_file_system: Fix hardcoded region
  * r/aws_apigatewayv2_integration: Data mapping in HTTP APIs.
  * Update CHANGELOG for #16885
  * Update CHANGELOG for #16884
  * fix wording in arg description
  * Replaces expandStringList(x.List()) with expandStringSet(x)
  * docs/contributing: Initial error handling documentation (#16794)
  * add lakeformation to issue/pr labeler
  * data source/partition: Rename attribute
  * Fix typo in 'data-handling-and-conversion.md' (#17042)
  * ds/partition: Add DNS prefix
  * Remove Otional and MaxItems from data source schema
  * Add acctest Name tag to all test workspaces
  * Test workspace_access_properties default values
  * Shift workspace_access_attributes from bool to string type
  * Fix resource name interpolation into tags in test configs
  * data aws_workspaces_directory: Add missed workspace_creation_properties
  * data aws_workspaces_directory: Add access properties
  * aws_workspaces_directory: Add access properties
  * Update CHANGELOG.md
  * Add subcategory to doc
  * remove computed from kms
  * missed a spot
  * restore vpc id
  * fix non existent argument + add kms key support
  * r/aws_cloudwatch_composite_alarm: code review
  * r/aws_cloudwatch_composite_alarm: add resource
  * add with image test
  * Add a doc for aws_route53_resolver_dnssec_config
  * Add tests for aws_route53_resolver_dnssec_config
  * Add aws_route53_resolver_dnssec_config
  * tests/workspaces_directory: Fix Sprintf issue
  * tests/workspaces_directory: Lint ignore hardcoded region
  * tests/resource/workspaces_directory: Fix hardcoded region
  * Fix formatting
  * Remove spurious file
  * add custom image
  * Apply suggestions from code review
  * add last tests
  * force new
  * fix default_resource_spec
  * fix basic test
  * share settings
  * remove kms key attributes and tests
  * fix filter for implict sgs
  * fix tags
  * tests are passing
  * delete implict sgs
  * sg test fmt
  * fix sg name
  * add kms test
  * add sg test
  * add tags test
  * move efs delete to tests
  * domain tests
  * add tests
  * fix argument name
  * add waiters
  * add to provider
  * add resource
  * Fix HCL
  * Code review changes
  * Fixed bug. include_map was using ExcludeMap on Update
- from version 3.23.0
  * Update CHANGELOG for #15808
  * rebased to master version w/changes
  * add mixed policy attachments test to permission set
  * add missing attribute
  * inline policy resource updates; managed policy attachment resource
  * add inline policy resource for permission set
  * importlint, typo, docs, remove unused
  * CR updates; align with design
  * move global/no account arn test
  * remove unused parameter
  * Update aws/resource_aws_sso_permission_set_test.go
  * update tfawsresource to use resource package
  * remove redundant error checks
  * Update website/docs/d/sso_instance.html.markdown
  * Update aws/resource_aws_sso_permission_set.go
  * Update aws/resource_aws_sso_permission_set.go
  * fix missing quote
  * Update aws/resource_aws_sso_permission_set.go
  * Update aws/resource_aws_sso_permission_set.go
  * Update aws/resource_aws_sso_permission_set_test.go
  * Update aws/resource_aws_sso_permission_set.go
  * Update aws/resource_aws_sso_permission_set_test.go
  * Update aws/resource_aws_sso_permission_set.go
  * Update aws/resource_aws_sso_permission_set.go
  * Update aws/data_source_aws_sso_permission_set.go
  * Update aws/data_source_aws_sso_permission_set.go
  * Update aws/data_source_aws_sso_permission_set.go
  * remove unused function
  * Update aws/data_source_aws_sso_instance.go
  * Update aws/data_source_aws_sso_instance.go
  * Update aws/data_source_aws_sso_instance.go
  * Update aws/data_source_aws_sso_instance.go
  * fix aws_sso_instance id
  * fix aws partition lints
  * fix misspelling
  * use testAccCheckResourceDisappears
  * add aws_sso_permission_set data source
  * add aws_sso_instance data source
  * tests/resource/cognito_user_group: Use data source for region
  * tests/resource/devicefarm: Remove unneeded test
  * tests/resource/instance: Update config comment
  * Update wording website/docs/r/security_group.html.markdown
  * Correctly handles error returned in Commercial partition and uses correct parameter name for workaround
  * No longer removes and adds modified parameters
  * Update CHANGELOG for #16829
  * Update CHANGELOG for #12340
  * resource/aws_route53_zone: Add length validations for `delegation_set_id` and `name` arguments (#12340)
  * Update CHANGELOG for #16924
  * resource/aws_emr_cluster: Remove from state instead of error on long terminated cluster (#16924)
  * resource/opsworks: Fix hardcoded regions
  * Naming cleanup
  * Adds parameter value tests
  * tests/resource/instance: Fix hardcoded region
  * tests/resource/iam_access_key: Fix hardcoded region
  * Moves ElastiCache parameter expander and flattener to resource file
  * Clean up
  * resource/devicefarm_project: Fix hardcoded regions
  * Update CHANGELOG for #9979
  * Update CHANGELOG.md for #16714
  * tests/resource/cognito_user_group: Fix hardcoded region
  * Update CHANGELOG.md for #16727
  * docs/resource/aws_emr_cluster: Link to AWS documentation for configuration settings (#16817)
  * Update CHANGELOG for #16495
  * resource/aws_vpc_endpoint_service: Make `private_dns_name` configurable
    and add `private_dns_name_configuration` attribute (#16495)
  * tests/resource/codebuild_project: Fix VPC issue
  * tests/resource/aws_autoscaling_group: Fix remaining S1039 reports
  * tests/resource/codebuild_project: Fix duplicate AZ config
  * tests/resource/codebuild_project: Standardized config with composeConfig()
  * tests/provider: Enable S1039 check for unnecessary fmt.Sprint()/fmt.Sprintf() usage (#16741)
  * Update CHANGELOG for #16938
  * resource/aws_transfer_user: Update username validation to support 100 characters (#16938)
  * .github/workflows: Increase goreleaser timeout from 1h to 2h (#16955)
  * Update CHANGELOG for #16914
  * Update CHANGELOG.md for #16082
  * tests/resource/codebuild_project: Fix hardcoded regions
  * tests/resource/budgets_budget: Fix hardcoded regions
  * tests/resource/dynamodb_global_table: Fix hardcoded regions
  * resource/eks_fargate_profile: Fix hardcoded regions
  * Restore go mod and sum
  * resource/gamelift: Fix hardcoded regions
  * docs/provider: Fix broken links to terraform docs (#16956)
  * build(deps): bump alex-page/github-project-automation-plus (#16764)
  * Update CHANGELOG for #16947
  * service/imagebuilder: Review items from #16947
  * Update aws/resource_aws_imagebuilder_image_recipe.go
  * docs/resource/aws_codeartifact_repository_permissions_policy: Fix typo (#16954)
  * build(deps): bump github.com/aws/aws-sdk-go in /awsproviderlint (#16935)
  * Update CHANGELOG for #16905
  * resource/aws_imagebuilder_distribution_configuration: Remove `user_ids` maximum limit (#16905)
  * docs/resource/aws_s3_ownership_controls: Remove preview note as it's now GA (#16897)
  * docs/provider: Fix links to terraform resource timeouts (#16899)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.36.12 to 1.36.19 (#16934)
  * docs: Update aws_imagebuilder_image_recipe new property working_directory
  * feature: Add working_directory to ImageBuilder
  * Fixed typo in docs
  * Added documentation & tidyup
  * Fixed resource import
  * Removed log statement
  * Initial commit for FMS policy
  * fix in resource aws_msk_cluster enhanced_monitoring and client_broker using the AWS Go SDK _Values()
  * add validation check to final snapshot identifier
  * remove ForceNew attribute from stateful_rule field and its children
  * Update CHANGELOG for #16608
  * Update website/docs/r/ssm_maintenance_window_task.html.markdown
  * Changelog typo
  * Include string "IMDSv2" in docs
  * r/aws_appmesh_route: Allow empty 'match' for 'grpc_route'.
  * build(deps): bump github.com/hashicorp/terraform-plugin-sdk/v2 (#16856)
  * build(deps): bump github.com/hashicorp/terraform-plugin-sdk/v2 (#16858)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.36.7 to 1.36.12 (#16857)
  * build(deps): bump github.com/aws/aws-sdk-go in /awsproviderlint (#16855)
  * Update glue_crawler.html.markdown
  * revert mongo db doc delete
  * add docs
  * default for recrawl
  * add recrawl argument + validations
  * add crawler test
  * flatten schem policy
  * add lineage settings
  * Updating example's "name"
  * Makes CodeStar Connection default for CodePipeline tests. GITHUB_TOKEN is no longer needs for most acceptance tests
- from version 3.22.0
  * Update CHANGELOG.md
  * Update CHANGELOG for #16678
  * Update CHANGELOG with Lake Formation
  * resource/lakeformation: Fix semgrep issues
  * resource/lakeformation: Fix linter issues
  * Separates GITHUB_TOKEN preCheck from CodePipeline service support preChek
  * ds/lakeformation_permissions: New data source
  * resource/lakeformation: Fix linting
  * resource/lakeformation: Pre-merge cleanup
  * resource/lakeformation_permissions: Adjust for passing tests
  * resource/lakeformation_permissions: Eventual consistency issues
  * resource/lakeformation: Use ValidatePrincipal for Lake Formation principals
  * validators: Add ValidatePrincipal for Lake Formation principals
  * resource/lakeformation_permissions: Align with design and conventions
  * docs/resource/lakeformation_permissions: Rework for design
  * resource/lakeformation_resource: Improve docs, error messages (minor)
  * ds/lakeformation_resource: New data source
  * resource/lakeformation_permissions: Remove PR-extraneous files
  * resource/lakeformation_permissions: Remove datalake_settings from PR
  * resource/lakeformation_permissions: Upgrade to plugin SDK v2
  * resource/lakeformation: Remove aws.erb from PR
  * Remove redundant check, add one test step
  * Fix type in HCL example
  * Handle TableWithColumns resource I/O in ListPermissions request
  * Cleanup
  * Use const defined in API for permissions
  * Add timestamp to resource ID
  * Check that permissions are revoked in acceptance tests
  * Test multiple permissions on table resource
  * Define permissions at catalog level
  * Add documentation
  * New resource: aws_lakeformation_permissions (WIP)
  * Add resource documentation
  * New resource: aws_lakeformation_datalake_settings
  * Update CHANGELOG for #16808
  * resource/aws_eip_association: fix eventual consistency issue when associating EIP (#16808)
  * Update CHANGELOG for #16684
  * Adds acceptance test for CodePipeline using CodeStar Connection source ation
  * Update CHANGELOG for #16830
  * Removes GitHub OAuth token hashing
  * Adds clarifying documentation about cluster mode and parameter groups
  * #16821 Fix spelling of db_subnet_group_name in restore_to_point_in_time
  * add support for extraConnectionAttributes in create/read ops and handle returned diffs
  * Adds cliuster_enabled output and plan-time validation for number_cache_clusters and cluster_mode
  * resource/aws_ec2_managed_prefix_list: Use cidr not cidr_block for API consistency
  * Update CHANGELOG for #14068
  * resource/aws_ec2_managed_prefix_list: Refactoring for consistency
  * Update CHANGELOG for #16738
  * New data source: aws_ec2_managed_prefix_list (#16738)
  * Fix s3_bucket lifecycle_rule requirements
  * resource/aws_directory_service_directory: Deletion and sweeper refactoring (#16653)
  * Update CHANGELOG for #16620
  * docs/data-source/aws_instance: Add throughput attribute
  * service/ec2: Add throughput attribute to aws_instance resource and data source (#16620)
  * docs/contributing: Add data handling and conversion documentation (#16748)
  * Update with Lake Formation resource and settings
  * resource/lakeformation_data_lake_settings: Clean up before merge
  * ds/lakeformat_data_lake_settings: New data source
  * resource/lakeformation_data_lake_settings: Add docs, validate function
  * resource/lakeformation_data_lake_settings: Fix linter issues, simplify
  * resource/lakeformation_data_lake_settings: Add arguments, tests
  * resource/lakeformation_data_lake_settings: Remove go.mod, go.sum from PR
  * resource/lakeformation_data_lake_settings: Rename 'datalake' to 'data lake'
  * resource/lakeformation_data_lake_settings: Upgrade to plugin v2
  * Remove redundant check
  * Use Lake Formation official spelling
  * Add documentation
  * New resource: aws_lakeformation_datalake_settings
  * updated mq broker user property to 'required'
  * Update CHANGELOG for #16669
  * service/ec2: Use paginated functions in plural COIP and Local Gateway data sources (#16669)
  * tests/resource/aws_elasticsearch_domain: Use multierror in sweeper and skip
    domains stuck in deleting status (#16648)
  * r/aws_ec2_managed_prefix_list: code review updates
  * r/aws_ec2_managed_prefix_list_entry: remove resource
  * Update ROADMAP.md
  * Update CHANGELOG for #16680
  * resource/aws_main_route_table_association: Prevent crash on creation when VPC
    main route table association is not found (#16680)
  * Update CHANGELOG.md
  * Read all atrributes in tunnel options.
  * Allows cluster_mode configuration when cluster mode is not enabled for parity with API
  * update policy of test configs and examples in documentation
  * Update CHANGELOG for #15990
  * Minor cleanup
  * Correctly quote `shared` in ecs_task_definition
  * Update CHANGELOG for #16770
  * data-source/aws_availability_zone: Add `parent_zone_id`, `parent_zone_name`, and `zone_type`
    attributes (additional support for Local and Wavelength Zones) (#16770)
  * Update CHANGELOG for #16723
  * data-source/aws_network_interface: Add association carrier_ip and customer_owned_ip attributes (#16723)
  * provider: Bump Go version to 1.15 and standardize on .go-version file for GitHub Actions workflows (#16557)
  * Update CHANGELOG for #16361
  * Support Nitro Enclaves in aws_instance and aws_launch_template (#16361)
  * Update CHANGELOG for #16724
  * service/ec2: Add `carrier_ip` attribute to aws_eip resource and data source (#16724)
  * tests/provider: Fix and enable AT009 lint check (#16637)
  * Fix a lint error
  * Add TestAccAWSCodeStarConnectionsConnection_disappears
  * Handle a case when a connection is not found
  * Rename rule to resp
  * Add a check if rule and rule.Connections is nil
  * Modify error messages
  * Rename connection_name to name
  * Remove connection_arn
  * Update CHANGELOG for #16739
  * data-source/aws_prefix_list: Using `name` argument no longer overrides other arguments (#16739)
  * update description of protocol arguments
  * New Service: Amazon Connect (#16644)
  * Update CHANGELOG for #14637
  * resource/aws_launch_configuration: Add metadata_options configuration block (#14637)
  * docs/resource/aws_launch_template: Fix typo: throughput (#16731)
  * Update CHANGELOG for #16692
  * resource/aws_workspaces_workspace: Fix Terminated Workspace Panic (#16692)
  * Use codestarconnections.ProviderType_Values() instead
  * Adds note about ElastiCache Replication Group not supporting auto minor version upgrade parameter
  * Update CHANGELOG for #16297
  * Adds launch_template to aws_autoscaling_group data source
  * build(deps): bump github.com/aws/aws-sdk-go from 1.36.0 to 1.36.7 (#16726)
  * r/aws_route_table: Refactor acceptance test configuration generator
    so as avoid 'terrafmt' linting exclusion (#16735)
  * build(deps): bump github.com/aws/aws-sdk-go in /awsproviderlint (#16744)
  * Code better broken up into functions and added struct for testing
  * Add vpn options to aws_vpn_connection resource
  * Check that  is empty is base test case
  * Ensure  not nil, even if no partition keys defined.
  * Update CHANGELOG.md
- from version 3.21.0
  * Update CHANGELOG for #16652
  * resource/aws_spot_fleet_request: Add 'throughput' attribute
    to 'launch_specification.ebs_block_device'
    and 'launch_specification.root_block_device' configuration blocks. (#16652)
  * Update CHANGELOG for #16457
  * data-source/aws_launch_template: Support id as argument (#16457)
  * Update CHANGELOG for #16649
  * service/ec2: Add gp3 volume scalable throughput to aws_launch_template
    resource and datasource (#16649)
  * Update CHANGELOG for #16707
  * aws_launch_template: AWS Wavelength support (#16707)
  * tests/resource/aws_instance: Correct 'TestAccAWSInstance_EbsRootDevice_ModifyType'. (#16702)
  * reduce retry logic
  * Mark kinesis stream access_key as sensitive
  * resource/lakeformation_resource: Use ForceNew for more update options
  * docs/contributing: Add Extending Terraform link for acceptance
    test framework environment variables (#16600)
  * provider: Document, standardize, and lint for disappears acceptance
    testing of parent resources (#16597)
  * provider: Prevent potential panics due to setting resource identifiers
    with raw string pointer dereferencing (#16594)
  * Adds support for AWS_CONTAINER_CREDENTIALS_FULL_URI for authentication
  * Update CHANGELOG for #16566
  * resource/aws_imagebuilder_image_recipe: Ensure proper ordering of
    `component` configuration blocks (#16566)
  * Adds validation for field names
  * resource/lakeformation_resource: Improve error messages
  * Update CHANGELOG for #16252
  * New Resource: aws_ec2_carrier_gateway (#16252)
  * tests/lakeformation_resource: Add precheck
  * resource/lakeformation_resource: Remove go.mod, go.sum
  * Update CHANGELOG for #16605
  * Update CHANGELOG for #16667
  * provider: adding Computed: true to id of few data sources, as those should
  be marked as computed even if set to optional (#16667)
  * tests/lakeformation_resource: Fix to use ARN check func
  * docs/lakeformation_datalake_settings: Remove from branch (part of later PR)
  * docs/lakeformation_resource: Fix formatting
  * resource/lakeformation: Remove lakeformation_datalake_settings
  * tests/resource/lakeformation_resource: Add exists and disappears
  * add rule to remove extraneous string list to set casting
  * Adds triggers parameter to instance_refresh
  * Removes non-default refresh triggers and adds testing for cancelling in-progress refreshes
  * Rework Lake Formation to design
  * Update CHANGELOG.md for #16612
  * Update CHANGELOG.md for #16459
  * Update CHANGELOG.md for #16589
  * Apply suggestions from code review
  * Better validations
  * Add resource documentation
  * New resource: aws_lakeformation_resource
  * Use Lake Formation official spelling
  * Make data lake admins list a set
  * Rename expand and flatten functions for admins list
  * Add missing website LakeFormation subcategory
  * Add AWS region in settings identifier
  * Add documentation
  * Check resource state on destroy
  * New resource: aws_lakeformation_datalake_settings
  * update ssm maintenance window task resource docs
  * remove validation
  * tests/resource/aws_ssm_maintenance_window: Fix TestAccAWSSSMMaintenanceWindow_ScheduleOffset configuration
  * Update CHANGELOG for #16569
  * resource/aws_ssm_maintenance_window: Add schedule_offset argument (#16569)
  * tests/resource/aws_route_table: Refactor acceptance tests in preparation
    for future fixes/enhancements (#14013)
  * deps: Update github.com/bflad/tfproviderlint@v0.21.0 (#16617)
  * tests/resource/sagemaker_endpoint: Make region agnostic
  * tests/res/route53: Fix hardcoded regions
  * tests/resource/aws_default_route_table: Refactor acceptance tests
    in preparation for future fixes/enhancements (#14012)
  * tests/res/security_group_rule: Fix hardcoded region
  * Fix custom security attribute check
  * update documentation
  * Add terraform acctest tags
  * @review Drop redundant aws_security_group test resource
  * aws_workspaces_directory: Fix empty custom_security_group_id & default_ou
  * wait before  create
  * Update aws/resource_aws_sagemaker_image.go
  * Apply suggestions from code review
  * Apply suggestions from code review
  * Update aws/resource_aws_sagemaker_image.go
  * delete timeput
  * add description and displayname tests
  * add tags test
  * basic tests passing
  * sagemaker image
  * doc fmt
  * remove check
  * add checks for version uptates
  * add docs
  * misspell
  * add parent disappears test
  * add schema version stuff
  * add code schema resource
  * r/aws_ec2_managed_prefix_list_entry: new resource
  * r/aws_ec2_managed_prefix_list: new resource
  * increased max retention period for kinesis stream to 8760
  * Only try to cancel Instance Refresh when we get an "InstanceRefreshInProgress" error
  * Update CHANGELOG.md for #16167
  * Updates naming to "Auto Scaling Group"
  * Moves nullable to experimental
  * use base ref from event payload
  * remove validation
  * Update documentation for aws_lambda_function 'runtime' parameter
  * tests/resource/aws_lightsail_domain: Remove hardcoded region
    and standardize disappears testing (#16304)
  * tests/resource/aws_batch_compute_environment: Handle INVALID status in sweeper (#16417)
  * tests/r/vpn_gateway: Fix hardcoded region
  * ds/eip ds/arn: Fix hardcoded region
  * specify master as checkout ref to ensure next milestone can be found
  * aws_workspaces_workspace: Add error code for the failed requests
  * Update CHANGELOG.md with next release #
- from version 3.20.0
  * Allows skipping GuardDuty Detector in sweepers
  * Removes DEBUG log statements
  * Update website/docs/d/lex_bot.html.markdown
  * Update website/docs/d/lex_bot.html.markdown
  * Update website/docs/d/lex_bot.html.markdown
  * Uses correct code for IAM
  * Factors IAM Role deletion and allows individual resource skipping in sweeper
  * Adds resource skipper function for sweepers
  * provider: Add -debug flag to main binary (#16565)
  * resource/codedeploy_deployment_group: Use flattenStringSet helper
  * add language to indicated that configurations to reporduce bugs are required
  * Update CHANGELOG for #16183
  * docs/data-source/aws_eks_cluster_auth: Add note about resource import (#16501)
  * Update CHANGELOG for #16484
  * resource/aws_cloudwatch_event_target: Prevent potential panic and passthrough
    custom event_bus_name in v0 state upgrade (#16484)
  * Update CHANGELOG for #16443
  * resource/aws_instance: Automatically retry instance_type restart on
    eventual consistency error (#16443)
  * docs/service/ec2: Include more references to aws_ec2_tag resource for
    EC2 Transit Gateway VPN Attachment usage (#16441)
  * tests/provider: Migrate remaining PreConfig disappears
    testing to testAccCheckResourceDisappears (#16305)
  * docs(lex_bot.html.markdown): updated missing attributes for lex_bot data source
  * update retry methods to include context
  * Update CHANGELOG for #16522
  * provider: Add ecrpublic Service Client (#16541)
  * provider: Ensure website PR files are labeled as documentation (#16545)
  * Update CHANGELOG for #16552
  * Update CHANGELOG.md for #16472
  * Update CHANGELOG for #16518
  * remove drift detection from capacity_type argument
  * tests/resource/ec2_transit_gateway: Fix/ignore hardcoded regions
  * tests/resource/ec2_client_vpn: Fix/ignore hardcoded regions
  * tests/resource/ec2_availability_zone_group: Lint ignore hardcoded region
  * Update CHANGELOG for #16476
  * resource/aws_backup_plan: Retry on eventual consistency error on deletion + validations (#16476)
  * tests/resource/route53: Use verb indices
  * tests/provider: Rework Route53 PublicDNS ErrorCheck
  * tests/resource/shield_protection: Add additional PreCheck for GovCloud
  * tests/provider: Fix fmt.Sprintf() indices (Route53)
  * tests/provider: Make Route53 data source test names consistent
  * tests/provider: Rename Route53 acceptance tests for consistency
  * tests/provider: Rework Route53 PublicDNS skipping
  * tests/route53: Skip PublicDNS tests
  * Update CHANGELOG for #16478
  * resource/aws_ssm_maintainance_window_target: Remove from state if deleted (#16478)
  * docs/service/elasticache: Removes references to automated backup
    not being available on t2 instances (#16462)
  * tests/provider: Fix hardcoded region
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16531)
  * Add MWAA service client (#16497)
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.37 to 1.36.0 (#16530)
  * remove invalid secondary_artifacts type
  * rename TestAccAWSLambdaEventSourceMapping_BatchWindow ->
    TestAccAWSLambdaEventSourceMapping_KinesisBatchWindow
  * move MaximumBatchingWindowInSeconds into params instantiation
  * Update aws/resource_aws_lambda_event_source_mapping_test.go
  * update documentation
  * update required fields and documentation
  * tests/datasync: Fix hardcoded regions
  * tests/transfer: Fix hardcoded regions
  * Uses the TypeStringNullableInt pattern for instance_warmup
  * tests/ds/region: Fix hardcoded region
  * Updated network association timeout from 10 min to 30 min
  * add acceptance test
  * add maximum_batching_window_in_seconds support for sqs as well
  * tests/ds/ip_ranges: Lint ignore hardcoded regions
- from version 3.19.0
  * Update CHANGELOG for ##16510
  * resource/aws_eks_node_group: Add capacity_type argument and
    support multiple instance_types (#16510)
  * Update CHANGELOG for #16512
  * update test cases
  * update import order
  * fix formatting
  * r/aws_appmesh_virtual_node: Test corrections.
  * r/aws_appmesh_virtual_node: Document 'listener.connection_pool'
    and 'listener.outlier_detection' attributes.
  * r/aws_appmesh_virtual_node: Add 'listener.outlier_detection' attribute.
  * Add 'expandAppmeshDuration' and 'flattenAppmeshDuration'.
  * r/aws_appmesh_virtual_node: Add '_disappears' test (#13826).
  * r/aws_appmesh_virtual_node: Add 'listener.connection_pool' attribute.
  * fetch lambda image ids from environment variables.
  * r/aws_appmesh_virtual_node: Add ExactlyOneOf constraint on 'spec.listener.timeout'.
  * r/aws_appmesh_virtual_node: Add ExactlyOneOf constraint on 'spec.listener.tls.certificate'.
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.35 to 1.35.37 (#16509)
  * Update CHANGELOG.md for #15249
  * Update CHANGELOG.md for #16168
  * update description for the link to lambda doc
  * fix link to lambda doc
  * Update CHANGELOG for #16488
  * resource/aws_fsx_windows_file_system: Prevent potential panics, unexpected errors,
    and use correct operation timeout on update (#16488)
  * Add CustomizeDiff to validate handler and runtime for zip type lambda functions
  * include link to lambda doc
  * use %%w for error format
  * add precheck for govcloud
  * Update CHANGELOG entry link
  * Update CHANGELOG for #15518
  * Use validation.Any instead
  * Add a new Acc test for point time restore and cloud watch log export
  * Updates instance_refresh structure to match API
  * Added EKS data source, updated docs
  * Apply suggestions from code review
  * service/serverlessapplicationrepository: Add issue and pull request labeling (#16486)
  * Update CHANGELOG.md
  * Update aws/resource_aws_eks_cluster_test.go
  * Update cognito_user_pool.markdown
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16428)
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.34 to 1.35.35 (#16429)
  * update test case
  * remove debug code
  * replace tab with spaces
  * address code review comments
  * address code review comments
  * Fixes instance refresh error
  * add more doc
  * add nics
  * add docs
  * add timeout test
  * update AWSAT004 docs to reflect migration
  * remove provider level typeset check functions
  * remove last references to tfawsresrouce
  * fix typo in instances_distribution example
  * add waiter for join domain
  * tests/provider: Migrate to SDK TypeSet Function
  * move waiter
  * add org unit
  * add GMT validation and some basic checks
  * add ou and domain controllers + validations
  * expand domain + computed fields
  * tests/provider: Migrate to SDK TypeSet Function
  * Update CHANGELOG.md for #16418
  * Update CHANGELOG.md for #16414
  * resource/aws_rds_cluster: Define validateRestoreToPointInTimeSourceClusterIdentifier
    for source_cluster_identifier in restore_to_point_in_time block
  * resource/aws_rds_cluster: Fix an enabled_cloudwatch_logs_exports type conversion error
  * Reformats tests
- from version 3.18.0
  * Update CHANGELOG for #15874
  * Update CHANGELOG for #16399
  * Avoids Go formatting churn and Git conflict
  * Reorganizes import and read code
  * CR updates
  * tests/resource/aws_batch_job_queue: Create and use IAM Instance Profile
    for compute resources (#16230)
  * Update CHANGELOG for #16306
  * resource/aws_lb_listener: Mark port argument as optional and only default protocol
    argument to HTTP for Application Load Balancers (Support Gateway Load Balancer) (#16306)
  * Update CHANGELOG for #16422
  * data-source/aws_codeartifact_repository_endpoint: Test and document support for NuGet (#16422)
  * Update CHANGELOG for #16279
  * Update website/docs/r/networkfirewall_resource_policy.html.markdown
  * Update example usage principal ARN
  * Update CHANGELOG for #16299
  * New Resource: aws_imagebuilder_image_pipeline (#16299)
  * Update CHANGELOG for #15302
  * Update website/docs/r/glue_registry.html.markdown
  * test and doc updates
  * Updates tfresource.NotFound() to support wrapped errors
  * Removes unneeded ForceNew from semantic_version attribute
  * change milestone workflow to use pull_request_target event
  * add glue registry resource
  * Update CHANGELOG for #16412
  * provider: Followup items from initial Code Signing release (#16412)
  * Update CHANGELOG.md for #16114
  * Update CHANGELOG for #16404
  * resource/aws_securityhub_member: Prevent invited attribute updates due to recent API changes (#16404)
  * update tests with jsonencode for policy
  * More renaming
  * Update CHANGELOG for #16319
  * resource/aws_cloudwatch_event_permission: Support DescribeEventBridge API returning account ID or root account ARN (#16319)
  * add support for access_based_enumeration and notification_policy
  * Update CHANGELOG for #16303
  * infrastructure/repository: Bump Terraform CLI to 0.13.5 and use remote backend (#16298)
  * Update CHANGELOG.md for #16389
  * tests/resource/aws_securityhub_member: Handle BadRequestException in CheckDestroy (#16408)
  * Update CHANGELOG.md for #16260
  * add
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16400)
  * Update CHANGELOG for #16218
  * New Resource: aws_imagebuilder_image_recipe (#16218)
  * Renames file
  * Renaming to match package name
  * Update aws/resource_aws_backup_region_settings_test.go
  * add sync-state information
  * update docs with correct ref to s3 bucket and stream
  * Adds import functionality
- from version 3.17.0
  * Update CHANGELOG.md for #16340
  * Update CHANGELOG for #16384
  * Support for Code Signing For AWS Lambda (#16384)
  * Update aws/resource_aws_backup_region_settings_test.go
  * Update CHANGELOG.md #15582
  * r/aws_kinesisanalyticsv2_application: Support Apache Flink v1.11.
  * Update CHANGELOG for #16383
  * Support for AWS Signer service (#16383)
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.33 to 1.35.34 (#16381)
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16369)
  * build(deps): Bump github.com/hashicorp/terraform-plugin-sdk/v2 (#16370)
  * Update CHANGELOG for #16363
  * resource/aws_fsx_windows_file_system: Update the default creation timeout from 30 to 45 minutes (#16363)
  * build(deps): Bump github.com/golangci/golangci-lint in /tools (#16371)
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.30 to 1.35.33 (#16368)
  * build(deps): Bump github.com/hashicorp/terraform-plugin-sdk/v2 (#16367)
  * internal/generators/listpages: Generate Context-Aware functions (#16345)
  * change group_id and owner_id to string
  * rename to deleted
  * Adds exclusion to multiple AWS service rule
  * Fix aws_networkfirewall_logging_configuration doc error (issue #16353).
  * Update website/docs/r/storagegateway_nfs_file_share.html.markdown
  * revert kms
  * add notifiaction policy + validations
  * test/resource/s3_bucket: Fix AWSR001 regional hostname issues
  * resource/s3_bucket: Fix hardcoded regions
  * tests/provider: Fix hardcoded regions (Validator, Structure)
  * ds/redshift_service_account: Fix hardcoded regions
  * hosted zone: Fix hardcoded region
  * ds/elb: Fixed hardcoded regions
  * tests/provider: Add Gateway LB precheck to tests
  * tests/config: Fix hardcoded regions
  * Update CHANGELOG.md for #16194
  * tests/ds/elastic_beanstalk_hosted_zone: Fix hardcoded region
  * tests/ds/cloudtrail_service_account: Fix hardcoded regions
  * Update CHANGELOG for #16314
  * resource/aws_lb: Fix enable_cross_zone_load_balancing argument handling with Gateway Load Balancers (#16314)
  * update resource tagging for Read Op
  * tests/resource/ec2_fleet: Fix query returned no results (GovCloud)
  * tests/data/autoscaling_group: Fix query returned no results (GovCloud)
  * tests/data/aws_instances: Fix query returned no results
  * Corrects connection_pool_config to be Optional and Computed
  * tests/resource/aws_codebuild_project: Remove WINDOWS_CONTAINER acceptance test (#16231)
  * service/ec2: Implement standardized EC2-Classic handling in
    TestAccDataSourceAwsEip_PublicIP_EC2Classic and TestAccAWSEIP_tags_Ec2Classic
  * Use flattenStringSet helper
  * resource/storagegateway_smb_file_share: Use flattenStringSet helper
  * CapacityRebalance proerty to 'false' if removed.
  * Update CHANGELOG for #16265
  * Improves validation message
  * Update CHANGELOG for #14451
  * Handles deletion of IP Group attached to multiple Directories
  * Update CHANGELOG.md after release
  * resource/s3_bucket_notification: Use flattenStringSet helper
  * resource/eks_cluster: Use flattenStringSet helper
  * tests/resource/aws_msk_cluster: Randomize resource naming in TestAccAWSMskCluster_LoggingInfo (#16278)
  * Update aws/resource_aws_glue_catalog_table.go
- from version 3.16.0
  * Update CHANGELOG for #16277
  * Update aws/resource_aws_networkfirewall_firewall.go
  * resource/ecs_service: Use flattenStringSet helper
  * fix destination type name typo
  * avoid panic when we only have 1 loggingConfig to update
  * 'tfawsresource.TestCheckTypeSetElemNestedAttrs' -> 'resource.TestCheckTypeSetElemNestedAttrs'.
  * update log destination refs
  * correct vpc/network find and replace
  * correct firewall resource refs in logging config tests
  * Update CHANGELOG.md for #16133
  * Update CHANGELOG.md for #16121
  * resource/codebuild_project: Use flattenStringSet helper
  * resource/batch_compute_environment: Use flattenStringSet helper
  * cleanup service refs
  * resource/datasync_location_smb: Use flattenStringSet helper
  * resource/cloudformation_stack: Use flattenStringSet helper
  * add alternate provider config
  * update acctest data source
  * add resource_policy resource support
  * resource/cloudfront_distribution: Use flattenStringSet helper
  * fix terrafmt error
  * updates for live env support
  * docs: Remediate and enable MD010 lint (#16271)
  * Update CHANGELOG for #16186
  * New Resource: aws_imagebuilder_infrastructure_configuration (#16186)
  * Update CHANGELOG for #14020
  * resource/aws_eks_fargate_profile: Keep previous IAM propagation timeout on
    creation and simplify new multiple profile test
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16269)
  * fix linting errors
  * CR updates and refactor
  * Cleanup
  * Adds correct validation to analyzer_name
  * Update CHANGELOG.md for #16052
  * Update CHANGELOG.md for #16072
  * Adds required parameter to example
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.29 to 1.35.30
  * r/aws_kinesisanalyticsv2_application: Change 'record_column' from 'TypeSet' to 'TypeList'.
  * r/aws_kinesis_analytics_application: Revert 'record_columns' from 'TypeSet' to 'TypeList'.
  * Update CHANGELOG for #16180
  * New Resource: aws_imagebuilder_distribution_configuration (#16180)
  * Update CHANGELOG for #13619 and #16169
  * tests/provider: Fix and enable AT004 lint check
  * New Resource: aws_imagebuilder_component (#16169)
  * docs/resource/aws_api_gateway_rest_api_policy: Fix tflint issue
  * tests/resource/ssm_document: Fix query returned no results
  * tests/resource/ssm_association: Fix query returned no results
  * tests/resource/launch_template: Fix query returned no results
  * Correct issue link for SNS redrive_policy issue
  * service/apigateway: Minor test and documentation updates for updated policy handling
  * Update CHANGELOG for #13654
  * Update CHANGELOG for #13619
  * New Resource: aws_api_gateway_rest_api_policy (#13619)
  * aws_workspaces_directory: Assign IP group
  * tests/resource/aws_cognito_user_pool_domain: Remove hardcoded region handling
    and create public ACM Certificate (#16140)
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.27 to 1.35.29 (#16234)
  * Update CHANGELOG for #15481
  * service/s3: Use the current credentials when trying to get the bucket region (#15481)
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16233)
  * docs/provider: Correcting attribute section byline (#16199)
  * docs/resource/aws_wafv2_web_acl: Update description of `field_to_match`
    block to include empty block requirement for `uri_path` (#16245)
  * resource/aws_glue_dev_endpoint: Catch additional IAM eventual consistency
    error and fix VPC testing (#16232)
  * tests/provider: Migrate to SDK TypeSet Function
  * resource/aws_msk_cluster: Support in-place Kafka version upgrade
  * tests/provider: Migrate to SDK TypeSet Function
  * tests/provider: Migrate to SDK TypeSet Function
  * tests/provider: Migrate to SDK TypeSet Function
  * tests/resource/aws_wafv2: Migrate to SDK TypeSet Function
  * tests/resource/aws_wafregional: Migrate to SDK TypeSet Function
  * tests/resource/aws_waf: Migrate to SDK TypeSet Function
  * build(deps): Bump github.com/pquerna/otp from 1.2.0 to 1.3.0 (#16138)
  * tests/resource/aws_iam_saml_provider: Add sweeper (#16193)
  * tests/resource/instance: Fix query returned no results
  * docs: Fix heading not matching TOC
  * tests/resource/aws_autoscaling: Migrate to SDK TypeSet Function
  * tests/resource/aws_appmesh: Migrate to SDK TypeSet Function
  * limit scope to first interaction
  * tests/resource/aws_appautoscaling_policy: Migrate to SDK TypeSet Function
  * tests/resource/aws_apigatewayv2: Migrate to SDK TypeSet Function
  * tests/resource/aws_api_gateway_integration: Migrate to SDK TypeSet function
  * tests/resource/aws_acm_certificate: Migrate to SDK TypeSet function
  * .github/workflows: Remove --quiet flag from terrafmt (#16182)
  * add OCI image support to aws_lambda_function resource
  * add partition indexes
  * Tweaks
  * change name, update description
  * change to one job in order to force a sequence
  * Update CHANGELOG for #14900
  * Consolidates content change test
  * remove heading formatting
  * quick wording change
  * Add Bill
  * r/aws_lambda_function return nil on resource not found errors
  * addressed PR feedback
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.25 to 1.35.27 (#16176)
  * Update CHANGELOG.md for #16112
  * Update CHANGELOG.md for #16116
  * build(deps): Bump github.com/aws/aws-sdk-go in /awsproviderlint (#16175)
  * tests/provider: Fixes for testing provider re-configuration (#16018)
  * Update aws/resource_aws_eks_cluster.go
  * Update website/docs/r/eks_cluster.html.markdown
  * Update aws/resource_aws_eks_cluster_test.go
  * Using planonly to check unchanged IP
  * Fixed typo in documentation.
  * tests/provider: Add API Gateway EDGE PreCheck
  * Update CHANGELOG for #15473
  * tests/provider: Add PreChecks (various)
  * Update CHANGELOG.md for #16008
  * Updates documentation
  * Update CHANGELOG.md for #7895
- from version 3.15.0
  * Test stack name
  * tests/resource/aws_eks_node_group: Fix test failures (#16164)
  * r/aws_appmesh_virtual_gateway: Test corrections.
  * Create timeout constants
  * lint fix
  * r/aws_appmesh_virtual_gateway: Test 'listener.connection_pool' attribute.
  * Adds disappears test
  * addressing PR feedback
  * r/aws_appmesh_virtual_gateway: Add 'listener.connection_pool' attribute.
  * r/aws_appmesh_virtual_gateway: Replace ConflictsWith constraints with ExactlyOneOf.
  * doc updates
  * support for updating feature_set attribute
  * adding fix for aws org update issue from #15462
  * Fix workspaces_defaultRole notes
  * Update hardcoding documentation for clarity
  * docs: Add documentation for avoid hardcoding in tests
  * Update CHANGELOG for #15969
  * re-use func in master
  * Update aws/validators_test.go error message
  * update validator test error message
  * CR updates
  * prevent panic from nil time value
  * remove unused default value and update docs
  * add point in time restore argument and refactor timestamp validator
  * Update CHANGELOG for #13921
  * service/ec2: rd/transit_gateway_route_table - add arn + refactor disappears (#13921)
  * Update CHANGELOG for #7031
  * service/rds: Discourage usage of engine_mode = "global" due to API changes (#16091)
  * Update CHANGELOG for #15556
  * resource/aws_ec2_transit_gateway: Support in-place updates for most arguments (#15556)
  * tests/resource/aws_api_gateway_domain_name: Remove hardcoded environment variable handling,
    create public ACM certificate, improve state value checks (#16139)
  * docs/provider: Grammatical changes (#16149)
  * Update CHANGELOG for #16159
  * service/ec2: Add Transit Gateway VPC Attachment appliance_mode_support argument/attribute (#16159)
  * Update CHANGELOG for #16032
  * service/ec2: Handle additional EIP association issues and remove EIP hardcoded us-east-1 environment
    variable handling in tests (#16032)
  * service/waf: Generate paginated list functions and implement all sweepers (#16150)
  * .github/workflows: Replace deprecated set-env handling (#16144)
  * Reformat code
  * Update aws/resource_aws_rds_cluster.go
  * tests/resource/devicefarm_project: Add PreCheck
  * Update fsx_windows_file_system.html.markdown
  * r/aws_apigatewayv2_domain_name: Create public ACM certificate for testing mutual TLS (relates: #16139).
  * Revert "Revert "r/aws_acmpca_certificate_authority: Add 'testAccCheckAwsAcmpcaCertificateAuthorityDisableCA'.""
  * Remove unused code.
  * r/aws_apigatewayv2_domain_name: Use Amazon Issued ACM certificate for mutual TLS acceptance tests.
  * Revert "r/aws_acmpca_certificate_authority: Add 'testAccCheckAwsAcmpcaCertificateAuthorityDisableCA'."
  * r/aws_apigatewayv2_domain_name: Test mutual authentication with ACM issued private certificate.
  * r/aws_apigatewayv2_domain_name: Add 'mutual_tls_authentication' attribute.
  * Update CHANGELOG for #15942
  * resource/aws_db_instance: Ignore DBInstanceNotFound error during deletion (#15942)
  * tests/resource/aws_lb: Fix TestAccAWSLB_networkLoadbalancerEIP configuration (#16134)
  * tests/provider: Simplify checks to run in awsproviderlint Makefile target (#15926)
  * Update CHANGELOG for #16131
  * Gateway Load Balancer Support (#16131)
  * Remove input validation check and document
  * Check for empty restore_to_time value
  * Add and use 'testAccPreCheckAWSAPIGatewayAccountCloudWatchRoleArn'.
  * r/aws_apigatewayv2_stage: Ensure account CloudWatch role ARN is set for acceptance tests.
  * Update aws/resource_aws_rds_cluster.go
  * add conflicts and restructure tests
  * r/aws_msk_sasl_scram_secret: New Resouce
  * Cleanup test config
  * Use testAccAvailableAZsNoOptInConfig to find AZ
  * Address the reviews
  * Update aws/resource_aws_rds_cluster.go
  * Update aws/resource_aws_rds_cluster_test.go
  * tests/resource/aws_fms_admin_account: Remove hardcoded environment variable handling (#16041)
  * tests/data-source/aws_pricing_product: Remove hardcoded us-east-1 handling (#16040)
  * tests/service/elasticache: Remove hardcoded us-east-1 handling (#16034)
  * tests/resource/aws_route53_query_log: Remove hardcoded environment variable handling (#16044)
  * tests/resource/aws_security_group: Remove hardcoded us-east-1 handling (#16036)
  * tests/resource/aws_instance: Remove hardcoded us-east-1 handling (#16035)
  * tests/data-source/aws_region: Remove hardcoded us-east-1 handling (#16024)
  * tests/resource/aws_datasync_location_smb: Simplify and update base configuration (#15951)
  * Update CHANGELOG.md
  * tests/resource/aws_default_security_group: Remove hardcoded us-east-1 handling (#16026)
  * More alignment fixes.
  * remove extra files
  * networkfirewall support
  * Modified alignment for consistency and readability.
  * Removed unneeded spacing.
  * Removed unneeded spacing.
  * Update aws/resource_aws_backup_vault_policy.go
  * Removed unneeded Default definition.
  * Update aws/resource_aws_spot_fleet_request_test.go
  * Update website/docs/r/autoscaling_group.html.markdown
  * Update aws/resource_aws_ec2_fleet_test.go
  * r/aws_apigatewayv2_stage: Add call to DeleteRouteSettings.
  * Update CHANGELOG.md
  * Update CHANGELOG for #15327
  * r/aws_apigatewayv2_stage: Remove custom set hash function.
  * Updated docs spacing to meet project linter.
  * Uses pre-defined enum slices
  * Updates documentation
  * build(deps): Bump github.com/aws/aws-sdk-go from 1.35.23 to 1.35.25 (#16126)
  * Additional IAM eventual consistency checks.
  * r/aws_kinesis_analytics_application: Use custom lister.
  * r/aws_kinesisanalyticsv2_application: Use generated lister.
  * Run 'make gen'.
  * Generate kinesisanalyticsv2 lister.
  * Skeleton kinesisanalytics lister.
  * r/aws_kinesisanalyticsv2_application: Tidt up sweeper logging.
  * r/aws_kinesisanalyticsv2_application: Minor refactoring to match r/aws_kinesis_analytics_application.
  * r/aws_kinesis_analytics_application: Minor refactoring to match r/aws_kinesisanalyticsv2_application.
  * r/aws_kinesisanalyticsv2_application: Check 'version_id' in 'TestAccAWSKinesisAnalyticsV2Application_Tags'.
  * r/aws_kinesisanalyticsv2_application: No need for callls to 'aws.StringValue()' in 'd.Set()'.
  * r/aws_kinesisanalyticsv2_application: Add and use 'waiter.IAMPropagation'.
  * r/aws_globalaccelerator_endpoint_group: Test 'port_override'.
  * Update CHANGELOG.md for #14535
  * add support for backup vault policy
  * Update error handling
  * tests/provider: Add PreCheck (LightSail)
  * Removes wait functions used only for S3 bucket tests
  * tests/provider: Add PreCheck (MQ)
  * Uses request token to identify stack events
  * r/aws_globalaccelerator_endpoint_group: Add 'port_override' expand and flatten.
  * r/aws_globalaccelerator_endpoint_group: Add 'TestAccAwsGlobalAcceleratorEndpointGroup_MultiRegion'.
  * r/aws_globalaccelerator_endpoint_group: Add and test 'arn' attribute.
  * fix team naming
  * r/aws_globalaccelerator_endpoint_group: Use finder in resource read.
  * docs: Add docs on linting
  * Waiter cleanup
  * Fix tests after feedback
  * Fix more comments
  * Address comments of 2nd feedback round
  * Add TestAccGlueDevEndpoint_disappears
  * Fix and simplify diffArguments func
  * Clean up TestAccGlueDevEndpoint_Arguments
  * Address comments
  * Please the linters
  * Switch to Terraform 0.12 Syntax
  * Switch to Terraform Plugin SDK Version 2
  * Update Glue Dev Endpoint to AWS API changes
  * Add resource aws_glue_dev_endpoint
  * Corrects error message
  * Moves failure reason handling to waiters
  * docs/resource/aws_lightsail_instance: Remove hardcoded blueprints list and add reference to AWS CLI command (#15779)
  * Update CHANGELOG.md
  * Update CHANGELOG for #15567
  * service/ec2: Prevent crash with ENI attachments missing DeviceIndex or AttachmentID (#15567)
  * Update CHANGELOG.md for #15479
  * Sort imports
  * Add configurable timeouts to workspaces
  * docs/resource/aws_lambda_function: Fix cycle error in documentation example (#15551)
  * Update CHANGELOG for #15773
  * resource/aws_cognito_identity_pool: Update name regex and test to comply with AWS Documentation (#15773)
  * Update CHANGELOG for #15927
  * resource/aws_ecs_service: Check for ClusterNotFoundException and remove service from state (#15927)
  * docs/resource/aws_secretsmanager_secret_version: Put import statement into single quotes to make it work (#15709)
  * resource/aws_route53_record: Update error message to be inline with implementation and docs. (#15757)
  * build(deps): bump actions/stale from v1 to v3.0.13 (#15995)
  * build(deps): bump actions/labeler from v2 to v3 (#16043)
  * docs/resource/aws_lb_target_group: Correct health check path reference per 1.7.0 (#16060)
  * tests/provider: Use make gen in CI to fully verify code generation during submissions (#16090)
  * r/aws_globalaccelerator_endpoint_grou: Add finder and use in acceptance tests.
  * r/aws_globalaccelerator_endpoint_group: Add 'port_override' to schema, plus validations.
  * r/aws_globalaccelerator_endpoint_group: Add 'port_override' documentation.
  * Gratify linter
  * Back to quotes
  * Update to Terraform 0.12+ syntax
  * aws_workspaces_bundle: Fix empty (private) owner
  * Fix 'make gen' failure. (#16084)
  * docs/resource/aws_elasticsearch_domain: Size is GiB not GB (#16079)
  * service/sagemaker: fixing typos in aws_sagemaker docs and tests (#16050)
  * build(deps): bump github.com/aws/aws-sdk-go in /awsproviderlint (#16086)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.35.19 to 1.35.23 (#16085)
  * tests/resource/aws_kinesis_firehose_delivery_stream: Remove extraneous comments
  * Added Capacity Rebalance to Spot Fleet
  * Added Capacity Rebalance to EC2 Fleet
  * Added Capacity Rebalance to Auto Scaling Groups
  * resource/aws_kinesis_firehose_delivery_stream: Finalize initial http_endpoint_configuration implementation
  * Rename date validator function
  * Update CHANGELOG for #15356
  * resource/aws_kinesis_firehose_delivery_stream: Add http_endpoint configuration block (#15356)
  * Fix lint issues
- from version 3.14.1
  * Update CHANGELOG for #16075
  * resource/aws_cloudwatch_event_target: Include state upgrade for new default event bus name
    in Read path and only include EventBusName when non-empty in API requests (#16075)
  * Rebase on master and address reviews
  * tests/resource/aws_waf_web_acl: Remove hardcoded environment variable handling (#16045)
  * Support Aurora point-in-time restore
  * Update website/docs/r/storagegateway_nfs_file_share.html.markdown
  * service/s3: Prefix internal error constants with ErrCode and remove multiple service
    imports from aws_s3_bucket_public_access_block (#16068)
  * computed and basic test
  * add file_share_name
  * docs/resource/aws_eks_cluster: Fix example Enabling IAM Roles for Service Accounts (#16001)
  * docs/resource/aws_athena_workgroup: Fix typo (#15987)
  * Adds waiters for CloudFormation Stacks
  * Update CHANGELOG.md to add unreleased version
- from version 3.14.0
  * resource/aws_fsx_lustre_file_system: remove required with for auto policy import (#15600)
  * Update CHANGELOG for #15799
  * docs/contributing: Add service-specific region acceptance testing section (#16039)
  * tests/resource/aws_s3_bucket: Refactor broken TypeSet checking (#15955)
  * tests/resource/aws_spot_datafeed_subscription: Add missing S3 grants
    to configuration and minor refactoring (#15954)
  * Update CHANGELOG for #15949
  * resource/aws_datasync_task: Allow UNAVAILABLE as pending status during creation (#15949)
  * Update CHANGELOG for #15939
  * resource/aws_rds_cluster_instance: Add Cluster Identifier to creation error message (#15939)
  * tests/provider: Check for multiple AWS Go SDK service imports (#15925)
  * Update CHANGELOG for #15922
  * Update CHANGELOG for #15915
  * resource/aws_rds_cluster: Prevent restored cluster recreation with kms_key_id and lack of
    storage_encrypted, add testing and documentation (#15915)
  * fix import issue
  * Update CHANGELOG.md for #14135
  * tests/provider: Add service PreCheck (SimpleDB)
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * added length constraints
  * remove group seperation
  * Update CHANGELOG.md for #8628
  * Apply suggestions from code review
  * Update CHANGELOG.md for #15957
  * improve docs
  * Update CHANGELOG for #16005
  * TF Testing formatting
  * Update CHANGELOG for #14028
  * resource/aws_eip: Add network_border_group attribute (#14028)
  * add catalog id check
  * use %%w for errors + add parameteres
  * More formatting issues with tests
  * Sorted more formatting out hopefully..
  * Improve documentation and add test for EventBridge target input transformer template
  * Update CHANGELOG for #15020
  * Cleanup
  * tests/provider: Fix hardcoded RDS versions
  * validations
  * Update CHANGELOG.md #16017
  * Update CHANGELOG.md for #15948
  * Update CHANGELOG.md for #15956
  * Update CHANGELOG.md for #16006
  * build(deps): bump github.com/terraform-linters/tflint in /tools (#15853)
  * build(deps): bump github.com/bflad/tfproviderlint in /awsproviderlint (#15932)
  * tests/service/rds: Remove hardcoded us-east-1 environment variable handling (#15973)
  * Update CHANGELOG.md for #15793
  * build(deps): bump github.com/hashicorp/terraform-plugin-sdk/v2 (#15997)
  * tests/provider: Fix partition issues (DS AMI)
  * build(deps): bump github.com/golangci/golangci-lint in /tools (#16000)
  * build(deps): bump github.com/hashicorp/terraform-plugin-sdk/v2 (#15999)
  * Update CHANGELOG for #15938
  * service/rds: Additional error handling for Global Clusters, test fixes for engine versions (#15938)
  * Update CHANGELOG.md for #15934
  * r/aws_apigatewayv2_integration: Different range of valid values and defaults
    for 'timeout_milliseconds' between HTTP and WebSocket APIs.
  * Hack to overcome data source with depends_on refresh
  * Gratify linter
  * Back to quotes
  * Update plugin SDK v2 & Terraform 0.12+ syntax
  * Fix RunningMode ALWAYS_ON and RunningModeAutoStopTimeoutInMinutes attributes collision
  * New data source: aws_workspaces_workspace
  * r/aws_storagegateway_smb_file_share: Add `file_share_name` argument
  * MAXITEMS
  * Apply suggestions from code review
  * Use 'test.%%[2]d.arn' over 'test.%%[2]d.arn' to please terrafmt.
  * Update aws/resource_aws_sagemaker_model_test.go
  * add tags
  * r/aws_kinesis_analytics_application: Update GH organization (#15859).
  * r/aws_kinesis_analytics_application: Tidy up.
  * r/aws_kinesis_analytics_application: Multiple updates test.
  * r/aws_kinesis_analytics_application: Input processing configuration tests.
  * r/aws_kinesis_analytics_application: Input tests.
  * r/aws_kinesis_analytics_application: Output tests.
  * r/aws_kinesis_analytics_application: Reference data source tests.
  * r/aws_kinesis_analytics_application: CloudWatch logging options tests.
  * r/aws_kinesis_analytics_application: Standard tags test.
  * r/aws_kinesis_analytics_application: Start to correct resource update.
  * r/aws_kinesis_analytics_application: Simplify resource creation. Add '_disappears' test (#13826).
  * r/aws_kinesis_analytics_application: Additional attribute validations.
  * r/aws_kinesis_analytics_application: Use internal 'waiters' package on deletion (#13280).
  * Missed id change in docs
  * Changes after review
  * Add aws_codestarconnections_connection resource
  * Adds `waiter` function for CloudFormation Stack Set operations
  * Update CHANGELOG.md
  * tests/provider: Update docs to avoid hardcoded endpoints ID
  * tests/provider: Fix hardcoded endpoint ID (wafregional)
  * tests/provider: Fix hardcoded endpoint ID (WAF)
  * tests/provider: Fix hardcoded endpoint ID (OpsWorks)
  * Adds support for CAPABILITY_RESOURCE_POLICY capability
  * tests/provider: Fix hardcoded endpoint ID (models.lex)
  * tests/provider: Fix hardcoded endpoint ID (fsx)
  * tests/provider: Fix hardcoded endpoint ID (codestar)
  * tests/provider: Fix hardcoded endpoint ID (CodeArtifact)
  * tests/provider: Fix hardcoded endpoints ID (cloudfront)
  * tests/provider: Fix hardcoded endpoint ID (cloud9)
  * tests/provider: Fix hardcoded endpoints ID (budgets)
  * tests/provider: Fix hardcoded endpoint ID (appsync)
  * tests/provider: Standardize remaining alternate provider testing and refactor
    testAccProviderFactories for broad usage (#15904)
  * build(deps): bump github.com/aws/aws-sdk-go in /awsproviderlint (#15962)
  * build(deps): bump github.com/aws/aws-sdk-go from 1.35.9 to 1.35.19 (#15964)
  * build(deps): bump github.com/golangci/golangci-lint in /tools (#15963)
  * provider: Add CodeStar Connections service client (#15960)
  * fix last weeks url ref additions
  * code review suggestions
  * remove slack notifier behavior
  * missed url references
  * move inheritied hashibot behaviors
  * a couple more moves
  * search replace to move links to new org
  * add disappears test
  * add image config test
  * refactor tests
  * add image config
  * use sagemaker datasource
  * variable assignment
  * Apply suggestions from code review
  * test fmt + check
  * use test instead of foo
  * tags test
  * validate more specific error on read + remove commented out code + tests
  * fix resource naming
  * add plan time validation for `instance_type` and `accelerator_type`
  * extraneous space
  * use shorthand validation logic
  * correct bucket reference
  * test refactor
  * refactor tests
  * change docs
  * comments
  * Add data capture config to Sagemaker endpoint configuration
  * plan time validations + read after create
  * remove validation func
  * Adds `required_capabilities` to Serverless Application Repository application data source
  * quote symbol really optional
  * linter: Clean up imports and add import linter
  * Update CHANGELOG.md
  * Adds tagging for PRs
  * Update CHANGELOG for #11685
  * ds/sagemaker_prebuilt_image_path: New data source
  * make markdown linter happy
  * changes to make md checker happy
  * remove error for targets
  * add support for mongodb target
  * add mongodb target
  * Adds tagging for EventBridge for aws_cloudwatch_event_* resources
- from version 3.13.0
  * Update CHANGELOG for #14345
  * Update CHANGELOG for #15121
  * Removes unused functions
  * Adds custom event bus support to EventBridge permission resource
  * Updates category name
  * docs/provider: Adjust Attribute Reference headings to Attributes Reference for consistency (#15845)
  * Update CHANGELOG for #15916
  * resource/aws_rds_global_cluster: Prevent recreation when using encrypted
    source_db_cluster_identifier without storage_encrypted (#15916)
  * Update CHANGELOG.md for #15809
  * Changes category and updates documentation
  * Capitalize Core Services
  * Apply suggestions from code review
  * Update CHANGELOG for #15896
  * provider: Stabilization of remaining data source id attributes and
    enable R015, R016, R017 linters (#15896)
  * Update CHANGELOG.md for #15894
  * use right func
  * use short name
  * Update aws/internal/service/sagemaker/finder/finder.go
  * add notebook instance example in docs
  * add sagemaker instance test for repo resource
  * Update CHANGELOG.md for #15370
  * use correct input
  * use correct package
  * extract code repo finder func to separate package
  * add validation to name
  * no need for err check for simple type
  * no need for err chcek for simple type
  * Apply suggestions from code review
  * update secret test
  * add examples to docs
  * add test for branch and secret
  *  add sagemaker code repository
  * Update CHANGELOG.md for #15830
  * Update CHANGELOG for #3485
  * add argument to list of args to ignore on import
  * update to using the aws go sdk's wait until stable function
  * tests/provider: Add precheck (KinesisVideo)
  * r/aws_apigatewayv2_integration: Simplify Lambda acceptance test configuration.
  * fix delete check
  * Apply suggestions from code review
  * handle error in list
  * add retention test
  * docs
  * basic test
  * add default values
  * tape pool resource
  * add `block_public_policy`
  * add `block_public_policy`
  * use v2 + validation
  * use iam waiter
  * ammend sweeper
  * add secret manager secret policy
  * Update CHANGELOG for #12126
  * resource/aws_vpc_peering_connection_options: Only modify VPC Peering options that have actually changed (#12126)
  * Clean-up imports
  * remove org change
  * add q4 roadmap, add elasticache as core service
  * tests/provider: Migrate additional tests to newer ProviderFactories
    setup and PreCheck functions (#15877)
  * Update CHANGELOG for #15725
  * data-source/aws_kms_secrets: Ensure the ID is deterministic (#15725)
  * r/aws_apigatewayv2_integration: Specify required parameters on update.
  * tests/provider: Enable AWSAT005
  * build(deps): bump github.com/golangci/golangci-lint in /tools (#15852)
  * Doc Changes
  * tests/provider: Add prechecks (AppMesh)
  * tests/provider: Fix hardcoded ARN (ds/iam_policy_doc)
  * tests/provider: Fix hardcoded ARN (DB*)
  * tests/provider: Add precheck (WAFv2)
  * Update CHANGELOG for #15604
  * New Resource: aws_s3control_bucket_lifecycle_configuration (#15604)
  * tests/provider: Fix hardcoded (DS CUR)
  * build(deps): bump github.com/hashicorp/terraform-plugin-sdk/v2 (#15878)
  * Contribution guideline changes
  * tests/provider: Initial migration from hardcoded regions and shared environment
    variable overwrite (CUR and EC2-Classic) (#15803)
  * tests/provider: Add precheck (WAFRegional)
  * Fixes documentation errors
  * tests/provider: Add precheck (WAF data sources)
  * tests/provider: Increase unit testing timeout from 2 to 5 minutes (#15864)
  * Update CHANGELOG for #15621
  * resource/aws_s3_access_point: Support S3 on Outposts (#15621)
  * Update CHANGELOG for #15585
  * New Resource: aws_s3outposts_endpoint (#15585)
  * tests/provider: Add precheck (SES Receipt)
  * tests/provider: Fix hardcoded canoncial (EC2 Traffic Mirror)
  * Update CHANGELOG for #15575
  * New Resource: aws_s3control_bucket_policy (#15575)
  * tests/service/wafv2: Implement sweepers (#15860)
  * Update CHANGELOG for $15727
  * Fixes terraform formatting
  * Update CHANGELOG for #15510
  * New Resource: aws_s3control_bucket (#15510)
  * build(deps): bump github.com/bflad/tfproviderdocs in /tools (#15854)
  * Removes check for schedule_expression in non-default bus
  * add docs + set max items
  * add support for `additional_code_repositories`
  * Documentation: On Demand Percentage Default
  * tests/resource/aws_iam_group: Prevent sweeper error with user membership in group (#15714)
  * docs/providers: Fix resource types in titles and import sections (#15843)
  * deps: Replace renovate configuration with dependabot (#15846)
  * Update CHANGELOG for #15802
  * resource/sagemaker_notebook_instance: Add `url` and `network_interface_id` attributes (#15802)
  * Update CHANGELOG for #15371
  * resource/aws_sagemaker_model: Add container configuration block mode attribute (#15371)
  * Refactor using HasChanges
  * Fix and make tests consistent for aws_s3_bucket_object
  * Fix stale version_id on aws_s3_bucket_object
  * Adds overridden version of terramt to tools modules
  * update to using github-script action for triage labeling
  * added length constraints to docs
  * Data source for Route53 Resolver endpoint
  * Adds documentation for generating paginated functions
  * tests/provider: Add precheck (GlobalAccelerator)
  * tests/provider: Add precheck (CB Report Group)
  * tests/provider: Add precheck (DataSync FSx)
  * tests/provider: Add prechecks (CodeArtifact)
  * tests/provider: Add prechecks (OpsWorks)
  * add new linter label
  * Moves target finder and lister functions to service package
  * Update resource_aws_api_gateway_usage_plan.go
  * Update CHANGELOG.md for #10361
  * Update resource_aws_api_gateway_usage_plan.go
- from version 3.12.0
  * refactor tests config to use composeconfig
  * use %%w for errors
  * move waiters to glue package
  * enum slicer
  * Adds test for import without event bus name
  * Fixes missed test
  * Added the aws resource glue resource policy
  * ad disappears test
  * use enum slices
  * Update CHANGELOG for #15789
  * New Data Source: aws_rds_certificate (#15789)
  * revise response time policy
  * Update CHANGELOG.md for #15705
  * Update CHANGELOG.md for #15385
  * add sec config test
  * add notify test
  * name validation + use acctest for generated test name
  * add notification property
  * add security config to action
  * Apply suggestions from code review
  * Adds test for import without BusName
  * tests/provider: Fix hardcoded ARN (Route53)
  * Update CHANGELOG.md for #15569
  * Handles custom event buses
  * tests/msk_cluster: Fix revision test
  * Update CHANGELOG.md for #15687
  * Update CHANGELOG.md for #11652
  * tests/provider: Fix hardcoded ARN (CUR Report)
  * Update CHANGELOG.md for #12027
  * fix formatting issue
  * Update CHANGELOG.md for #13618
  * Update CHANGELOG.md for #15127
  * Update CHANGELOG.md for #12523
  * Update CHANGELOG for #8965
  * tests/provider: Fix hardcoded ARN (Flow Log)
  * Update aws/internal/service/autoscalingplans/finder/finder.go
  * Cleanup
  * Adds `ConflictsWith` validation to `input`, `input_path`, and `input_transformer`.
  * Clean up tests
  * Use 'StateChangeConf.Delay' to better handle API eventual consistency issues.
  * Update CHANGELOG for #15641
  * Update CHANGELOG for #15669
  * tests/provider: Fix hardcoded ARN (EMR*)
  * remove igw
  * fix waiter
  * tests/provider: Fix hardcoded ARN (Shield Protection)
  * tests/provider: Fix hardcoded ARN (WAFv2 Web ACL)
  * tests/provider: Fix hardcoded ARN (Transfer User)
  * tests/provider: Fix hardcoded ARN (S3)
  * tests/provider: Fix hardcoded ARN (Pinpoint App)
  * tests/provider: Fix hardcoded ARN (Organizations)
  * tests/provider: Fix hardcoded ARN (Media Store*)
  * tests/provider: Fix hardcoded ARN (IOT Topic)
  * tests/resource/aws_iam_user_login_profile: Ensure testDecryptPasswordAndTest
    honors current testing region (#15697)
  * tests/provider: Fix hardcoded ARN (GuardDuty)
  * tests/provider: Fix hardcoded ARN (Glue*)
  * tests/provider: Fix hardcoded ARN (GameLift)
  * use t3 instance for tests
  * add igw
  * update volume fix
  * really fix volume config
  * recreate instance for volume size to smaller size
  * fix volume test config
  * allow updating default code repo
  * refactor to be uniform with other tests
  * fix subnet check
  * fix tags test - the last one!
  * lifecycle config remove test fix tags test add kms test add more checks
  * lifecycle config remove test fix tags test add kms test add more checks
  * standardize tags test remove custom check funcs and replace with regular attribute checks
  * move some waiters to their own package add validation to `role_arn`, `instance_type`
  * Tagging on PUT only works when creating a rule
  * Uses IAM propagation timeout
  * Handles custom event buses
  * tests/provider: Fix hardcoded ARN (Cognito)
  * Remove extra if
  * tests/provider: Fix hardcoded ARN (CloudWatch Log Res Pol)
  * add specific message for first time contributors
  * tests/provider: Fix hardcoded ARN (CodeDeploy Dep Group)
  * Add test for removing tags
  * Adds `AtLeastOneOf` validation to `schedule_expression` and `event_pattern`
  * tests/provider: Fix hardcoded ARN (Cloud*)
  * tests/provider: Fix hardcoded (Lambda Perm)
  * Add 'testAccPreCheckIamServiceLinkedRole' and use for scaling plans with predictive scaling.
  * Update website/docs/r/autoscalingplans_scaling_plan.html.markdown
  * Add documentation note about service-linked role.
  * Consider workspace terminated only after directory metadata cleanup
  * add wait for restoring
  * add waiter
  * test config name + lint
  * test config name
  * depend on working storage
  * remove volume_arn test
  * remove volume_arn
  * order resources
  * fix test config to pass tests
  * tags ignore on read
  * zero tags check for basic test
  * refactor disappears test
  * refactor tests
  * tf 12 syntax for tests
  * use %%w for errors
  * add required with for kms key
  * fix sdk v2
  * docs tf 12
  * sdk v2
  * add disappearing test case
  * edit docs
  * change tests + add docs
  * add storagegateway stored iscsi volume resource
  * Update website/docs/r/codeartifact_repository.html.markdown
  * tests/provider: Lint ignore hardcoded ARN
  * tests/provider: Fix hardcoded ARN (CloudTrail)
  * fixed formatting
  * added expecterror to validation test
  * renamed validator functions
  * Properly handle `name` and `name_prefix`
  * modified pull_requests file to include new comment on new pr
  * Clean up tests
  * tests/provider: Fix hardcoded (S resources)
  * add persistent type for copy tags to backups
  * fix test name
  * Add copy_tags_to_backups to aws_fsx_lustre_file_system
  * tests/provider: Fix hardcoded ARN (Sagemaker Model)
  * Update CHANGELOG for #12281
  * resource/aws_network_interface: Read after create and add support for IPv6 (#12281)
  * Update module hashicorp/aws-sdk-go-base to v0.7.0 (#15517)
  * Update Terraform github to v3.1.0 (#15601)
  * Add ewbankkit as Service Maintainer for kinesisanalytics(v2).
  * r/aws_autoscalingplans_scaling_plan: Better handling of eventual
    consistency when waiting for creation and deletion.
  * Update module aws/aws-sdk-go to v1.35.9 (#15500)
  * tests/provider: Fix hardcoded ARN (IAM)
  * Update CHANGELOG for #10256
  * tests/provider: Fix hardcoded ARN (ACMPCA Cert Auth)
  * tests/provider: Fix hardcoded (ECS task def)
  * r/aws_autoscalingplans_scaling_plan: Use '_Values()' (#14601).
  * tests/provider: Fix hardcoded ARNs (data sources)
  * Removes `dorny/paths-filter`
  * tests/provider: Lint ignore hardcoded (StorageGateway)
  * tests/provider: Fix hardcoded ARN (Kinesis)
  * tests/provider: Fix hardcoded ARN (LB)
  * tests/provider: Fix hardcoded ARN (securityhub)
  * added validation to input_paths
  * tests/provider: Fix hardcoded ARN (Config)
  * Updates documentation
  * tests/provider: Fix hardcoded ARN (CloudWatch Event Target)
  * Adds tag support
  * tests/provider: Fix hardcoded ARN (provider)
  * max backup_retention_days increased from 35 to 90
  * Clean up
  * remove computed + add docs
  * add computed and max items
  * conn name is require and add validation to domain owner
  * add support for external connection
  * Adds use of generated ListTargetsByRulePages() function
  * tests/provider: Fix hardcoded (EKS Cluster)
  * add merged prs and linked issues to current milestone
  * Uses generator to create missing List...Pages() functions
  * Fix markdown-lint errors.
  * Fix 'Warning: List items should be accessed using square brackets
    (terraform_deprecated_index)' and terrafmt warnings."
  * fsx - updated max retention days from 35 to 90
  * Fix golangci-lint errors.
  * lb_target_group: Allow invalid stickiness config, avoid breaking change
  * tests/provider: Fix hardcoded (EMR Cluster)
  * Update plan output to reflect publish(version, qualified_arn) when config changes
  * f/aws_elasticache_cluster: Support final snapshot
  * f/aws_elasticache_cluster: Support final snapshot
  * f/aws_elasticache_cluster: Support final snapshot
  * f/aws_elasticache_cluster: Support final snapshot
  * f/aws_elasticache_cluster: Support final snapshot
  * tests/provider: Add precheck (Lex)
  * f/aws_fsx_windows_file_system: allow updating storage and throughout capacity without recreation of resource
  * f/aws_fsx_windows_file_system: allow updating storage and throughout capacity without recreation of resource
  * f/aws_fsx_windows_file_system: allow updating storage and throughout capacity without recreation of resource
  * f/aws_fsx_windows_file_system: allow updating storage and throughout capacity without recreation of resource
  * f/aws_fsx_windows_file_system: allow updating storage and throughout capacity without recreation of resource
  * f/aws_fsx_windows_file_system: allow updating storage and throughout capacity without recreation of resource
  * r/aws_kinesisanalyticsv2_application: Move some code around.
  * r/aws_kinesisanalyticsv2_application: Add documentation examples.
  * Add documentation notes on usage of r/aws_kinesis_analytics_application vs. r/aws_kinesisanalyticsv2_application.
  * r/aws_kinesis_analytics_application: Change documentation sub-category.
  * Modify documentation sub-category to reflect recent product repositioning.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_VPCConfiguration_Update'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_VPCConfiguration_Delete'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_VPCConfiguration_Add'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_FlinkApplicationConfiguration_EnvironmentProperties_Update'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_Multiple_Update'.
  * r/aws_kinesisanalyticsv2_application: Reorder tests.
  * Remove unused code.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_Output_Update'.
  * added acctest, added minitems to list
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_ReferenceDataSource_Delete'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_ReferenceDataSource_Add'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_ReferenceDataSource_Update'.
  * Move TimedOut check inside 'kinesisAnalyticsV2RetryIAMEventualConsistency'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_InputProcessingConfiguration_Delete'.
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_InputProcessingConfiguration_Add'.
  * fixed indentation
  * fixed conditional set within Read function
  * added network_config
  * r/aws_kinesisanalyticsv2_application:
    Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_InputProcessingConfiguration_Update'.
  * tests/provider: Add precheck (appsync)
  * Add TLS config to apigw integration
  * Add TLS config to apigw integration
  * r/aws_kinesisanalyticsv2_application: Add 'TestAccAWSKinesisAnalyticsV2Application_SQLApplicationConfiguration_Input_Add'.
  * r/aws_kinesisanalyticsv2_application: Handle 'sql_application_configuration.input' updates.
  * r/aws_kinesisanalyticsv2_application: Handle 'environment_properties' updates.
  * r/aws_kinesisanalyticsv2_application: Handle 'flink_application_configuration' updates.
  * r/aws_kinesisanalyticsv2_application: Handle 'application_snapshot_configuration' updates.
  * r/aws_kinesisanalyticsv2_application: Handle 'application_code_configuration' updates.
  * r/aws_kinesisanalyticsv2_application: Handle 'cloudwatch_logging_options' updates.
  * r/aws_kinesisanalyticsv2_application: Make 'application_configuration' computed.
  * r/aws_kinesisanalyticsv2_application: Fix 'TestAccAWSKinesisAnalyticsV2Application_UpdateServiceExecutionRole'.
  * r/aws_kinesisanalyticsv2_application: Standardize tags tests.
  * r/aws_kinesisanalyticsv2_application: Update 'service_execution_role'.
  * r/aws_kinesisanalyticsv2_application: Add a true 'Basic' configuration.
  * r/aws_kinesisanalyticsv2_application: Call Read after Create, not Update.
  * r/aws_kinesisanalyticsv2_application: Start to add documentation.
  * r/aws_kinesisanalyticsv2_application: Tidy up acceptance tests.
  * r/aws_kinesisanalyticsv2_application: Add test sweeper.
  * r/aws_kinesisanalyticsv2_application: Add and use internal 'waiter' package.
  * r/aws_kinesisanalyticsv2_application: Add and use internal 'finder' package.
  * r/aws_kinesisanalyticsv2_application: Remove 'testAccCheckKinesisAnalyticsV2ApplicationDisappears' (#13527).
  * r/aws_kinesisanalyticsv2_application: 'resName' -> 'resourceName'.
  * r/aws_kinesisanalyticsv2_application: 'aws_kinesis_analyticsv2_application' -> 'aws_kinesisanalyticsv2_application'.
  * r/aws_kinesisanalyticsv2_application: Rename source files.
  * fix: add validation checks for aws_glue_catalog_table resource properties
  * add validator for s3 bucket acl
  * add in currently documented s3 bucket canned acls to validator
  * fix destroy check
  * use enum slice
  * update test
  * tf12 syntax
  * extra checks for basic test
  * change api_stages to set extract lists/set expansion to functions move
    usage plan flattners to usage plan file refactor tests
  * Clean up assertion of set contents
  * Unsetting ser_de_info.name from aws_glue_catalog_table results in error
  * add validations
  * disappears test use aws value funcs
  * refactor tests
  * refactor error add plan time validation to `arn`, `role_arn`,
    `launch_type`, `task_definition_arn` refactor tests
  * r/aws_lambda_function: Update 'version' and 'qualified_arn' on publish
  * Remove inconsistent error handling
  * fix %%w for log
  * fix rename
  * use enum list
  * rename `recovery_mechanisms` to `recovery_mechanism`
  * rename `recovery_mechanisms` to `recovery_mechanism`
  * arn arn from read output instead of constructing it refactor tests
  * use %%w for errors in tests
  * use %%w for errors
  * add support for account recovery settings
  * Upgrade to Plugin SDK v2 and use Terraform 0.12 syntax in documentation.
  * Use 'tfawsresource' acceptance test checkers.
  * Use 'testAccAvailableEc2InstanceTypeForRegion', not 'testAccAvailableEc2InstanceTypeForAvailabilityZone'.
  * r/aws_autoscalingplans_scaling_plan: Remove custom set hash functions.
  * Simplify acceptance tests a bit.
  * Add 'internal/service/autoscalingplans/waiter' package.
  * Use 'go-multierror' in test sweeper.
  * Remove 'sidebar_current'.
  * Replace 'validateStringDoesNotContainAny' with 'validation.StringDoesNotContainAny'.
  * Add 'subcategory'.
  * Terraform Plugin SDK migration.
  * Add 'aws_autoscalingplans_scaling_plan' resource.
  * resource/aws_autoscaling_group: fix typos in test comments
  * resource/aws_autoscaling_group: add instance_refresh block
  * Adding test for multi fargate profile serialization.
  * Removing retry based code, adding in mutex locking instead.
  * added `operation_name` attribute to API G. method
  * Fixing formatting
  * Fix for issue #13538
  * Fix linter errors
  * Convert length one sets to lists (fix linter S018 warnings)
  * Namespace hash functions to kinesisanalyticsv2 application
  * Remove debugging print statements
  * Use composeConfig for combining test configs
  * Add test for application disappears
  * Fix remaining tests
  * Fix another test
  * Fix another test
  * Fix another test
  * Fix more tests. Fix issue with code config update not applied
  * Continue revising schema and patching up tests
  * Continue revising schema
  * Continue revising schema
  * Avoid empty kms_arn * If logs and/or bookmark encryption are DISABLED, don't send these fields empty to the API call
  * fix fmt
  * Fix updating
  * Continue revising schema
  * Continue work on schema revisions
  * Continue work on schema revisions
  * Continue schema revisions
  * Continue work on schema revisions
  * Add feature to concurrently update/del AWS API Gateway method settings
  * Begin work to revise schema to more closely match AWS API
  * Fix metrics level validation
  * Simplify validators with StringInSlice
  * Namespace kinesisanalyticsv2 validation functions
  * Use TypeSet instead of TypeMap for Flink's checkpoint_configuration, monitoring_configuration, and parallelism_configuration
  * Finish renaming aws_kinesis_analytics_application_v2 to aws_kinesis_analyticsv2_application
  * Rename KinesisAnalyticsApplicationV2 -> KinesisAnalyticsV2Application
  * Add event_bus_name attribute to aws_cloudwatch_event_rule
  * Add event_bus_name attribute to aws_cloudwatch_event_target
  * Fix reference to v2 test config
  * fix website formatting
  * d/aws_api_gateway_domain_name: Add API Gateway Custom Domain lookup
  * Split kinesis analytics application created with v2 API into separate resource
  * Add resource aws_cloudwatch_event_bus
  * Simplify return statement
  * Handle computed diffs better by using computed for map schemas
  * Fix flink config expansion so empty values are not expanded
  * Separate logic from excessively long function into other functions
  * Remove ineffectual assignment
  * Use existing utility function for runtime comparison
  * Populate empty application config at read time
  * Fix some tests
  * Continue refactoring for more AWS-like schema
  * fixing merge problem
  * Begin reworking schema to make more semantically similar to AWS API
  * Add support for property groups
  * Add test for kinesisanalytics configuration type validation
  * Remove unnecessary type conversion
  * Add tests for new validators
  * Add optional S3 object version to schema
  * Add validation for log level
  * Add validation for configuration type and metrics level
  * Fix bug updating Flink appplications. Add update test
  * Fix import for Flink application resources. Cover more with test
  * Set cloudwatch logging option updates in update application options
  * Fix update
  * Fix test config issues
  * Fix version being incremented when no changes occurred
  * Fix more tests
  * Continue work on testing kinesisanalyticsv2 provider
  * Test monitoring and parallelism
  * Add parallelism config
  * Add monitoring config
  * Start fleshing out create logic
  * Begin adding tests for flink application provisioning
  * Make more fixes for differing runtimes
  * Fix some differences with SQL and Flink runtime configs
  * Add skeleton for Flink configuration
  * Begin adding support for Flink runtime with KDA
  * Add required field for service execution role
  * Update usage of kinesisanalytics packge to kinesisanalyticsv2
  * Fix format
  * Fix format
  * Add mutex and retry for usage plan key
  * Fixes typo in function name
  * Renames tests for `aws_serverlessrepository_stack`
  * Adds documentation for `aws_serverlessrepository_stack`
  * Renames the resource to `aws_serverlessrepository_stack`
  * Updates AWS region used to the default `us-west-2`
  * Creates and updates tags
  * Fixes linting error
  * Add a test for reading tags
  * Added tags to Read operation
  * Added Update to serverless application
  * Revert "Factored waiting for execution of CloudFormation change
    set to separate function; will be reused for Update"
  * Factored waiting for execution of CloudFormation change set to
    separate function; will be reused for Update
  * Moved status check into function as well
  * Factored waiting for creation of CloudFormation change set to separate
    function; will be reused for Update
  * Added CloudFormation `capabilities` field as output; needed for update
  * Added outputs to serverless repo application
  * Formatting changes
  * Added parameter tests for basic case
  * Added test for changing application version
  * Added version parameter as output and optional input
  * Added basic creation, reading, and deletion of a Serveless Repo Application
  * Added documentation
  * Added version parameter for Serverless Application Repo application data source
  * Handle non-existent applications in the repo
  * Created happy path latest version Serverless Repo data source
  * Add reader_endpoint_address to aws_elasticache_replication_group
  * openAPI body's basePath import options
  * remark on existing local cache for README
* Wed Nov 11 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add symbolic link to comply with new filesystem layout for local provider copies
* Mon Oct 19 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Define and use common Go spec file variables
- Enable Go vendoring
- Update to version 3.11.0:
  * documentation: Add PreCheck docs
  * Removes `TF_PLUGIN_CACHE_DIR`
  * Update CHANGELOG.md for #15638
  * Update CHANGELOG.md for 15341
  * r/aws_appmesh_gateway_route: New resource.
  * tests/provider: Fix AMI failures (Launch Config)
  * tests/provider: Fix formatting (sagemaker notebook)
  * better wording as suggested
  * Update CHANGELOG.md for #15611
  * Update CHANGELOG.md for #15521
  * Update CHANGELOG.md for #14577
  * better workflow name
  * add newline
  * add automation to move maintainer PR's into the review column
  * Update CHANGELOG for #13772
  * Fix small typo on 'Usage with prefix list' section
  * Update website/docs/r/apigatewayv2_route.html.markdown aws_apigatewayv2_route documentation
  * add non-managed TF tags
  * add tags for current upcoming TF versions
  * docs/resources/wafv2_web_acl: provide a link to the AWS WAF managed rules group names
  * r/aws_appmesh_virtual_gateway: Add examples to documentation.
  * docs/resource/aws_backup_vault: Fix typo in backup vault notifications (#15570)
  * r/aws_appmesh_virtual_gateway: New resource.
  * tests/provider: Enable semgrep resource.Retry verification for resource.TimeoutError handling (#15530)
  * f/aws_sagemaker_notebook_instance: Volume size
  * tests/resource/aws_db_proxy_default_target_group: Check disappearance with DB Proxy removal since default Target Group cannot be removed (#15546)
  * tests/resource/aws_opsworks_application: Fix ImportStateVerifyIgnore for TestAccAWSOpsworksApplication_basic (#15547)
  * tests/resource/aws_elastic_transcoder_preset: Adjust ImportStateVerifyIgnore handling in TestAccAWSElasticTranscoderPreset_AudioCodecOptions_empty (#15542)
  * tests/resource/aws_elasticsearch_domain: Add missing ImportStateVerifyIgnore to TestAccAWSElasticSearchDomain_LogPublishingOptions_AuditLogs (#15543)
  * New Service Client: s3outposts (#15468)
  * f/aws_sagemaker_notebook_instance: Volume size
  * Gratify terrafmt
  * Back to disabled workdocs
  * Back to disabled self-service permissions
  * Add note about workdocs site
  * Back to quotes
  * [aws_workspace_directory] Add workspace_creation_properties
  * Update module terraform-linters/tflint to v0.20.2
  * Updates `terrafmt` dependency and uses tools version for website/validate-terraform workflow
  * Update CHANGELOG.md for #15566
  * Update CHANGELOG for #14846
  * Adds some test cases to TestCanonicalCidrBlock
  * Renames some validator tests
  * Cleanup after v3.10.0 release
- from version 3.10.0
  * Update CHANGELOG.md
  * Add stickiness fixes
  * Update CHANGELOG.md for #14361
  * lint
  * docs
  * add codeartifact repo endpoint data source
  * Update CHANGELOG.md for #15562
  * Update CHANGELOG for #15263
  * Update CHANGELOG for #15467
  * Update CHANGELOG for #15482
  * Update website/docs/r/codeartifact_repository_permissions_policy.html.markdown
  * Update CHANGELOG for #15537
  * Update CHANGELOG for #15538
  * Update CHANGELOG for #15548
  * Update CHANGELOG.md for #15425
  * docs + fox test
  * fix read repo name
  * fix arn compare
  * lint
  * rebase
  * add repo permissions policy resource
  * add support for code artifact repository
  * Update codeartifact_authorization_token.html.markdown
  * Apply suggestions from code review
  * f/aws_sagemaker_notebook_instance: Volume size
  * corrected example from .id to .arn
  * Restore invalidThreshold test config
  * Remove unecessary stickiness block from TCP tests
  * Override AWS plugin for examples
  * Update aws/resource_aws_s3_bucket_ownership_controls.go
  * Update CHANGELOG for #15470
  * service/batch: Support resource tagging and prevent differences with new secrets support in container properties (#15470)
  * Enables Organizations policy import AWS-managed acceptance test
  * Update CHANGELOG for #15457
  * resource/aws_ecs_cluster: Retry CreateCluster for IAM Service Linked Role eventual consistency (#15457)
  * Update CHANGELOG.md
  * Update CHANGELOG for #15541
  * resource/aws_emr_managed_scaling_policy: Ensure cluster_id attribute is saved during import and handle additional disappears cases (#15541)
  * Adds go.mod to path triggers for examples and website workflows
  * Update CHANGELOG for #15529
  * resource/aws_s3_bucket_analytics_configuration: Check resource.TimeoutError on deletion (#15529)
  * Update CHANGELOG for #15527
  * service/lex: Check resource.TimeoutError on creation (#15527)
  * Update CHANGELOG for #15526
  * resource/aws_gamelift_fleet: Check resource.TimeoutError on creation (#15526)
  * Update CHANGELOG for #15524
  * resource/aws_config_remediation_configuration: Check resource.TimeoutError on deletion (#15524)
  * Update CHANGELOG for #15523
  * resource/aws_codestarnotifications_notification_rule: Check for resource.TimeoutError on target deletion (#15523)
  * Update CHANGELOG for #15522
  * resource/aws_acm_certificate: Check for resource.TimeoutError on deletion (#15522)
  * Adapt test for cross regions
  * Update CHANGELOG for #15438
  * New Data Source: aws_redshift_orderable_cluster (#15438)
  * resource/aws_emr_instance_fleet: Prevent error on deletion when EMR Cluster is no longer running
  * infrastructure/repository: Add service labels for appflow, s3outposts, timestreamwrite (#15431)
  * Add tests for stickiness with NLB protocols
  * Set default stickiness type for NLB protocols
  * Apply suggestions from code review
  * No need to re-run formatting if validation script changes
  * alphabetical sort structures, docs, tests and set
  * resource/aws_glue_workflow: Ensure max_concurrent_runs attribute is saved during import
  * service/rds: Increase default proxy deletion timeout, ensure proxy target import includes all attributes
  * Update module hashicorp/terraform-plugin-sdk/v2 to v2.0.4 (#15531)
  * Update CHANGELOG for #15446
  * Update .gitignore
  * Adds file path conditional checks for acceptance tests linters
  * Clarifies need to use `ignore_changes` when using `aws_autoscaling_attachment` resources with `aws_autoscaling_group`
  * Update CHANGELOG for #14154
  * data-source/aws_s3_bucket_object: Prevent crash when S3 HeadObject returns empty response (#14154)
  * docs/provider: Document usage of internally defined AWS API error codes (#15516)
  * docs/provider: Update Resource Contribution Guidelines to remove automatically checked issues
  * docs/resource/aws_cloudfront_distribution: Updated web_acl_id description (#15511)
  * Update CHANGELOG for #12013
  * service/s3: Correctly handle ignored tags for S3 Bucket and Object resources (#12013)
  * Add support for stickiness for NLBs
  * Address review comments
  * Update CHANGELOG for #8919
  * More serialization
  * Handles IAM eventual consistency, validates log settings, and adds `resource_prefix` to log settings
  * Serialize acceptance tests with Bot version publishing
  * Check proper stickiness usage in create LB TG
  * Clarify stickiness usage in documentation
  * Consolidates Lex Bot field validations
  * tests/provider: Add precheck (CloudFront)
  * tests/provider: Add precheck (Cloud9)
  * tests/provider: Add prechecks (budgets)
  * examples/sagemaker: Change "upload to ECS" to "upload to ECR" (#15502)
  * tests/provider: Add prechecks (AppMesh)
  * Typo in Lex Intent docs (#15478)
  * tests/provider: Add precheck (CodeStar Notifications)
  * .github/workflows: Ignore Renovate pull requests for needs-triage labeling (#15488)
  * docs/provider: Update Contributing Guide PR checklist to use `aws-sdk-go-base/tfawserr` and `internal/tfresource` helpers (#15494)
  * tests/provider: Add precheck (CodeArtifact)
  * Updated CHANGELOG for #15399
  * provider: Stabilization of singular data source id attributes with clear identifiers (#15399)
  * Add and use 'internal/tfresource' package. (#15477)
  * docs/resource/aws_lb: Fixed incorrect subnet example (#15475)
  * provider: Use `aws-sdk-go-base/tfawserr` in internal packages (#13036)
  * Update module bflad/tfproviderlint to v0.19.0 (#15485)
  * Update documentation
  * provider: Fix and prevent additional occurrences of extraneous conditionals after (helper/schema.ResourceData).GetOk() receiver method
  * New Resource: aws_s3_bucket_ownership_controls
  * split tests, add missing attributes and update documentation
  * data-source/aws_vpc_endpoint_service: Accept service_type as argument
  * docs/provider: Typo fixes (#15464)
  * Minor documentation updates to fix links and paragraph formatting
  * resource/aws_backup_plan: Add support for AdvancedBackupSettings
  * tests/provider: Enable nakedret linter (#15455)
  * provider: Add TimestreamWrite service client (#15421) (#15451)
  * Update module aws/aws-sdk-go to v1.35.2 (#15226)
  * Update module golangci/golangci-lint to v1.31.0 (#14448)
  * Update CHANGELOG for #10496
  * resource/aws_sns_topic_subscription: Create subscriptions with attributes instead of separate API calls (#10496)
  * Cleanup after v3.9.0 release
- from version 3.9.0
  * Removes manual testing scripts
  * Addresses PR comments
  * tests/provider: Support (helper/schema.Resource).DeleteContext in testAccCheckResourceDisappears (#15448)
  * docs: add missing forces new docs to db_parameter_group
  * Use Go modules to manage tflint version (#15342)
  * Formatting fix
  * Prevents importing AWS-managed Organizations policy
  * Rolls back incorrect syntax fix
  * Update CHANGELOG for #8918
  * Serialize Lex Bot version tests on TeamCity
  * Serializes Lex Bot create version tests
  * Clean up
  * Fixes after rebase.
  * Update CHANGELOG for #12547
  * Update CHANGELOG for #14916
  * Update CHANGELOG ordering
  * Update CHANGELOG for #15367
  * resource/aws_ec2_client_vpn_authorization_rule: Increased active and revoked timeouts from 5 to 10 minutes (#15367)
  * Update CHANGELOG for #15231
  * Remove duplicate example in aws_appmesh_route documentation.
  * r/aws_appmesh_virtual_node: Update resource testing and documentation to 0.12 syntax. r/aws_appmesh_route: Update resource testing and documentation to 0.12 syntax.
  * r/aws_appmesh_virtual_node: Use '_Values()' (#14601). r/aws_appmesh_route: Use '_Values()' (#14601).
  * Fix compilation errors after rebase.
  * r/aws_appmesh_virtual_node: Add 'testAccAwsAppmeshVirtualNode_listenerTimeout'.
  * r/aws_appmesh_virtual_node: Add timeout configuration support.
  * r/aws_appmesh_route: Refactor timeout serde functions.
  * r/aws_appmesh_route: Fix HTTP and HTTP2 route timeout acceptance tests.
  * r/aws_appmesh_route: Add HTTP and HTTP2 route timeout configuration support.
  * r/aws_appmesh_route: Add TCP route timeout configuration support.
  * r/aws_appmesh_route: Add gRPC route timeout configuration support.
  * r/aws_appmesh_virtual_router: Test gRPC and HTTP/2 listener protocols.
  * r/aws_appmesh_route: Support gRPC and HTTP/2 services.
  * r/aws_appmesh_route: Support gRPC and HTTP/2 services.
  * r/aws_appmesh_route: Add support for retry policies.
  * r/aws_appmesh_route: Add support for retry policies.
  * deps: Update github.com/ulikunitz/xz@v0.5.8 (#15432)
  * remove test
  * Update CHANGELOG for #14429
  * add precheck
  * add requiredwith for import path
  * docs
  * add computed, remove default value. fix tests
  * add support for `auto_import_policy`
  * Update CHANGELOG for #15299
  * Update CHANGELOG for #13753
  * Update CHANGELOG for #11669
  * provider: Update Makefile fmt target to ignore ./awsproviderlint/vendor (#15426)
  * lint
  * doc lint
  * Apply suggestions from code review
  * add account validation
  * doc
  * get authorization token resource
  * r/aws_appmesh_route: Additional checks for 'mesh_owner' and 'resource_owner'.
  * Remove duplicate example in aws_appmesh_route documentation.
  * r/aws_appmesh_virtual_node: Use '_Values()' (#14601). r/aws_appmesh_virtual_router: Use '_Values()' (#14601).
  * r/aws_appmesh_route: Update resource testing and documentation to 0.12 syntax.
  * r/aws_appmesh_route: Modify acceptance tests for #13556.
  * r/aws_appmesh_route: Correct acceptance tests after merge of https://github.com/terraform-providers/terraform-provider-aws/pull/13539.
  * r/aws_appmesh_route: Correct acceptance tests after removing custom hash functions.
  * r/aws_appmesh_virtual_node: Add gRPC and HTTP/2 listener protocols.
  * r/aws_appmesh_virtual_router: Test gRPC and HTTP/2 listener protocols.
  * Support new grpc, http2 port protocols for app mesh virtual router
  * r/aws_appmesh_route: Support gRPC and HTTP/2 services.
  * r/aws_appmesh_route: Add support for retry policies.
  * r/aws_appmesh_route: Add support for retry policies.
  * Update CHANGELOG for #12784
  * resource/aws_db_proxy_target: Refactoring and fixes for AWS GovCloud (US) testing
  * test lint
  * add precheck
  * docs lint
  * remove required as `automatic_backup_retention_days` doesnt require `daily_automatic_backup_start_time` only one way.
  * docs
  * add support for `daily_automatic_backup_start_time`
  * sdk v2
  * minor changes for docs + err %%w
  * support multi account properly add owner test case fix docs
  * add update scenario + make test more specific
  * fix example in docs
  * fix docs + example
  * us %%w for error
  * fix name to `codeartifact_domain_permissions_policy`
  * add codeartifact domain permission resource
  * v2
  * add owner test
  * add owner test
  * err %%w
  * use arn as id
  * docs
  * add `external_connections` attribute change `upstreams` to singular
  * tests
  * add support for code artifact repository
  * Update CHANGELOG for #13743
  * Update CHANGELOG for #14727
  * Update CHANGELOG for #12541
  * Update aws/resource_aws_glue_data_catalog_encryption_settings_test.go
  * Update CHANGELOG for #15404
  * service/rds: Prevent ordering differences with enabled_cloudwatch_logs_exports arguments (#15404)
  * resource/aws_db_proxy_target: Apply suggestions from code review
  * Update resource_aws_glue_data_catalog_encryption_settings_test.go
  * Update CHANGELOG for #15339
  * resource/aws_redshift_cluster: Increase default Update timeout to 75 minutes and remove arbitrary lower create timeout in testing (#15339)
  * Add macie2 pull request path labeler config
  * provider: Add Macie2 service client (#13432)
  * tests/provider: Run Terraform Providers Checks on tools/** changes (#15403)
  * r/aws_acmpca_certificate_authority: Add 'testAccCheckAwsAcmpcaCertificateAuthorityDisableCA'.
  * r/aws_appmesh_virtual_node: Tidy up acceptance tests.
  * r/aws_appmesh_virtual_node: Delete 'appmeshVirtualNodeBackendHash'.
  * r/aws_appmesh_virtual_node: Fix 'testAccAwsAppmeshVirtualNode_clientPolicyAcm'.
  * Use 'TestCheckTypeSetElemNestedAttrs'.
  * Correct listener index in acceptance tests.
  * 'flattenIntList' -> 'flattenInt64List' to match corresponding 'expand' function.
  * Address TODOs.
  * r/aws_acmpca_certificate_authority: Test CA activation.
  * Simplify certificate handling - Some TODOs.
  * Fix testAccAwsAppmeshVirtualNode_tls acceptance test.
  * Use multierror in test sweeper:
  * Remove commented-out references to 'sds'. That features is not out of preview.
  * Remove artifacts of other preview features.
  * r/aws_appmesh_virtual_node: Test spec.backend_defaults attribute.
  * r/aws_appmesh_virtual_node: Add spec.backend_defaults attribute.
  * r/aws_appmesh_virtual_node: Test backend.virtual_service.client_policy...acm attribute.
  * r/aws_appmesh_virtual_node: Test backend.virtual_service.client_policy...file attribute.
  * r/aws_appmesh_virtual_node: Add backend.virtual_service.client_policy attribute.
  * r/aws_appmesh_virtual_node: Test listener.tls attribute.
  * r/aws_appmesh_virtual_node: Add listener.tls attribute.
  * fix multi test
  * test lint
  * fix parameters
  * multi part and parameters test
  * refactor out partition id get/create
  * test lint
  * tf 12 syntax for tests
  * use %%w for errors
  * use v2 sdk
  * docs
  * rename + docs
  * disappears
  * add disappearing test case
  * refactor + tests
  * stringify id
  * initial commit
  * change `aws_kms_id` to `aws_kms_key_id`
  * change `aws_kms_id` to `aws_kms_key_id`
  * stricter checks
  * add docs
  * add arm validation for kms keys
  * add tests
  * add resource to provider
  * add glue data catalog encryption settings resource
  * doc lint
  * test lint
  * use v2 and tf12 syntax
  * support multi account properly
  * copy pasta
  * add sweeper
  * domain name to prefix
  * fix kms to only take arn to prevent diffs
  * use %%w
  * fix error handling to add more logs
  * no need to get when setting string
  * fix doc comments
  * throw error
  * add codeartifact domain resource
  * tests/provider: Ensure CHANGELOG.md changes properly comment on forked pull requests (#15396)
  * deps: Split Go Modules for tooling, remove root module vendoring (#15391)
  * Terraform 0.12 syntax fixes
  * Update CHANGELOG for #12501
  *  Update CHANGELOG for #12501
  * Update CHANGELOG for #14909
  * Update CHANGELOG for #11660
  * docs/resource/aws_dms_replication_instance: Changed IAM Role link (#15340)
  * docs/resource/aws_transfer_server: Add `VPC` for endpoint_type to transfer_server (#15373)
  * docs/resource/aws_storagegateway_cached_iscsi_volume: fix import command (#15372)
  * docs/resource/aws_transfer_server: Fix command for generating the host key (#15392)
  * applying new pattern for d.set() and extra line between attributes
  * Update CHANGELOG for #8917
  * Fixes copypasta
  * Wraps error return
  * Removes "zero-width space" characters (\u200b)
  * Rebased on add_aws_lex_bot branch, review updates
  * tests/provider: Add precheck (FSx lustre)
  * Apply suggestions from code review
  * Simplify and make Sprintf verb indices consistent
  * Add more bot resource tests
  * Fix github check tf format and website format
  * Rebase on add_aws_lex_intent_resource branch and first pass to address review comments, still need to expand on resource tests
  * Fix github check error remove unused code
  * Fix github check errors lint
  * Fix github check errors
  * Latest review comments addressed, so many changes ...
  * Update CHANGELOG for #15350
  * Terraform formatting fix
  * tests/provider: Update hardcoded AZs (DB Instance)
  * Apply suggestions from code review
  * add missing key/value block
  * f/aws_glue_crawler:support for s3_target connection_name
  * f/aws_glue_crawler:support for s3_target connection name
  * f/aws_glue_crawler- allow connectionname for s3 target
  * Update CHANGELOG.md for #14184
  * Cleanup after v3.8.0 release
- from version 3.8.0
  * Update CHANGELOG for #12599
  * resource/aws_transfer_server: Remove EC2 handling, prevent panic with Transfer API lookup and errors with VPC_ENDPOINT type, comment special handling with EIPs
  * Update CHANGELOG for #15293
  * tests/resource/aws_transfer_server: Refactor VPC endpoint testing configuration to remove error, 0.12 syntax, and formatting
  * Update CHANGELOG for #15284
  * tests/resource/aws_transfer_user: Remove duplicate home_directory_mappings testing
  * Update CHANGELOG for #11428
  * Update CHANGELOG for #15268
  * Cleans up CHANGELOG
  * Update CHANGELOG for #15218
  * Update CHANGELOG for #15316
  * resource/aws_glue_job: Add glue_version 2.0 testing and small documentation note (#15067)
  * test lint
  * Update aws/resource_aws_glue_ml_transform.go
  * Apply suggestions from code review
  * fmt example
  * full find matches example + add validation
  * complete docs
  * remove evaluation metrics
  * add docs
  * fix basic test
  * add arn to index.html.markdown
  * add more checks to basic for all attributes
  * fix workerType test
  * handle delete not exists error
  * actually delete ML transform
  * remove wait for ready
  * add waiters
  * make parameters updatable
  * add tests fix arn add parameters to update
  * more validations for `max_capacity`
  * add `evaluation_metrics` to read
  * add `evaluation_metrics`
  * add `schema`
  * add `aws_glue_ml_transform` resource
  * f/aws_organizations_policy:support for tags
  * f/aws_organizations_policy:support for tags
  * f/aws_organizations_policy:support for tags
  * Add storage_type to aws_fsx_lustre_file_system
  * Modify aws_kinesis_firehose_delivery_stream documentation
  * add acceptance tests for log publishing options on create
  * #12599 Updates from comments
  * #12599 Updates from comments
  * #12599 Updates from comments
  * docs/resource/aws_glue_crawler: Fix linting issue (#15324)
  * Update CHANGELOG.md for #14819
  * Updates Terraform configurations in acceptance tests for resource names starting with "t" to "z"
  * Update CHANGELOG.md for #14818
  * Update tflint version
  * New datasource ec2_instance_type to get characteristics about ec2 instance type
  * r/aws_appmesh_route: Additional mesh_owner and resource_owner checks.
  * Fix terrafmt error.
  * r/aws_appmesh_route: Use '_Values()' (#14601).
  * r/aws_appmesh_route: Update resource testing and documentation to 0.12 syntax.
  * r/aws_appmesh_route: No need for custom set hash functions.
  * r/aws_appmesh_route: Add support for retry policies.
  * Update CHANGELOG.md for #14910
  * provider: Remove now duplicate security issue link (#15282)
  * provider: Try actions/labeler for PR needs-triage labels (#15286)
  * Update CHANGELOG.md
  * d/neptune_engine_version: New data source
  * d/docdb_engine_version: New data source
  * d/rds_engine_version: New data source
  * Update CHANGELOG for #14349
  * #12599 Updates from comments
  * service/appmesh: Add 'mesh_owner' and 'resource_owner' attributes in support of cross-account AppMesh mesh sharing (#14349)
  * f/aws_organizations_policy:support for tags
  * Update CHANGELOG for #15232
  * tests/resource/aws_s3_bucket_object: Fix etag and non-versions test configurations (#15225)
  * #12599 Updates from comments
  * #12599 Updates from comments
  * resource/aws_cloudformation_stack_set_instance: Handle IAM eventual consistency retries during creation (#15173)
  * update dependencies github action with forked repo support
  * revert dependencies.yml to changes from #14954
  * Update dependencies.yml
  * Update CHANGELOG for #15250
  * Update dependencies.yml with bot name
  * Update dependencies.yml comment output
  * Update CHANGELOG for #14313
  * Update dependencies.yml with comment step
  * Update dependencies.yml
  * update comment gh action in dependencies.yml
  * docs/resource/aws_kinesis_firehose_delivery_stream: Fix typo on key_arn documentation (#15306)
  * Add source_ip as option for target_group stickiness type
  * Add mount_name to aws_fsx_lustre_file_system
  * Restricts TestAccAWSRouteDataSource_basic to supported subnets
  * Increase the efs_mount_target creation timeout to 30 minutes
  * Restricts TestAccAWSRouteTable_instance to supported subnets
  * Update CHANGELOG for #14793
  * Fixes acceptance test errors
  * Update dependencies.yml
  * update dependencies.yml syntax
  * remove user anGie44 for testing
  * Update dependencies.yml with pull request target
  * r/aws_apigatewayv2_authorizer: Distinguish between missing and zero values for cache TTL.
  * Add configuring-enhanced-monitoring to create/update pending states of Neptune cluster
  * Update CHANGELOG for #15057
  * resource/aws_fsx_lustre_file_system: Add kms_key_id argument (#15057)
  * resource/aws_elastic_beanstalk_environment: Handle Terminated status on deletion, use IAM Instance Profile and custom service role in testing (#15158)
  * Update CHANGELOG for #14709
  * resource/aws_rds_cluster: Add allow_major_version_upgrade argument (#14709)
  * r/aws_apigatewayv2_authorizer: Correctly handle result cache disabling.
  * tech-debt/aws_rds_cluster:TestAccAWSRDSCluster_SnapshotIdentifier_PreferredBackupWindow
  * tech-debt/aws_rds_cluster:TestAccAWSRDSCluster_SnapshotIdentifier_PreferredBackupWindow
  * check for abort option when adding expiration setting
  * Updates Terraform configurations in acceptance tests for resource names starting with "o" to "s"
  * Update tflint version
  * r/aws_apigatewayv2_api: Add 'disable_execute_api_endpoint' attribute.
  * d/rds_orderable_db_instance: Enable default only version
  * Adds missing text
  * d/neptune_orderable_db_instance: Add default only argument
  * d/docdb_orderable_db_instance: Add default only argument
  * Update CHANGELOG for #14901
  * Update CHANGELOG for #14897
  * tests/resource/aws_transfer_user: Terraform 0.12 syntax and formatting updates
  * Update CHANGELOG for #13591
  * r/aws_apigatewayv2_authorizer: Make 'identity_sources' optional.
  * Fix markdown-lint failure in 'fsx_lustre_file_system.html.markdown'. (#15233)
  * Update CHANGELOG for #12196
  * resource/aws_s3_bucket_object: Ignore changes due to default bucket encryption (#10200)
  * r/aws_apigatewayv2_authorizer: Support Lambda authorization options for HTTP APIs.
  * Update CHANGELOG for #12686
  * Updates acceptance tests to use modern splat syntax instead of adding individual array elements to list
  * resource/aws_storagegateway_smb_file_share: Ensure admin_user_list is included in newer HasChanges logic
  * tests/resource/aws_storagegateway_smb_file_share: Fix merge conflict resolution
  * Update CHANGELOG for #14446
  * Update CHANGELOG for #14314
  * Update CHANGELOG for #15115
  * Update CHANGELOG for #15169
  * Update CHANGELOG of #12335
  * Create waiter for load balancer creation and update
  * resource/aws_elasticsearch_domain: Replace enum of possible log types with `LogType_Values()`
  * Document breaking change in aws_launch_template data source
  * Splat expressions and Go 1.13 error wrapping
  * Update module aws/aws-sdk-go to v1.34.26 (#15123)
  * Update CHANGELOG for #15201
  * service/ec2: Increase default VPN Gateway detach timeout to 30 mins (#15201)
  * Update CHANGELOG for #15170
  * service/elbv2: Add Outpost and COIP support to aws_lb datasource and resource (#15170)
  * tests/service/rds: Remove hardcoded instance classes from EC2-Classic tests and basic data source test (#15184)
  * Cleanup after v3.7.0 release
- from version 3.7.0
  * tests/resource/aws_vpc_endpoint: Switch TestAccAWSVpcEndpoint_gatewayPolicy to dynamodb (#15185)
  * tests/resource/aws_ses_active_receipt_rule_set: Serialize testing (#15188)
  * tests/resource/aws_subnet: Fix errant resource name in TestAccAWSSubnet_availabilityZoneId test (#15162)
  * Update CHANGELOG for #15178
  * resource/aws_cognito_identity_pool: Prevent ordering differences for openid_connect_provider_arns argument (#15178)
  * tests/resource/aws_elasticsearch_domain: Fix configuration issues in TestAccAWSElasticSearchDomain_vpc_update (#15180)
  * docs/provider: Split Terraform 0.13 and later example configuration (#15065)
  * Updates Terraform configurations in acceptance tests for resource names starting with "l" to "n"
  * Update tflint version
  * Fixes acceptance test inconsistencies
  * tests/provider: Fix hardcoded (OpsWorks Stacks)
  * Update CHANGELOG for #11954
  * resource/aws_kinesis_firehose_delivery_stream: Ensure previous enabled-only SSE configurations work, minor refactoring
  * re-add logic to expand non_key_attributes configured in a TypeList
  * tests/provider: Add precheck (DS DS)
  * Updates Terraform configurations in acceptance tests for resource names starting with "i" and "k"
  * Update CHANGELOG for #13884
  * Adds package name and fixes formatting
  * Update aws/resource_aws_config_remediation_configuration.go
  * Update CHANGELOG for #15169
  * provider: Remove extraneous zero-value checking with (helper/schema.ResourceData).GetOk() (#15111)
  * tests/resource/aws_spot_instance_request: Remove hardcoded instance types (#15161)
  * tests/provider: Add precheck (DB Proxy)
  * Fix terraform validation check
  * Fix github checks errors
  * Update data_source_aws_kms_secrets.go
  * Update data_source_aws_kms_secrets.go
  * Added section how to import hsm module resources
  * First batch of updates for review prep
  * tests/provider: Fix, Enable AWSAT002
  * tests/provider: Fix hardcoded (rds cluster instance)
  * service/eks: Document enabling Security Groups for Pods functionality (#15097)
  * service/directconnect: Replace EqSe2 location with EqSe2-EQ (#15152)
  * reference all previous versions
  * Add FAQ item to describe backport policy
  * New Service Clients: identitystore and ssoadmin (#15119)
  * examples/count: Fix AMI hvm issue #15139
  * linting go (2)
  * linting go
  * linting terraform
  * All acceptance tests pass
  * tests/provider: Add precheck for ep config type edge (API Gateway Doc Part)
  * tests/provider: Add precheck for ep config type edge (API Gateway Deployment)
  * tests/provider: Add precheck for ep config type edge (API Gateway Doc Version)
  * tests/provider: Add precheck for ep config type edge (API Gateway Gateway & Integration)
  * tests/provider: Add precheck for ep config type edge (API Gateway Method)
  * tests/provider: Add precheck for ep config type edge (API Gateway Model-Stage)
  * tests/provider: Add precheck for ep config type edge (API Gateway Usage Plan)
  * tests/provider: Add precheck to ep config type edge (API Gateway Authorizer)
  * Update CHANGELOG for #15060
  * resource/aws_acm_certificate: Prevent tagging is not permitted on re-import error (#15060)
  * data-source/aws_ssm_parameter: Add parameter name to error message (#15117)
  * tests/provider: Lint AWSAT002 ignore (validators_test)
  * tests/provider: Fix hardcoded (Codepipeline)
  * tests/provider: Add precheck for ep config type edge (API Gateway Rest API)
  * Update CHANGELOG for #15132
  * resource/aws_db_cluster_snapshot: Add plan-time validation for db_cluster_snapshot_identifier argument (#15132)
  * tests/resource/aws_ssm_maintenance_window_target: Fix TestAccAWSSSMMaintenanceWindowTarget_resourceGroup (#15134)
  * Update Terraform github to v3 (#15068)
  * Consolidates deletion steps
  * tests/provider: Update hardcoded AZs (DocDB related)
  * Refactors deletion steps
  * tests/provider: Add prechecks (Workspaces)
  * Re-apply #15039 with comma fix
  * Revert .hashibot.hcl before #15039 to see if it comes back
  * Testing another .hashibot.hcl update to trigger reload
  * Testing .hashibot.hcl update to trigger reload
  * Clean up ELB attachment tests
  * Update module aws/aws-sdk-go to v1.34.21 (#14955)
  * provider: Ensure hashibot labels internal service files with service label (#15039)
  * Adds data sources to validtion workflow and fixes syntax
  * Updates tflint rules to use "--only" flag
  * Cleanup after v3.6.0 release
- from version 3.6.0
  * tests/provider: Update resource testing to 0.12 syntax (V Resources)
  * Fixes Elasticache cluster acceptance tests
  * Fix test failure splitting TestAccAWSNetworkAclRule_ipv6VpcAssignGene… (#14918)
  * Update CHANGELOG for #12743
  * New Resource: aws_db_proxy_default_target_group (#12743)
  * use TestMatchResourceAttrPair to check for valid arn
  * Separate tests for encryption of firehose streams with different key types
  * Remove hardcoded values and use standard function in firehose file
  * Add kms_key_type and kms_key_arn to firehose documentation
  * Fix firehose delivery stream test for server side encryption
  * Add CUSTOMER_MANAGED_CMK encryption possibility for firehose streams
  * Fixes EIP Association acceptance tests
  * More fixes to EIP acceptance tests
  * Fixes EIP tests and returns error when setting tags on EIP in EC2 Classic
  * tests/provider: Fix hardcoded (DynamoDB Global Table)
  * tests/provider: Fix hardcoded (GuardDuty Filter)
  * tests/provider: Fix hardcoded (Config Config Aggregator)
  * tests/provider: Fix hardcoded (app sticky cookie)
  * docs/resource/aws_iam_group_policy: Assign group name (not id) to group argument (#15041)
  * Updates Terraform configurations in acceptance tests for resource names starting with "f" and "g"
  * Updates Terraform configurations in acceptance tests for resource names starting with "e"
  * Updates tflint rules to use "--only" flag
  * tests/provider: Try out semgrep in CI (#15014)
  * tests/provider: Fix hardcoded AZs (docdb cluster)
  * Update CHANGELOG for #15037
  * resource/aws_ec2_client_vpn_authorization_rule: Updated ClientVpnAuthorizationRuleActiveTimeout and ClientVpnAuthorizationRuleRevokedTimeout to 5 minute timeout (#15037)
  * docs/resource/aws_guardduty_filter: Fix incorrect import doc instructions (#15058)
  * tests/resource/aws_elasticache_cluster: Fix TestAccAWSElasticacheCluster_ReplicationGroupID_SingleReplica (#15043)
  * Add test for updates
  * Add test for recreation
  * Add test for out-of-band deletion
  * resource/aws_db_proxy_target: Test fixes II
  * resource/aws_db_proxy_target: Test fixes I
  * resource/aws_db_proxy_target: Adding initial tests, upgrade to SDK v2
  * resource/aws_db_proxy_target: Initial commit
  * docs/resource/aws_db_proxy: Reflect that engine_family supports Postgres (#15021)
  * fix docs
  * validate name len
  * update main arn doc
  * add support for max concurrent runs
  * add support for glue workflow tags and arn
  * tests/provider: Fix hardcoded AZs (launch config, template)
  * Missed script update
  * Updates Terraform configurations in acceptance tests for resource names starting with "b, c, d"
  * tests/provider: Fix hardcoded (lb cookie sticky policy)
  * tests/provider: Fix hardcoded (RDS cluster endpoint)
  * tests/provider: Fix hardcoded (proxy protocol policy)
  * tests/provider: Fix hardcoded (lb listener policy)
  * Cleanup after v3.5.0 release
  * tests/provider: Fix hardcoded AZs (spot fleet request)
- from version 3.5.0
  * Update CHANGELOG for #15015
  * resource/aws_route53_resolver_rule: Correct handling for single period (`.`) value in `domain_name` argument (#15015)
  * tests/provider: Fix hardcoded AZs (neptune)
  * tests/provider: Fix hardcoded AZs (lb policy)
  * tests/provider: Fix hardcoded AZs (elasticache subnet grp)
  * tech-debt/aws_instance: add state conf for root device and metadata updates (#14723)
  * Update CHANGELOG for #14993
  * resource/aws_cloudfront_distribution: Prevent crash with missing ForwardedValues (#14993)
  * tests/provider: Fix hardcoded AZs (docdb subnet)
  * Update documentation for the WAFv2 pattern regex set to include file_to_match and text_transformation attributes
  * tests/provider: Fix hardcoded AZs (nat gateway ds)
  * r/rds_orderable_db_instance: Improve filters
  * tests/provider: Fix hardcoded AZs (Redshift cluster ds)
  * tests/provider: Fix hardcoded AZs (RDS cluster ds)
  * tests/provider: Update hardcoded AZs (EBS Snapshot IDs)
  * Removes non-existent fields from RDS cluster instance documentation
  * Removes non-existent fields from RDS cluster documentation
  * service/ec2: Prevent aws_default_route_table panic caused by aws_route_table attribute changes (#14988)
  * data-source/aws_neptune_orderable_db_instance: Fix naming (#14992)
  * data-source/aws_docdb_orderable_db_instance: Fix naming (#14991)
  * Updates Terraform configurations in acceptance tests for resource names starting with "a"
  * Update CHANGELOG for #14876
  * Updates from code review
  * Update CHANGELOG for #9988
  * Update CHANGELOG for #12390
  * resource/aws_cloudtrail: Add insight_selector configuration block (#12390)
  * Update CHANGELOG for #12428
  * service/costandusagereporting: Parquet, Athena and more (#12428)
  * Tweak log message when resource not found.
  * Tweak log message when resource not found.
  * Update CHANGELOG for #14964
  * revert to previous flattenFieldToMatch logic with nil checks
  * add rate_limit to list of possible update changes
  * tests/provider: Remediate and enable markdownlint MD009 rule (#14978)
  * docs/provider: Whitespaces at the end of line fixes. (#14954)
  * Update CHANGELOG for #14967
  * data-source/aws_outposts_outpost: Add arn argument (#14967)
  * Update CHANGELOG for #14906
  * service/ec2: Additional support for volume type io2 (#14906)
  * revert waf_rate_based_rule changes
  * add rate_limit to list of possible update changes
  * update acctest configuration params and remove disappears methods; update enumerated vals
  * update acctests to use updated typeset pair check
  * update test to use resource pair check for typeset
  * Update CHANGELOG.md
  * update typeset checks, remove custom disappears func, and use enumerated types
  * update typset check and remove custom disappears funcs
  * Update CHANGELOG for #14864
  * service/ec2: Add local gateway routes and route table entries (#14864)
  * Update CHANGELOG for #9491
  * data-source/neptune_orderable_db_instance: New data source
  * New Data Source: aws_vpc_peering_connections (#9491)
  * add precheck for appsync service and and remove custom disappears fns
  * Update CHANGELOG for #12704
  * New Resource: aws_db_proxy (#12704)
  * refactor non-key attributes difference method and acctests
  * tests/resource/aws_worklink_fleet: Fix TestAccAWSWorkLinkFleet_AuditStreamArn (#14907)
  * Update CHANGELOG for #14851
  * Update CHANGELOG for #13976
  * resource/aws_lambda_function_event_invoke_config: Prevent unexpected format of function resource error (#14851)
  * Update CHANGELOG for #14813
  * New Resource: aws_emr_instance_fleet (#14813)
  * Update CHANGELOG for #14171
  * resource/aws_ec2_client_vpn_endpoint: Support authentication_options type federated-authentication value and saml_provider_arn argument (#14171)
  * Update module aws/aws-sdk-go to v1.34.14 (#14936)
  * Update CHANGELOG.md
  * data-source/docdb_orderable_db_instance: New data source
  * Update CHANGELOG for #13868
  * tests/resource/aws_lightsail_instance: Add key-only tags test (#12346)
  * provider: Support arbitrary additional tag data, implement keyvaluetags and ignore_tags support in aws_autoscaling_group resource, return empty strings with key-only tags instead of panicking (#13868)
  * Uses RFC 3339 dates for "updatedAt" field
  * data-source/aws_rds_orderable_db_instance: New data source
  * update backup-plan resource testing with SDKv2 TypeSet handling
  * Update CHANGELOG for #14902
  * Add provider functions to check more hostnames
  * Update CHANGELOG for #14788
  * resource/aws_emr_cluster: Add core_instance_fleet and master_instance_fleet configuration blocks (#14788)
  * tests/provider: Update hardcoded AZs (DMS related)
  * Update CHANGELOG for #12484
  * resource/aws_kinesis_firehose_delivery_stream: Add elasticsearch_configuration cluster_endpoint argument + other plan-time validations (#12484)
  * Update CHANGELOG for #12537
  * New Resource: aws_glue_user_defined_function (#12537)
  * Update CHANGELOG for #14885
  * resource/aws_route53_zone_association: Correctly handle zones with over 100 VPC associations (#14885)
  * Update CHANGELOG for #13269
  * resource/aws_kinesis_firehose_delivery_stream: Add elasticsearch_configuration vpc_config configuration block (support Elasticsearch VPC configuration) (#13269)
  * only pass repeated parameter once
  * documentation formatting
  * remove website changes
  * Update aws/resource_aws_config_remediation_configuration_test.go
  * Update aws/resource_aws_config_remediation_configuration_test.go
  * Update aws/resource_aws_config_remediation_configuration.go
  * Update aws/resource_aws_config_remediation_configuration.go
  * Update aws/resource_aws_config_remediation_configuration.go
  * r/aws_route53_resolver_query_log_config_association: Add acceptance test sweeper.
  * Update CHANGELOG for #8916
  * Updates filter criteria to match AWS API
  * Update CHANGELOG for #14894
  * resource/aws_ebs_volume: Support io2 type (#14894)
  * Update CHANGELOG for #14850
  * resource/aws_mq_configuration: Don't update the configuration if only tags change. (#14850)
  * add support for ForwardedIPConfig in IPSetReferenceStatement
  * r/aws_route53_resolver_query_log_config_association: New resource.
  * Correct acceptance test configuration generator names.
  * Documentation correction.
  * Update CHANGELOG for #12573
  * New Resource: aws_codebuild_report_group (#12573)
  * docs/resource/aws_storagegateway_gateway: Docs clarification for importing (#14878)
  * resource/aws_sns_topic_subscription: Fix error message (#14888)
  * r/aws_route53_resolver_query_log_config: New resource.
  * Update module aws/aws-sdk-go to v1.34.13
  * Update CHANGELOG for #14858
  * resource/aws_emr_cluster: Prevent recreation when `ebs_config.volumes_per_instance` is greater than 1 (#14858)
  * Update CHANGELOG for #14886
  * Update CHANGELOG for #14862
  * Update CHANGELOG for #14826
  * resource/aws_msk_configuration: Implement Update and Delete support (#14826)
  * Update CHANGELOG for #14782
  * resource/aws_acm_certificate: Provide additional plan-time validation for subject_alternative_names values (#14782)
  * add "other" to source type values
  * refactor opsworks_slack tests and update enumerated values
  * add diffsupressfunc for json field
  * Updates Exists function to make API call and return API object
  * Cleanup after v3.4.0 release
- from version 3.4.0
  * Adds tag update ability and ARN output
  * add create timeout for rds_cluster_endpoint resource
  * Update CHANGELOG for #9525
  * Update CHANGELOG for #14106
  * resource/aws_emr_instance_group: Increase creation and update timeouts to 30 minutes (#14106)
  * Update CHANGELOG for #13077
  * resource/aws_emr_instance_group: Extend instance group timeout by 50%% (#13077)
  * tests/provider: Ensure GitHub Actions workflow for markdown-lint checks out code and can fetch latest v1 (#14849)
  * Update CHANGELOG for #12974
  * Update CHANGELOG for #14860
  * resource/aws_apigatewayv2_integration: AWS service integrations for HTTP APIs. (#14860)
  * Update CHANGELOG for #13600
  * New Resource: aws_xray_encryption_config (#13600)
  * Update website/docs/r/elasticache_replication_group.html.markdown
  * tests/resource/aws_elb: Fix TestAccAWSELB_swap_subnets (#14865)
  * Update CHANGELOG for #13597
  * New Resource: aws_xray_group (#13597)
  * Adds update and disappears tests
  * Handle case when there are no tags set and add more complete tests
  * use aws.String() instead of string pointer
  * refactor and add acceptance test for always_on workspace property
  * tests/provider: Update hardcoded AZs (Default Subnet)
  * Update CHANGELOG for #14844
  * remove aws webite ref
  * use canonicalCidrBlock() from #14543
  * Fix aws_ecs_task_definition docs markdown links
  * feature(sagemaker notebook): Add support for DefaultCodeRepository
  * deps: Allow dependabot to upgrade GitHub action versions (#14835)
  * Update CHANGELOG for #10493
  * resource/aws_securityhub_action_target: Finishing touches for initial resource
  * r/aws_cloudfront_distribution: Fix 'TestAccAWSCloudFrontDistribution_OriginGroups'.
  * aws_ec2_transit_gateway_route: ipv6 support
  * r/aws_cloudfront_distribution: Avoid raw pointer dereferences (#12992).
  * add handling for pair matching without sentinel
  * internal/service/guardduty/waiter: Refactor Publishing Destination status handling
  * resource/aws_guardduty_publishing_destination: Minor adjustments for initial resource
  * Update CHANGELOG for #13894
  * New Resource: aws_guardduty_publishing_destination (#13894)
  * docs/resource/aws_autoscaling_policy: Add missing min_adjustment_magnitude argument (#14807)
  * update to using data source instance types
  * update test configs to fix failing tests
  * Small syntax fixes
  * tests/resource/aws_redshift_subnet_group: Implement sweeper and disappears test (#14828)
  * Updates Terraform syntax for data source acceptance tests
  * Update CHANGELOG for #14831
  * resource/aws_xray_sampling_rule: Add tags argument (#14831)
  * tests/resource/aws_codepipeline: Fix TestAccAWSCodePipeline_deployWithServiceRole (#14830)
  * Update CHANGELOG for #13965
  * New Resource: aws_emr_managed_scaling_policy (#13965)
  * Update to Terraform 0.12+ syntax
  * Update module aws/aws-sdk-go to v1.34.10 (#14665)
  * update doc
  * docs/resource/aws_cloudwatch_log_group: Add information about 0 value for retention_in_days argument (#14791)
  * Update CHANGELOG for #13568
  * Add @Tensho as WorkSpaces services maintainer to CODEOWNERS
  * New data source: aws_workspaces_image
  * add docs for ddb target arguments
  * add test for scan rate
  * add test for scan all
  * add support for `scan_all` and `scan_rate` ddb target attributes
  * use enum list and support network connection type add disappears test
  * update test description
  * resource/aws_storagegateway_gateway: Add support for bandwidth values (#13568)
  * update tf syntax
  * Update CHANGELOG for #14790
  * resource/aws_storagegateway_smb_file_share: Support cache attributes and case sensitivity, remove errant docs (#14790)
  * service/appmesh: Update AppMesh resource acceptance tests to 0.12 syntax (#14795)
  * Update CHANGELOG for #14792
  * Use TF 0.12 refs, use RootAccess_Values func
  * Configurable root access to SM notebook instance
  * use built in `stringMapToPointers` func
  * Update aws/resource_aws_glue_job.go
  * Update aws/resource_aws_glue_job.go
  * add disappears test
  * support non overridable arguments
  * refactor disappears test
  * allow removing schedule
  * revert validation
  * Update elasticache_replication_group.html.markdown
  * resource/aws_service_discovery_http_namespace: Correct name validation (#14749)
  * Update CHANGELOG for #14486
  * service/globalaccelerator: Support Client IP address preservation, increase default accelerator creation timeout, remove health_check_path default (#14486)
  * provider: Alphabetize services in CODEOWNERS
  * CODEOWNERS- Add @drfaust92 as services maintainer (#14051)
  * Update CHANGELOG for #13684
  * service/acmpca: Add activation of ACMPCA CA to acceptance tests (#13684)
  * Update CHANGELOG for #14759
  * resource/aws_storagegateway_nfs_file_share: Add cache_attributes configuration block and support S3 Intelligent Tiering (#14759)
  * use %%#v for complex types in logs
  * v2
  * lower case for test names
  * tf 12 test config
  * tf 12 docs
  * Update aws/resource_aws_datasync_location_fsx_windows_file_system.go
  * Update website/docs/r/datasync_location_fsx_windows_file_system.html.markdown
  * refactor id and state
  * use %%w for errors
  * use %%w for errors
  * disappears test + ignore tags
  * rename to add `file_system` suffix
  * fix lint (?)
  * fix lint (?)
  * fix lint (?)
  * add docs
  * add fsx arn
  * add option to import fsx arn
  * fix test
  * fix uri regex
  * add new resource to provider
  * add validations
  * initial commit
  * docs tf12
  * use v2 api
  * fmt + sweeper changes
  * Update aws/resource_aws_backup_vault_notifications.go
  * Update aws/resource_aws_backup_vault_notifications.go
  * Update aws/resource_aws_backup_vault_notifications.go
  * Update aws/resource_aws_backup_vault_notifications.go
  * tf 12 syntax
  * sdk wrapper and errors
  * add sweeper
  * refactor
  * fix linting problem
  * rename arn attrib
  * rename arn attrib
  * fix destroy check + permissions
  * ammend docs
  * add sns policy for backup events + docs
  * add backup vault notifications resource
  * update iam related tests with formatting change and regex to catch trailing resources
  * Update CHANGELOG for #14074
  * resource/aws_appmesh_virtual_node: Disallow empty 'backend' blocks. (#14074)
  * Update CHANGELOG for #13563
  * resource/aws_storagegateway_gateway: Add `smb_security_strategy` argument (#13563)
  * Update CHANGELOG for #12066
  * resource/aws_storagegateway_cached_iscsi_volume: Add kms_encrypted and kms_key arguments (#12066)
  * Add 'ewbankkit' as maintainer of select services. (#14246)
  * tests/resource/aws_cloudtrail: fix testAccAWSCloudTrail_cloudwatch (#14762)
  * docs/resource/aws_instance: Update volume_type default to gp2 (#14767)
  * docs/resource/aws_cloudfront_distribution: Clarified arguments requirement for default_cache_behavior (#14760)
  * Add Security Hub custom action resource
  * Address review comments
- from version 3.3.0
  * Update CHANGELOG for #13590
  * resource/aws_storagegateway_nfs_file_share: Skip UpdateSMBFileShare API call when only tags change and remove extraneous ListTagsForResource API call during read (#13590)
  * Update CHANGELOG for #12303
  * resource/aws_subnet: Fix removing ipv6 cidr block from subnet (#12303)
  * Update CHANGELOG for #13572
  * resource/aws_storagegatway_smb_file_share: Add audit_destination_arn and smb_acl_enabled arguments (#13572)
  * awsproviderlint: Add AWSV001 check, switch fmtsprintfcallexpr pass to upstream (#14681)
  * Update CHANGELOG for #10407
  * resource/aws_api_gateway_vpc_link: Remove customizable timeout and increase previous hardcoded timeouts to 20 minutes
  * update to using AWS SDK defined values arrays
  * Update CHANGELOG for #14146
  * resource/aws_ec2_client_vpn_network_association: Support resource import and additional security groups (#14146)
  * docs/resource/aws_cloudtrail: Update CloudWatch Log group argument reference (#14751)
  * Update CHANGELOG for #14685
  * tests/provider: Update hardcoded AZs (Redshift)
  * Update CHANGELOG for #14639
  * resource/aws_eks_node_group: Add launch_template configuration block (#14639)
  * Check for null regexp in 'testCheckTypeSetElemNestedAttrsInState'.
  * wafv2_web_acl_logging_configuration docs: inspect -> redact
  * Update CHANGELOG for #12112
  * r/aws_rds_cluster_parameter_group and r/aws_db_parameter_group: Restore ability to change parameter values
  * Update CHANGELOG for #14501
  * service/ec2: Support additional tag on create resources (#14501)
  * docs/provider: Remove legacy side navigation file (#14734)
  * Update CHANGELOG for #14732
  * resource/aws_user_pool_domain: Remove from state when deleted + move waiters to their own package (#14732)
  * Update CHANGELOG for #14729
  * resource/aws_eks_node_group: Support `AL2_ARM_64` value for `ami_type` argument plan-time validation (#14729)
  * docs/resource/aws_s3_bucket_inventory: Clarify bucket argument (#14726)
  * add webacl geo-match tests
  * Update CHANGELOG for #14555
  * tests/provider: Update hardcoded AZs (Data subnet ids)
  * use error method migrated to tfawserr package
  * Update module hashicorp/aws-sdk-go-base to v0.6.0
  * Update CHANGELOG for #14514
  * resource/aws_ssm_parameter: Handle data_type retries after creation for asynchronous validation process (#14514)
  * infrastructure/repository: Sync recent new AWS service labels (#14641)
  * docs/provider: Re-add Release Process section to maintaining guide (#14652)
  * docs/provider: Remove mention of side navigation file in Contributing Guide (#14713)
  * tests/provider: Update hardcoded AZs (VPC Endpoint)
  * Update CHANGELOG for #14662
  * resource/aws_launch_template: add support for "spot-instances-request" and "elastic-gpu" tag spec (#14662)
  * tests/provider: Update hardcoded AZs (lb)
  * Add note on how to use aws_wafv2_web_acl_association with Cloudfront
  * Remove extra whitespace with HEREDOCs
  * tests/provider: Update resource testing to 0.12 syntax (T Resources)
  * tests/provider: Update resource testing to 0.12 syntax (Si-Sq Resources)
  * Update CHANGELOG for #14663
  * tests/provider: Update resource testing to 0.12 syntax (Ses Resources)
  * tests/provider: Update resource testing to 0.12 syntax (Sec/Ser Resources)
  * tests/provider: Update resource testing to 0.12 syntax (S3/Sa Resources)
  * Update CHANGELOG for #12567
  * tests/provider: Update resource testing to 0.12 syntax (Ro Resources)
  * tests/provider: Update resource testing to 0.12 syntax (WAFReg Resources)
  * tests/provider: Update resource testing to 0.12 syntax (W Resources)
  * tests/provider: Update resource testing to 0.12 syntax (Ss-Sw Resources)
  * add test for regex matching in typesets
  * tests/provider: Update resource testing to 0.12 syntax (Ra/RD/Re Resources)
  * tests/provider: Update resource testing to 0.12 syntax (Q Resources)
  * Don't attempt to validate EOL runtimes.
  * Update documentation references to latest Lambda Node.js runtime (nodejs12.x).
  * Simplify aws_lambda_function runtime acceptance tests.
  * tests/provider: Update resource testing to 0.12 syntax (IAM Resources)
  * AWS Lambda support for Java 8 (Corretto) and custom runtimes on Amazon Linux 2.
  * tests/provider: Update resource testing to 0.12 syntax (I Resources)
  * Remove quoted deprecated syntax
  * tests/provider: Update resource testing to 0.12 syntax (K Resources)
  * Documentation: Replace aws_ec2_instance_spot_price by aws_ec2_spot_price (#14680)
  * docs/provider: Fix broken link in Contribution Checklist (#14466)
  * add forwarded_ip_config attribute to geo and rate_based statements
  * update db cluster snapshot create with retry logic
  * Update website/docs/index.html.markdown
  * expect config additional opts to be set in aws-sdk-go-base
  * Update module bflad/tfproviderlint to v0.18.0 (#14654)
  * Update CHANGELOG for #14550
  * resource/aws_dms_replication_instance: Add `allow_major_version_upgrade` argument (#14550)
  * docs/provider: Document requirement of Terraform CLI v0.12.26+ for acceptance tests. (#14659)
  * provider: Remove website and website-test Makefile targets (#14503)
  * Update module aws/aws-sdk-go to v1.34.4 (#14523)
  * Update CHANGELOG for #14638
  * resource/aws_apigatewayv2_stage: Set 'execution_arn' attribute for HTTP APIs. (#14638)
  * resource/aws_lb_ssl_negotiation_policy: Fix parsing of resource ID. (#14644)
  * Cleanup after v3.2.0 release
- from version 3.2.0
  * refactor: renaming CloudFormationTemplate to JsonOrYaml
  * Update CHANGELOG for #14650
  * resource/aws_organizations_organization: Add support for AISERVICES_OPT_OUT_POLICY (#14650)
  * resource/apigatewayv2: Add support for `body` parameter
  * R011
  * Adds state migration function, returns errors instead of warnings for setting rule state
  * update user_pool and domain sweepers
  * tests/resource/aws_route53_record: Fix 'TestAccAWSRoute53Record_Alias_VpcEndpoint'. (#14640)
  * Update CHANGELOG for #14617
  * Updates hashcode package
  * Makes aws_default_security_group resource definition independent of aws_security_group
  * Update CHANGELOG for #14616
  * add back removed newline in CHANGELOG
  * Update CHANGELOG for #14614
  * Update CHANGELOG for #14545
  * data-source/aws_lb: Add `subnet_mapping` `private_ipv4_address` attribute (#14545)
  * Update CHANGELOG for #14532
  * resource/aws_codebuild_project: Adding codebuild.EnvironmentTypeWindowsServer2019Container as a valid option for Codebuild environment type (#14532)
  * tests/provider: Update resource testing to 0.12 syntax (P Resources)
  * tests/provider: Update resource testing to 0.12 syntax (O Resources)
  * tests/provider: Update resource testing to 0.12 syntax (N Resources)
  * tests/provider: Update resource testing to 0.12 syntax (M Resources)
  * Use availability zone config func.
  * Use availability zone config func.
  * Add availability zones config
  * Add availability zone config func
  * deps: Remove direct dependencies on github.com/hashicorp/vault and github.com/hashicorp/errwrap (#14612)
  * Update CHANGELOG for #14583
  * data-source/aws_launch_configuration: Add 'ebs_block_device.no_device' attribute (#14583)
  * fix forced resource recreation due to rule block force-new arguments
  * fix forced resource recreation due to rule block force-new arguments
  * add formatted documentation and new test
  * Update CHANGELOG for #14590
  * Update CHANGELOG for #14584
  * Update CHANGELOG for #14528
  * resource/aws_organizations_policy: Support AISERVICES_OPT_OUT_POLICY for the organization policy (#14528)
  * tests/provider: Replace 'randIntRange' with 'acctest.RandIntRange'. (#14589)
  * feat: Add a deprecated _import_commenter
  * fix typo
  * Prune internalized helper packages
  * Internalize SDKv1 deprecated helper packages
  * feat: Migrate remained legacy codes
  * refactor: Internalize hashcode.String from deprecation
  * Update CHANGELOG for #14599
  * tests/provider: Update resource testing to 0.12 syntax (L Resources)
  * tests/resource/aws_ecs_service: Fix TestAccAWSEcsService_withMultipleTargetGroups (#14586)
  * Update module bflad/tfproviderlint to v0.17.0 (#14594)
  * d/aws_launch_template: Change 'network_interfaces.delete_on_termination' to TypeString, matching associated resource.
  * d/aws_launch_template: Add 'TestAccAWSLaunchTemplateDataSource_networkInterfaces_deleteOnTermination'.
  * Update CHANGELOG for #14493
  * resource/aws_accessanalyzer_analyzer: Support ORGANIZATION value in type argument (#14493)
  * tests/provider: Update resource testing to 0.12 syntax (E Resources) (#14423)
  * tests/provider: Update resource testing to 0.12 syntax (C Resources) (#14419)
  * safely handle nil resourcerecord or resourcerecord.name received from DesribeCertificate call
  * Corrects script documentation
  * Moves Terraform validation to website GitHub workflow
  * tests/provider: Update resource testing to 0.12 syntax (Glue Resources)
  * tests/provider: Update resource testing to 0.12 syntax (G Resources except Glue)
  * safely handle nil encryption information returned from API
  * tests/provider: Update resource testing to 0.12 syntax (F Resources)
  * Add a variable detectorResourceName
  * Use aws.StringValue instead of direct pointer manupulation
  * Define the function to create the GuardDuty Filter's ID
  * Use parseImportedId
  * Make test data simple and move the resource under test to the top of the configuration
  * Check for too many parts as well
  * Change pointer
  * Simplify flattenFindingCriteria
  * Fix the style in document
  * Replace strings to constants defined in the AWS SDK
  * Fix the error handling
  * Fix the error handling
  * Fix the error handling
  * Remove the timeout setting
  * Update aws/resource_aws_guardduty_filter.go
  * Remove deprecated 'sidebar_current'
  * Fix a lint error AWSR002
  * Add test for finding_criteria
  * Use resource.TestCheckResourceAttrPair to verify that the correct value is set
  * Add test to cover updating values
  * Rephrase an error message
  * Update the fmt.Errorf calls to return the error object itself using the %%w directive
  * Use keyvaluetags package
  * Add a validator for a maximum length of 512
  * Add a validator for a minimum length of 3, maximum length of 64
  * Add the subcategory "GuardDuty"
  * Removed obsolete tests cases
  * Updated the resource to work with the new provider version
  * Tiny stylefix
  * Added the documentation
  * Improved tests
  * Added tests for GuardDuty filter
  * Implemented a better error output
  * Fixed create/update case where one field can contain more than one condition
  * Just moved things around
  * Dryed up the flattening functions
  * Made import work also for Finding Criteria
  * Fixed map with possible conditions
  * Implemented a mock of  flattening of the finding criteria
  * Gofmt with -s fixes
  * Gofmt fixes
  * Added import function without the findingCriteria
  * Moved a function
  * Made Id of GD filter to be a compounded one
  * Cleaned up comments
  * Implemented on-the-flight validation for the conditions
  * Added validations for generic cases
  * Cleaned up the action default and unveiled the update action
  * Added the update action for the guardduty filter
  * Made different sort of conditions work
  * Changed the format of guard_duty_filter criterion
  * Extracted buildFindingCriteria
  * Filled in finding criteria
  * Implemented DELETE action for filters
  * Made create request work for region only condition
  * Fixed tags assignment
  * Added tags field for creation
  * Made Create action to make its way to the API request
  * Made Create action uncommented and not crashing
  * Fixed or workarounded syntax errors
  * Added a partially copied, partially corrected resource file
  * Update CHANGELOG.md
  * add configurable user-agent information
  * Update module bflad/tfproviderlint to v0.16.0 (#14552)
  * Upgrade to TF SDKv2 (#14432)
  * Fixes return code and disables additional tflint rule
  * Renames action
  * Adds GitHub action for linting documentation
  * Updates syntax and additional fixes identified by tflint
  * tests/resource/aws_ses_identity_policy: Fix TestAccAWSSESIdentityPolicy_* tests (#14524)
  * service/eks: Update EKS tests for new versions and supported regions (#14533)
  * service/eks: Remove references to AmazonEKSServicePolicy (#14521)
  * docs/resource/aws_autoscaling_group: Change type of target_group_arns in docs from list to set (#14538)
  * update most_recent test to split up snapshot resources
  * update engine without versioning restrictions for cloudwatch
  * add redshift cluster snapshot sweeper
  * Cleanup after v3.1.0 release
- from version 3.1.0
  * Update CHANGELOG for #14520
  * Update aws/resource_aws_ecr_repository.go
  * Adds encryption configuration to ECR repository resource and data source
  * docs/data-source/aws_iam_policy_document: Small fix (#14515)
  * remove auth error handling for non-s3-import or snapshots
  * use %%w for errors
  * add tag ignore
  * use sdk wrapper and simplify sets
  * move note
  * add clarification for tags
  * add read + update tag support + test for tags
  * add read + update tag support + test for tags
  * Update module aws/aws-sdk-go to v1.33.21 (#14000)
  * Update CHANGELOG for #14490
  * resource/aws_rds_cluster: Consolidate CreateDBCluster logic and prevent creation issue when global_cluster_identifier and replication_source_identifier are both configured (#14490)
  * Update CHANGELOG for #14487
  * resource/aws_rds_global_cluster: Add force_destroy and source_db_cluster_identifier arguments, add global_cluster_members attribute (#14487)
  * tests/resource/aws_rds_cluster: Fix and standardize TestAccAWSRDSCluster_EncryptedCrossRegionReplication (#14491)
  * Update CHANGELOG for #14459
  * resource/aws_secretsmanager_secret: Allow retries for IAM eventual consistency errors (#14459)
  * Update CHANGELOG for #14215
  * tests/resource/aws_route53_zone_association: Remove unused testAccCheckRoute53ZoneAssociationDisappears function
  * service/route53: Finalize cross-account VPC association handling
  * tests/provider: Add checks for docs/ and ensure website/ checks catch .md files (#13655)
  * Update CHANGELOG for #14481
  * service/s3: Passthrough provider s3_force_path_style configuration for s3manager.GetBucketRegion calls (#14481)
  * Correction after rename of aws_availability_zones data source.
  * r/aws_instance: Add 'testAccPartitionPreCheck' and use in 'TestAccAWSInstance_multipleRegions'.
  * Revert "r/aws_instance: Delete 'TestAccAWSInstance_multipleRegions'."
  * d|r/aws_instance: Include changes from #13361.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_atLeastOneOtherEbsVolume'.
  * r/aws_instance: Rename 'TestAccAWSInstance_basic' to 'TestAccAWSInstance_atLeastOneOtherEbsVolume'. Add new 'TestAccAWSInstance_basic'. Remove hardcoded AMI ID from 'TestAccAWSInstance_disappears', plus #13527.
  * r/aws_instance: 'TestAccAWSInstance_rootBlockDeviceMismatch' can only run in `us-west-2`.
  * r/aws_instance: Delete 'TestAccAWSInstance_multipleRegions'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_changeInstanceType'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_volumeTags' and 'TestAccAWSInstance_volumeTagsComputed'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_tags'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_noAMIEphemeralDevices'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_rootInstanceStore'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_blockDevices', 'TestAccAWSInstance_EbsRootDevice_MultipleBlockDevices_ModifySize', 'TestAccAWSInstance_EbsRootDevice_MultipleBlockDevices_ModifyDeleteOnTermination'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_GP2WithIopsValue'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_GP2IopsDevice'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_userDataBase64'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_RootBlockDevice_KmsKeyArn'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_EbsBlockDevice_KmsKeyArn'.
  * r/aws_instance: Remove hardcoded AMI ID from 'TestAccAWSInstance_inEc2Classic'.
  * tests/resource/aws_autoscaling_group: Use Amazon Linux for web server testing (#14409)
  * Fix data source test configs (up to s3 bucket)
  * Fix acc test configs (up to VPC endpoint)
  * Fix acc test configs (up to workspaces)
  * Fix data source config formatting, 0.12 up to regions
  * Update CHANGELOG for #14475
  * internal/naming: Fix NamePrefixFromName with hex suffix. (#14475)
  * docs/resource/aws_cloudhsm_v2_cluster: Various grammar and formatting fixes (#14463)
  * Update module bflad/tfproviderlint to v0.15.0 (#14477)
  * resource/wafv2_web_acl: Fix documentation for excluded_rule
  * Change aws_fsx_lustre_file_system's network_interface_ids to TypeList to preserve ordering.
  * add docs
  * add support for `automatic_backup_retention_days` use %%w for errors
  * wait for update
  * change disappears test
  * resource/aws_route53_zone_association: Fix tests, update docs/test config to Terraform 0.12 format
  * resource/aws_route53_zone_association: Apply suggested changes
  * Update CHANGELOG for #14420
  * Update CHANGELOG for #12479
  * Update CHANGELOG for #12759
  * Update CHANGELOG for #12651
  * update test configs with resource refs
  * Update module bflad/tfproviderdocs to v0.7.0 (#14436)
  * tests/provider: Use SDK v2 compliant ExpectError conditions (#14434)
  * Update CHANGELOG for #14368
  * data-source/aws_ecr_repository: Make `registry_id` optional to allow to filter by account + add missing attributes (#14368)
  * Update CHANGELOG for #14367
  * resource/aws_vpc_dhcp_options: Add disappears tests + prevent error when vpc is deleted out of terraform (#14367)
  * use new provider incantation
  * data-source/aws_ec2_spot_price: Add missing underscores to test names
  * Update CHANGELOG for #13326
  * resource/aws_ssm_parameter: Omit data_type default, add special aws:ec2:image error handling during read, and acceptance test aws:ec2:image data_type
  * Update CHANGELOG for #11404
  * resource/aws_lb: Address PR review feedback
  * Update CHANGELOG for #12504
  * New Data Source: aws_ec2_spot_price (#12504)
  * Update CHANGELOG for #14092
  * resource/aws_elastictranscoder_present: Prevent empty configuration block panics (#14092)
  * Update CHANGELOG for #14412
  * data-source/aws_availability_zones: Fix group_names attribute to be Computed instead of Optional (#14412)
  * Cleanup after v3.0.0 release
- from version 3.0.0
  * Update CHANGELOG for #14175
  * Updates provider for multiregion tests and adds OAuthToken to CodePipeline Webhook tests
  * Revert "Removes hashing from GitHub `OAuthToken` and marks `configuration` sensitive"
  * Removes hashing from GitHub `OAuthToken` and marks `configuration` sensitive
  * Adds Version 3 Upgrade documentation
  * Updates `PreCheck` to try API call in acceptance test regions
  * Updates tests for GovCloud
  * Adds disappears test and cleans up test configurations
  * Updates usage example in documentation for Terraform 0.12
  * Removes `GITHUB_TOKEN` environment variable requirement for CodePipeline and adds drift detection to GitHub action OAuthToken
  * Code cleanup
  * tests/provider: Update resource testing to 0.12 syntax (B Resources) (#14418)
  * tests/provider: Update resource testing to 0.12 syntax (D Resources)
  * update expected key/value dictionary in check steps
  * update expected config line breaks
  * Update CHANGELOG for #14220
  * Update CHANGELOG for #14214
  * resource/aws_cloudwatch_log_group: Automatically trim :* suffix from ARN in API response (#14214)
  * bring back trimming of name at import time
  * update route53 record to allow trailing period in name and revert acm cert computed attr val
  * Fix config for data sources
  * Fix config for data source tests
  * Fix config for tests
  * Fix config for data source tests
  * Fix config formating for data sources
  * remove iam_role_arn from acctest
  * revert 0d61434c8e0b3fc3de13b2053f6026a4eeb99670
  * remove iam_role_arn from acctest
  * CR updates to remove custom period handling and add validation instead
  * Update naming to conform with convention
  * Move semaphore notify to test cleanup (#14381)
  * Enables `tflint` for examples and fixes issues
  * Update CHANGELOG for #14339
  * Updates documentation formatting to Terraform 0.12 syntax
  * Remove hardcoded AZs and AMIs from ASG
  * Add AZ standard config functions
  * update documentation wording
  * update upgrade guide with attribute change
  * update computed field naming and removal of internal/flatmap
  * Update module golangci/golangci-lint to v1.29.0 (#13789)
  * Stop using provider alias, use name/factory (#14312)
  * tests/provider: Workaround unused U1000 reports caused by t.Skip() usage (#14241)
  * Update CHANGELOG for #14187
  * resource/aws_iam_server_certificate: Remove state hashing from certificate_body, certificate_chain, and private_key arguments (#14187)
  * resource/aws_spot_fleet_request: Capture additional IAM eventual consistency error during RequestSpotFleet (#14358)
  * Remove hardcoded AMI ID from aws_route_test
  * Update CHANGELOG.md
  * Update CHANGELOG.md for #14316
  * Update aws/resource_aws_spot_fleet_request_test.go
  * fix role name
  * fix depends
  * rebase and refactor
  * fix `target_capacity`
  * remove hardcoded params
  * add import to test
  * fmt
  * zero capacity update wait for modification to complete
  * Update CHANGELOG.md for #13266
  * Restore Gov Cloud spot prices.
  * revert domain name trim at Create time and update docs
  * Remove hardcoded AMI ID in 'testAccAwsEc2InstanceConfigDynamicEBSBlockDevices'.
  * tests/resource/aws_rds_cluster: Fix TestAccAWSRDSCluster_Port (#14341)
  * Updates documentation formatting to Terraform 0.12 syntax
  * Attribute correction
  * Remove hardcoded AMI IDs from data_source_aws_instance_test
  * r/aws_volume_attachment: Replace 'data aws_ec2_instance_type_offering available {}' with 'testAccAvailableEc2InstanceTypeForAvailabilityZone'.
  * r/aws_storagegateway_gateway: Replace 'data aws_ec2_instance_type_offering available {}' with 'testAccAvailableEc2InstanceTypeForAvailabilityZone'.
  * r/aws_spot_fleet_request: Replace 'data aws_ec2_instance_type_offering available {}' with 'testAccAvailableEc2InstanceTypeForRegion'.
  * r/aws_cloudwatch_metric_alarm: Replace 'data aws_ec2_instance_type_offering available {}' with 'testAccAvailableEc2InstanceTypeForAvailabilityZone'.
  * r/aws_ami_from_instance: Replace 'data aws_ec2_instance_type_offering available {}' with 'testAccAvailableEc2InstanceTypeForRegion'.
  * r/aws_eip: Replace 'data aws_ec2_instance_type_offering available {}' with 'testAccAvailableEc2InstanceTypeForAvailabilityZone'.
  * Updates documentation formatting to Terraform 0.12 syntax
  * Add 'testAccAvailableEc2InstanceTypeForAvailabilityZone' config generator.
  * re-add check step
  * rename field to workaround state migration
  * fixup acctests with trailing period and documentation
  * parent b69af0579e0415631faa9b77559a55a5f6e7c208 author Brian Flad <bflad417@gmail.com> 1594769808 -0400 committer Angie Pinilla <angelinepinilla@gmail.com> 1595878294 -0400
  * Update CHANGELOG for #14221 and other minor formatting fixes
  * Update provider's S3 bucket lookup to use GetBucketRegion utility (#14221)
  * Updates missed configurations
  * Missed old style formatting
  * Updates documentation formatting to Terraform 0.12 syntax
  * Update CHANGELOG for #14259
  * resource/aws_appautoscaling_target: Remove  DeregisterScalableTarget retries on all errors and add disappears test (#14259)
  * Update CHANGELOG for #12643
  * docs/resource/aws_security_group: Update `cidr_blocks` value to list (#14329)
  * Updates documentation formatting to Terraform 0.12 syntax
  * Fixes errors from upgrade
  * Remove hardcoded AMI IDs
  * Update CHANGELOG for #14144
  * service/directconnect: vpn_gateway_id Argument Removals and Increase aws_dx_gateway_association Default Timeouts (#14144)
  * Update CHANGELOG for #14262
  * resource/aws_sns_topic_subscription: Use paginated ListSubscriptionsByTopic and return immediately on errors (#14262)
  * refactor tests
  * add cloudfront section to upgrade guide
  * refactor tests
  * revert validation for `authorizer_uri`
  * Updates data source documentation to 0.12 syntax
  * use set len func
  * add validation for `authorizer_uri`, `authorizer_credentials` changes for %%w remove deprecated func
  * add support for zero ttl
  * resource/aws_cloudfront_distribution: Ensure we are catching d.Set("active_trusted_signers", ...) error
  * resource/aws_cloudfront_distribution: go fmt and minor documentation fixes
  * resource/aws_cloudfront_distribution: Fix `active_trusted_signers` attribute for Terraform 0.12
  * fix lint
  * Updates general documentation
  * added default: text
  * Update CHANGELOG for #14303
  * resource/aws_iam_instance_profile: Remove deprecated roles argument (#14303)
  * Update CHANGELOG for #14296
  * resource/aws_glue_job: Remove deprecated allocated_capacity argument (#14296)
  * Update CHANGELOG for #14238
  * provider: Remove deprecated kinesis_analytics and r53 custom endpoint arguments (#14238)
  * Update CHANGELOG for #14299
  * resource/aws_iam_access_key: Remove deprecated ses_smtp_password attribute (#14299)
  * added @bflad suggestions
  * provider: Initial snapshot build workflow (#14140)
  * tests/provider: Ensure awsproviderlint source is dependency and lint checked (#14131)
  * Update CHANGELOG for #14294
  * resource/aws_cognito_user_pool: Remove deprecated admin_create_user_config.unused_account_validity_days argument (#14294)
  * Update CHANGELOG for #14309
  * resource/aws_lb_listener_rule: Remove deprecated condition configuration block field and values arguments (#14309)
  * Update CHANGELOG for #14311
  * resource/aws_ssm_maintenance_window_task: Remove deprecated logging_info and task_parameters configuration blocks (#14311)
  * Got it!
  * docs/resource/aws_codebuild_project: Add SECRETS_MANAGER to the CodeBuild environment_variable type (#14200)
  * Implement Disappears test for API Gateway resources (#13243)
  * Update CHANGELOG for #14199
  * resource/aws_acm_certificate: Convert domain_validation_options to TypeSet and calculate elements during plan (#14199)
  * Add deployment type to aws_fsx_lustre_file_system
  * Removes error added for testing
  * Drops checks for warnings
  * Try anything
  * Again
  * One step back
  * Baby steps
  * Step-by-step
  * Echoes warning count
  * Update CHANGELOG.md for #13809
  * Adds back jq
  * Add back terraform validate -json
  * Resetting warning test to debug it
  * Simplify warning check since it will exit on syntax errors
  * r/aws_apigatewayv2_integration: Add acceptance test for Lambda integration with HTTP API.
  * Updates warning equality
  * Tightens warning check
  * Revert "r/aws_apigatewayv2_integration: No need for diff-suppression for new resources."
  * r/aws_apigatewayv2_integration: No need for diff-suppression for new resources.
  * r/aws_apigatewayv2_integration: Suppress integration_method diff for AWS Lambda integrations.
  * Remove hardcoded AMIs and AZs
  * Wraps jq result in quotes to force it into a string to avoid "unary operator expected" error
  * Update CHANGELOG with Go versioning
  * Fixes bash conditional
  * Only check for warnings if there are no errors
  * Restore `terraform validate` output
  * Updates example action workflow to validate only with Terraform 0.12. Adds error for testing
  * Update CHANGELOG for #14310
  * Update CHANGELOG for #14291
  * resource/aws_lambda_function: Increase IAM retry timeout for create to 2 minutes (#14291)
  * improve upgrade docs for iops
  * Remove hardcoded AMIs and AZs
  * Remove hardcoded AMIs and AZs
  * Update CHANGELOG for #14230
  * Remove hardcoded AMI and AZ
  * Improve static check for hardcoded partition in ARN
  * storage capacity for hdd needs to be at least 2000
  * storage capacity for hdd needs to be at least 2000
  * Updates workspaces example
  * error when iops provided for unsupported type
  * Updates two-tier example
  * Updates transit-gateway-cross-account-vpc-attachment example
  * Updates transit-gateway-cross-account-peering-attachment example
  * Updates sagemaker example
  * Updates s3-cross-account-access
  * Updates s3-api-gateway-integration example
  * Updates rds example
  * Updates networking example
  * Updates lambda-file-system example
  * Updates lambda example
  * Updates elb example
  * Updates elasticsearch-domain example
  * Updates eks-getting-started example
  * Updates eip example
  * Updates ecs-alb example
  * Updates dx-gateway-cross-account-vgw-association example
  * Updates count example
  * Updates cognito-user-pool example
  * Updates cloudwatch-events kinesis and sns examples
  * Updates cloudhsm example
  * Updates asg example
  * Update CHANGELOG.md
  * Update CHANGELOG.md for #13013
  * Update CHANGELOG.md
  * Update CHANGELOG.md for #13833
  * Update CHANGELOG.md for #14080
  * Updates api-gateway-websocket-chat-app example
  * Updates alexa example
  * add support for storage type
  * Update CHANGELOG.md for #13644
  * tests/resource/aws_rds_cluster: Fix TestAccAWSRDSCluster_EngineVersion (#14286)
  * Update CHANGELOG for #14261
  * resource/aws_network_acl_rule: Immediately return DescribeNetworkAcls errors on creation (#14261)
  * Update CHANGELOG for #14263
  * resource/aws_ssm_activation: Only retry CreateActivation on IAM eventual consistency error, allow retries for standard 2 minutes (#14263)
  * Update CHANGELOG for #14264
  * resource/aws_codepipeline: Only retry CreatePipeline errors for IAM eventual consistency (#14264)
  * Update CHANGELOG for #14265
  * resource/aws_spot_fleet_request: Only retry RequestSpotFleet on IAM eventual consistency errors, use standard 2 minute timeout (#14265)
  * resource/aws_launch_configuration: Remove DescribeLaunchConfigurations retries on all errors (#14260)
  * tests/provider: Enable AWSAT004 check for CI (#14216)
  * Fix schema set errors (#14167)
  * Update CHANGELOG.md for #12676
  * Add unit tests for TestCheckTypeSetElemAttrPair
  * r/aws_apigatewayv2_stage: Change 'route_setting.logging_level' to computed to address different defaults for WebSocket vs. HTTP.
  * Update CHANGELOG for #14266
  * update import ID pattern
  * Fix mess from rebase.
  * Revert "r/aws_apigatewayv2_stage: Add computed 'api_protocol_type' attribute."
  * Revert "r/aws_apigatewayv2_stage: Pass API protocol type to 'flattenApiGatewayV2RouteSettings'."
  * r/aws_apigatewayv2_stage: Pass API protocol type to 'flattenApiGatewayV2RouteSettings'.
  * r/aws_apigatewayv2_stage: Add computed 'api_protocol_type' attribute.
  * r/aws_apigatewayv2_stage: Additional route_settings and default_route_settings test cases.
  * r/aws_apigatewayv2_stage: No need for diff-suppression for new resources.
  * r/aws_apigatewayv2_stage: 'data_trace_enabled' and 'logging_level' are only valid for WebSocket APIs.
  * r/aws_apigatewayv2_integration: Additional import test step in 'TestAccAWSAPIGatewayV2Integration_VpcLinkHttp'.
  * Update CHANGELOG for #14268
  * Update CHANGELOG for #10520 and #10521
  * Add function to check TypeSet pairs
  * Update website/docs/r/fsx_windows_file_system.html.markdown
  * Update website/docs/r/fsx_windows_file_system.html.markdown
  * Update website/docs/r/fsx_windows_file_system.html.markdown
  * tests/resource/aws_rds_cluster: Remove aws_s3_bucket region argument from TestAccAWSRDSCluster_s3Restore (#14272)
  * update default value for min_capacity in scaling_configuration block of rds_cluster
  * add support for `SINGLE_AZ_2` type
  * keep throttling disabled by default in api gateway method settings resource
  * tests/resource/aws_s3_bucket: Add S3 Same-Region Replication acceptance test (#10170)
  * docs/provider: Document max_retries default (#14256)
  * docs/provider: Setup and document release/* branch convention, link 2.x and earlier changelog entries (#14177)
  * Update ROADMAP.md to fix formatting omissions
  * r/aws_apigatewayv2_stage: Make deployment_id a computed attribute.
  * r/aws_apigatewayv2_integration: Test HTTP API VPC Link integration.
  * Revert "Remove 'tls_config' attribute. It doesn't seem to do anything right now."
  * Update CHANGELOG for #13062
  * remove currently in progress in case it causes confusion
  * fix milestone link
  * add old roadmap section
  * add-q3-roadmap-draft
  * Update Terraform github to v2.9.2 (#14021)
  * provider: Remove unnecessary fmt.Sprint()/fmt.Sprintf() (#14242)
  * fix lint issue
  * disappears
  * fix multi az test
  * remove computed
  * fix docs
  * add docs
  * add computed flag to deployment_type
  * add deployment type to test
  * add plan time validation to `self_managed_active_directory.dns_ips`
  * Add underscore to acceptance test names, minor naming convention fixes
  * Removed hardcoded AMIs and AZs
  * Remove hardcoded AMI and AZ
  * Ignore hardcoded AMI because not actually used
  * Remove hardcoded AMI
  * add atleastoneof property to filter attributes
  * consolidate maintainer lists
  * set virtual attributes in import func
  * Resolve linting issues
  * adjust error messaging
  * Cleanup go.sum changes
  * resource/aws_route53_zone_association: Support for cross account zone associations
  * adjust error messaging
  * Update CHANGELOG for #12876
  * resource/aws_lambda_alias: Finalize resource import adjustments
  * docs/resource/aws_codebuild_webhook: Add COMMIT_MESSAGE to acceptable codebuild filter types (#14207)
  * Update CHANGELOG for #14079
  * Update CHANGELOG for #8612
  * update to using expandstringset method
  * refactor resource import
  * version 3 upgrade details
  * Update CHANGELOG for #12616
  * resource/aws_acm_certificate: Finalize subject_alternative_names change from TypeList to TypeSet
  * add angie and dirk
  * add missing validation value for comparison_operator argument
  * bump to go v1.14.5
  * rebased and addressed review feedback
  * Removing import of aws_security_group_rule for rules associated with aws_security_group implicitly during its import. Acceptance tests updated to account for removed rules in import state check.
  * adding upgrade instructions
  * Update CHANGELOG for #14127
  * resource/aws_s3_bucket: Convert region to read-only attribute (#14127)
  * tests/provider: Update testacc target to error when provided example test pattern (#14091)
  * Update CHANGELOG for #14132
  * resource/aws_msk_cluster: Update encryption_info.encryption_in_transit.client_broker default to match API default (#14132)
  * docs/service/ecs: Update wording around ECS Capacity Provider and Auto Scaling Group handling with AmazonECSManaged tag (#14069)
  * provider: Catch aws_elastictranscoder resource naming with issues correctly (#14088)
  * Update CHANGELOG for #14134
  * data-source/aws_availability_zones: Remove blacklisted_names and blacklisted_zone_ids arguments (#14134)
  * Update CHANGELOG for #14143
  * provider: New versions of the provider can only be automatically installed on Terraform 0.12 and later (#14143)
  * Update CHANGELOG for #13529
  * docs/provider: Fix copypasta error in version 3 upgrade guide
  * Update CHANGELOG for #3894 and #9685
  * resource/aws_acm_certificate: Finalize state hash removal for certificate_body, certificate_chain, and private_key arguments
  * Update CHANGELOG for #14006
  * Update CHANGELOG for #14005
  * Update CHANGELOG for #14064
  * update documentation examples
  * update documentation and affected tests
  * reintroduce changes made in #9478; remove fields from exported attributes list
  * testing all possible inputs
  * resource/aws_sns_platform_application: Finalize platform_credential and platform_princial hash removal
  * data-source/aws_lambda_invocation: Remove result_map attribute (#14125)
  * Update CHANGELOG for #12927
  * resource/aws_autoscaling_group: Finalize availability_zones and vpc_zone_identifier ConflictsWith
  * FAQ.md  Link reactions to sorted PRs and issues (#13891)
  * Update CHANGELOG for #7141
  * docs/provider: Add aws_elastic_transcoder_preset resource max_frame_rate argument default removal to version 3 upgrade guide
  * resource/aws_elastic_transcoder_preset: Add covering test for MaxFrameRate default removal and ensure it is Computed
  * Update CHANGELOG for #14137
  * resource/aws_emr_cluster: Remove `instance_group` configuration block, `core_instance_count`, `core_instance_type`, and `master_instance_type` arguments (#14137)
  * Update CHANGELOG for #9718
  * docs/provider: Add aws_spot_fleet_request resource section to version 3 upgrade guide
  * Corrects name of Workspaces Workspace sweeper
  * Update CHANGELOG for #14124
  * resource/aws_dx_gateway: Remove automatic aws_dx_gateway_association import (#14124)
  * provider: Clarify requested Terraform versions wanted in bug report issue template (#14157)
  * Update CHANGELOG for #14121
  * resource/aws_s3_bucket: Remove automatic aws_s3_bucket_policy import (#14121)
  * Update CHANGELOG.md
  * Ensure nil is not passed to RetryError helpers (#14104)
  * Update CHANGELOG.md
  * Remove "Removed" attributes (#14001)
  * update documentation attributes
  * tests/provider: Skip count example for 0.11 syntax checking
  * Update CHANGELOG for #14077
  * provider: Authentication updates for Terraform AWS Provider v3.0.0 (#14077)
  * examples/count: Update syntax to 0.12 (#11557)
  * docs/resource/aws_cloudfront_distribution: Update minimum_protocol_version documentation (#14152)
  * docs/resource/aws_msk_cluster: Fix Kafka version and some warns (#14150)
  * docs/resource/aws_lb_listener_rule: Fix headers (#13900)
  * docs/resource/aws_instance: new instance class (#13847)
  * docs/resource/aws_instance: Updated example Ubuntu AMI 14.04 -> 20.04 and variable interpolation to 0.12 syntax  (#13748)
  * docs/resource/aws_cloudfront_origin_access_identity: Remove ListBucket from policy example (#13694)
  * docs/resource/aws_dax_cluster: Update import byline (#13652)
  * docs/resource/aws_elasticsearch_domain: Update doc to emphasize that log_publishing_options block can be reused multiple times within the elasticsearch_domain resource. (#13592)
  * docs/resource/aws_instance: Fix interpolation and update example to latest LTS (#13482)
  * docs/resource/aws_secretsmanager_secret: KMS key alias is not acceptable (#13303)
  * Update kms_secrets.html.markdown - add example for AWS CLI v2 (#13224)
  * Removed hardcoded AMI IDs from AutoscalingAttachment
  * Remove hardcoded AMI IDs from launch_config data source
  * Fix multiline pattern in an example. (#12563)
  * docs/resource/aws_s3_bucket: Removing Interpolation-only expression (#12442)
  * docs/data-source/aws_vpcs: Terraform 0.12 syntax (#12278)
  * Add static check for hardcoded AWS partition DNS suffixes
  * docs/resource/aws_ec2_transit_gateway_vpc_attachment: Non-deprecated syntax for TGW attachment example (#13602)
  * docs/resource/aws_route53_zone: Use 0.12 interpolation syntax (#14096)
  * docs/resource/aws_autoscaling_group: Update concat example for Terraform 0.12 syntax (#14126)
  * Cleanup after v2.70.0 release
- from version 2.70.0
  * Remove hardcoded AMIs in spot instance request tests
  * Add static check for hardcoded ARN partition
  * awsproviderlint: go fmt -s -w and go mod vendor (#14129)
  * fmt fix up
  * Missed semaphore Notify
  * Update CHANGELOG for #14103
  * Update website/docs/r/ec2_client_vpn_route.html.markdown
  * Update website/docs/r/ec2_client_vpn_route.html.markdown
  * Add static check for hardcoded state hashes
  * Rewrite TypeSet checks with helpers [Part 6] (#14067)
  * resource/aws_lb_target_group_attachment: Added use case of private IP outside of VPC scope (#14117)
  * Fix SetId
  * @review Fix resource and data source creation race
  * Prettify aws_workspaces_bundle data source
  * New data source: aws_workspaces_directory
  * Fixes documentation side navigation
  * change private_ips to secondary_private_ips and enable update
  * Adds synchronization to Client VPN route tests
  * Update CHANGELOG for #13950
  * Implements import operation
  * Updates Create, Read, and Delete operations and adds documentation
  * Update aws/resource_aws_ec2_client_vpn_authorization_rule.go
  * Update aws/internal/service/ec2/waiter/status.go
  * Add static check for hardcoded region and AZ
  * tests/resource/aws_sqs_queue_policy: Add disappears test (#14047)
  * tests/provider: Initial goreleaser configuration and CI workflow (#14033)
  * r/aws_apigatewayv2_integration: Add 'request_parameters' attribute.
  * add private_ips field
  * Update CHANGELOG for #14060
  * service/organizations: Support Backup policies (#14060)
  * Fix review comments
  * Update exists test function to set output
  * Add Lex Slot Type data source and resource
  * Makes acceptance tests more stand-alone
  * Fixes documentation re-ordering
  * Moves synchronization functions to experimental package
  * Adds validity check for ID parsing
  * Moves waiter and status functions to `waiter` package
  * resource/aws_launch_template: Skip extra API call during update and parallelize new tests (#14065)
  * Update CHANGELOG for #5225
  * docs/rds_cluster_instance: the engine/version should match that of the cluster (#14037)
  * Sagemaker example of "deploy your own model" (#9948)
  * enable modifying default template version to latest available
  * Cleanup after v2.69.0 release
  * CR updates
  * return error for singular data source
  * adjust error formatting and handling
  * return error for singular data source
  * return error for singular data source
  * return error for singular data source
  * Fixes synchronization for network association and consolidates test cases
  * Removes unused function
  * Fixes test name
  * Combines Client VPN tests for synchronization
  * Moves Endpoint delete waiter to waiter package. Renames some error constants
  * Fixed auto stop timeout issue
  * CR updates
  * data-source/aws_db_subnet_group: create aws_db_subnet_group data-source
  * Adds waiter for Client VPN to be deleted and removed
  * Removes unneeded Client VPN network association deletion from endpoint deletion
  * Update resource_aws_workspaces_workspace.go
  * Adds semaphore to limit concurrency of Client VPN-related acceptance tests
  * Consolidates retrieving individual Client VPN authorization rules
  * Reorganizes shared test configurations
  * remove top-level output var
  * update launch template when content or description changes and update tests
  * remove duplicate test function
  * only create new version when data changes
  * update documentation
  * add update_default_version attribute
  * updatable default version
  * Renames shared configuration functions
  * Test cleanup and update to use Terraform 0.12 syntax
  * Fixes documentation
  * Adds import documentation
  * Adds tests for multiple subnets
  * Adds correct filters to Destroy check
  * Adds import
  * Cleanup
  * Removes `route` from `aws_ec2_client_vpn_endpoint.test`
  * Handles multiple authorization groups
  * Adds waiters and `disappears` test
  * Moves Client VPN authorization rule to separate resource and adds basic test
  * Removes deprecation of `aws_ec2_client_vpn_network_association` and removes `network_association` field from `aws_ec2_client_vpn_endpoint` resource
  * Adds API resource parameter to `Exists` function
  * Authorization Rules are not required for Routes
  * Formatting cleanup
  * Authorization Rules do not require a Network Association
  * documentation
  * update to recent version
  * feedback(pr): 3rd lot
  * feedback(pr): 2nd lot
  * feedback(pr): 1st lot
  * feat(tests): write unit tests
  * feature(config): manage AWS Config Remediation Configuration
  * r/aws_apigatewayv2_route: Update route key.
  * add validation setting
  * Add home_directory_mappings and home_directory_type attributes for aws_transfer_user resource
  * re-add computed: true to subject_alternative_names attribute
  * Send the PlatformCredential if the PlatformPrincipal has changed
  * Remove hashing StateFunc on platform credential and principal
  * avoid aws-sdk-go manually updated
  * doc for data_type ssm input
  * adding data_type ssm input
  * Add acceptance test for private ipv4 address subnet mapping
  * fix subnet mapping indentation
  * typo fix
  * fmt
  * r/aws_apigatewayv2_integration: suppress diff for passthrough_behavior
  * Initial support for cross-account hosted zone associations
  * Fix documentation wording for aws_route53_vpc_association_authorization
  * Add aws_route53_vpc_association_authorization resource
  * Revert "remove DiffSuppressFunc from availability_zones"
  * explicitly say that azs conflict with vpc_zone_identifiers
  * remove DiffSuppressFunc from availability_zones
  * remove emptyAvailabilityZones test
  * autoscaling: set conflict between availability_zones and vpc_zone_identifier
  * r/aws_apigatewayv2_domain_name: Document association of a Route 53 RR.
  * Fixes aws_lambda_alias import to set function_name attribute correctly instead of function's ARN
  * fix zero ttl
  * fix zero ttl
  * Add VPC Endpoint Security Group Support
  * Update
  * Add Support for Transfer Server VPC Endpoint Type and Transfer Server User Home Directory Type / Mapping
  * allow zero value for `maximum_retry_attempts`
  * delete_on_termination on ENI has to be optional
  * Replace DyanmoDB table when local secondary index changes (#12334)
  * Add documentation for admin_user_list
  * add admin_user_list test for SG GW SMB File Share
  * add admin_user_list to SG GW SMB File Share
  * Add documentation changes
  * add support for private ipv4 addresses in subnet mapping
  * let subject_alternative_names be a set
  * Updated website docs
  * Add resource schema and test file
  * Apply go fmt
  * Fix ACM certificates update tests
  * Error when data.aws_launch_template cannot find launch template
  * Error when data.aws_ecr_repository cannot find repository
  * fix(diffDynamoDbGSI): ignore ordering of non_key_attributes in equality check to stop forced reconstruction of GSI [fixes ##3828]
  * Passed tests.
  * Add Timeouts block for api gateway vpc link.
  * Add docs for create_version
  * Fix review comments, compute version and use create_version, remove generic functions for embedded ones
  * Allow creation of everlasting spot fleet requests
  * Fix update of imported ACM certificates
  * Update to address review comments, formatting and minor fixes
  * Update to address review comments, format docs consistent with other resources.
  * Update to address review comments, move common code into resource of first use
  * Update to address review linting
  * Update to address review comments
  * Added Disabled to Route 53 health check resource
  * Add Lex intent data source and resoruce
  * Recommend specifying glue_catalog_table table_type argument
  * renaming net assoc refresh func
  * re-adding network association docs too
  * readding network assoc resource w/ deprecation message
  * adding route functionality
  * more acctest changes
  * more acc test tweaks
  * updating doc with network_association
  * r/aws_ec2_client_vpn_endpoint: Reworked endpoint resource to include network associations and authorization rules as parameters
  * another progess commit
  * initial commit
  * Remove max_frame_rate default value
* Mon Aug 10 2020 rjschwei@suse.com
- Update to version 2.69.0:
  * resource/aws_customer_gateway: Allow 4-byte ASNs (#14030)
  * awsproviderlint: Add missing AWSR002 link and docs to add these links to README (#14034)
  * Add hardcoded AMI ID check
  * docs: Fix broken ec2_tag resource link in resource tagging guide (#14023)
  * docs/resource/aws_vpc: Change instance_tenancy to default (#14026)
  * Update CHANGELOG for #13927
  * resource/aws_db_instance_role_association: Prevent immediate read after creation panic (#13927)
  * Update CHANGELOG for #12005
  * resource/aws_sfn_state_machine: Handle IAM role eventual consistency on creation + wait for delete + add `arn` attribute (#12005)
  * Update CHANGELOG for #13012
  * tests/resource/aws_route53_record: Add covering tests for updates involving health_check_id
  * Update CHANGELOG for #11335
  * tests/resource/aws_route53_record: Filter Local Zones from aws_availability_zones usage
  * Update CHANGELOG for #13922
  * resource/aws_spot_fleet_request: Increase default delete timeout to 15 minutes (#13922)
  * Update CHANGELOG for #13912
  * resource/aws_autoscaling_group: Prevent unexpected differences in `tags` for Terraform 0.11 and earlier with boolean `propagate_at_launch` values (#13912)
  * tests/service/iam: Implement aws_iam_group and aws_iam_policy sweepers, catch additional aws_iam_role and aws_iam_user (#13901)
  * tests/resource/aws_cloudtrail: Ensure covering test for removing of all event_selector configuration blocks
  * awsproviderlint: Enforce kms_key_id as ARN attribute in AWSAT001 check (#13996)
  * docs/resource/aws_cognito_user_pool_domain: terrafmt fix
  * Added the creation of the aws_route53_record to the Custom Cognito Domain example (#10196)
  * Update CHANGELOG for #10452
  * tests/provider: Ensure terrafmt check runs on website updates (#13997)
  * add misspell job
  * Update module aws/aws-sdk-go to v1.32.12 (#13803)
  * docs/resource/aws_cognito_user_pool: Remove "it's" contraction due to format error in website (#13993)
  * docs/provider: Fix various typos (#13991)
  * docs/service/docdb: Fix typos on aws_docdb_cluster/instance doc (#13987)
  * Update website/docs/r/ecs_service.html.markdown
  * add gh-action for markdown file linting
  * correct ul indentation w/MD007 rule
  * Update CHANGELOG for #12183
  * add force new details to enabled attribute in docs
  * update version
  * Update CHANGELOG for #13961
  * Update Terraform github to v2.9.0 (#13978)
  * Update CHANGELOG for #13945
  * resource/aws_backup_selection: Remove from Terraform state when Backup Plan is destroyed instead of returning error (#13945)
  * resource/aws_elasticsearch_domain: Improve handling of advanced_security_options.enabled = false
  * filter by repo rather than by org
  * run terrafmt on config
  * add additional test for operator statement
  * docs/provider: Final markdownlint fixes for MD007
  * tests/provider: Move markdownlint MD007 configuration to top
  * Update CHANGELOG for #13771
  * provider: First pass at removing non-inclusive terminology (#13771)
  * add additional nested level
  * Update CHANGELOG for #13928
  * resource/aws_db_instance: Prevent schema version 1 upgrade panic on missing state (#13928)
  * Update CHANGELOG for #13958
  * Update CHANGELOG for 13958
  * resource/aws_efs_mount_target: Continue allowing empty string in ip_address validation (#13958)
  * Rewrite TypeSet checks with new helpers [Part 4] (#13932)
  * Rewrite TypeSet checks with new helpers [Part 5] (#13934)
  * Cleanup after v2.68.0 release
  * v2.68.0
  * Update CHANGELOG for #13907
  * embed warmConfig
  * Rewrite TypeSet checks with new helpers [Part 3] (#13882)
  * Rewrite TypeSet checks with new helpers [Part 2] (#13831)
  * Rewrite TypeSet checks with new helpers (#13812)
  * Update CHANGELOG for #13935
  * resource/aws_batch_compute_environment: Remove resource from Terraform state when not found instead of returning error (#13935)
  * resource/aws_dynamodb_table: Return error instead of panic on empty CreateTable response (#13925)
  * Update CHANGELOG for #13918
  * New Data Source: aws_efs_access_points (#13918)
  * tests/resource/aws_instance: Ensure sweeper has dependencies on resources that manage EC2 Instances (#13917)
  * Update CHANGELOG for #13937
  * action-setup
  * Update CHANGELOG for #5448
  * resource/aws_cloudtrail: Handle single event selector in cloudtrail with non-default read_write_type (#5448)
  * Update CHANGELOG for #13892
  * correct retry message to match in error handling
  * correct import resource name
  * accept empty string in volume_type validation
  * Update CHANGELOG for #4855
  * resource/aws_batch_compute_environment: Support fully optional desired_vcpus and wait for updates
  * add retry error handling for SLR
  * remove unused WebACL resource name in disappears test
  * reference current AWS partition in iam role policy stmt
  * remove duplicated disappears test step
  * Update CHANGELOG for #13926
  * resource/aws_ecs_service: Add plan-time validation and prevent panics with empty `type` argument in `ordered_placement_strategy` configuration block (#13926)
  * CR updates
  * Update CHANGELOG for #13778
  * service/ec2: Additional validation and fixes for CIDR misalignment (#13778)
  * tests/resource/aws_db_snapshot: Ensure sweeper runs after aws_db_instance and skips automated snapshots (#13897)
  * docs/resource/aws_media_store_container_policy: Corrected the ARN in the Resource of the policy (#13924)
  * Update CHANGELOG for #13577
  * resource/aws_spot_fleet_request: Fix import crash on missing 'availability_zone'. (#13577)
  * Update CHANGELOG for #11463
  * resource/aws_ecs_task_definition: Prevent API ordering differences in `container_definitions` environment variables during updates (#11463)
  * Update CHANGELOG for #13136
  * resource/aws_ecs_task_definition: Support EFS Access Points and Transit Encryption (#13136)
  * MD007 changes part 5/5
  * MD007 changes part 4/5
  * update disappears test and string formatting in resource read msg
  * update test cases and attribute checks
  * update test cases and attribute checks
  * MD007 changes part 3/5
  * MD007 changes part 2/5
  * use enabled parameter in test
  * MD007 changes part 1/5
  * Update CHANGELOG for #13836
  * resource/aws_vpn_connection: Add arn attribute (#13836)
  * add note to docs
  * Update CHANGELOG for #8134 / #8652
  * resource/aws_ecs_service: Minor testing/documentation tweaks for EXTERNAL deployment controller release
  * Add note on how to use wafv2 in CloudFront
  * Update CHANGELOG for #12038
  * service/ec2: Add arn attribute and plan-time validations to aws_ami(_*) resources (#12038)
  * Update CHANGELOG for #13876
  * resource/aws_vpc_endpoint: Wait for acceptance when auto_accept is enabled (#13876)
  * tests/resource/aws_ec2_transit_gateway: Change disappears test + arn check (#13899)
  * update iam_role_policy name reference
  * Update CHANGELOG for #13858
  * resource/aws_vpc_endpoint_service: Add 'arn' attribute and tags test (#13858)
  * Update CHANGELOG for #13856
  * data-source/aws_vpc_endpoint_service: Add 'arn' attribute. (#13856)
  * markdownlint fixes
  * Update CHANGELOG for #11922
  * resource/aws_iot_topic_rule: Add error_action configuration block (#11922)
  * Update CHANGELOG for #13895
  * resource/aws_ebs_snapshot: Support resource import (#13895)
  * Update CHANGELOG for #13827
  * service/ec2: Add arn attribute to aws_vpn_gateway resources (#13827)
  * Update CHANGELOG for 13611
  * service/ec2: Add arn attribute and plan-time validations to aws_customer_gateway resources (#13611)
  * set redacted_fields to empty arr if not set
  * resource/web_acl_logging_configuration: new resource
  * split enabled and disabled configs
  * use zero values
  * provider: Add Resource Groups Tagging API service client and initial keyvaluetags support (#12587)
  * add a test step with UW disabled
  * Update CHANGELOG for #13853
  * resource/aws_vpc_endpoint: Add 'arn' attribute and tags test (#13853)
  * Update CHANGELOG for #13707
  * resource/aws_iot_policy: Support resource import & ForceNew on name (#13707)
  * Update CHANGELOG for #13852
  * data-source/aws_vpc_endpoint: Add arn attribute (#13852)
  * resource_aws_elasticsearch_domain: warm_enabled does not recreate resource
  * tests/data_source/aws_elasticsearch_domain: only assert advanced_security_options in advanced test
  * Update CHANGELOG for #13452
  * resource/aws_glue_catalog_database: Add arn attribute + disappears test (#13452)
  * resource/aws_elasticsearch_domain: internal_user_database_enabled default and docs
  * resource/aws_elasticsearch_domain: advanced_security_options error wrapping
  * Add ARN for AWS Foundational Security Best Practices (#13851)
  * Update CHANGELOG for #13840
  * service/ec2: Add arn attribute to aws_ebs_snapshot(_copy) resources (#13840)
  * Update CHANGELOG for #13849
  * resource/aws_ec2_traffic_mirror_session: Add arn attribute (#13849)
  * Update CHANGELOG for #13838
  * resource/aws_placement_group: Add arn attribute + disappears test (#13838)
  * Update CHANGELOG for #13819
  * service/ec2: Add arn attribute and plan-time validations to aws_(default_)network_acl resources (#13819)
  * Update CHANGELOG for #13811
  * resource/aws_ses_receipt_filter: Add arn attribute and plan-time validations for all arguments (#13811)
  * Mention that override_action is required for rule groups
  * Update CHANGELOG for #13871
  * resource/aws_wafv2_web_acl: Skip UpdateWebACL call on tags only updates (#13871)
  * resource/aws_elasticsearch_domain: style and test cleanup
  * resource/aws_elasticsearch_domain: return fmt.Errorf
  * examples/aws_elasticsearch_domain: formatting
  * Revert "examples/aws_elasticsearch_domain: remove interpolation syntax"
  * examples/aws_elasticsearch_domain: remove interpolation syntax
  * resource/aws_elasticsearch_domain: schema settings; resource read logic
  * docs/resource/aws_elasticsearch_domain: Update master_user_options description
  * Update website/docs/r/elasticsearch_domain.html.markdown
  * Update website/docs/d/elasticsearch_domain.html.markdown
  * Update website/docs/r/elasticsearch_domain.html.markdown
  * Update website/docs/r/elasticsearch_domain.html.markdown
  * Update website/docs/r/elasticsearch_domain.html.markdown
  * resource/aws_elasticsearch_domain: aws conversion methods; schema validation
  * Cleanup after v2.67.0 release
  * v2.67.0
  * update CHANGELOG.md to revert failed release
  * v2.67.0
  * service/secretsmanager: Fix rotation resource typo and testing
  * docs/resource/aws_secretsmanager_secret: Add more verbiage around rotation changes
  * Update CHANGELOG for #9487
  * Update CHANGELOG for #12497
  * New resource: aws_secretsmanager_secret_rotation (#9487)
  * tests/provider: Switch Outposts acceptance testing to testAccPreCheckAWSOutpostsOutposts and aws_outposts_outposts data source (#13822)
  * Update CHANGELOG for #13824
  * New Data Sources: aws_outposts_outpost_instance_type(s) (#13824)
  * Update CHANGELOG for #13825
  * New Data Sources: aws_outposts_site(s) (#13825)
  * Update CHANGELOG for #13782
  * Applies Terraform format fixes
  * Adds tweaks for acceptance tests
  * Update CHANGELOG for #12698
  * Update CHANGELOG for #12395
  * Update CHANGELOG for #13777
  * New Data Sources: aws_outposts_outpost(s) (#13777)
  * Update CHANGELOG for #13779
  * New Guide: Resource Tagging (#13779)
  * Update CHANGELOG for #13456
  * resource/aws_glue_catalog_table: Add arn attribute (#13456)
  * Update module hashicorp/go-version to v1.2.1 (#13804)
  * Update CHANGELOG for #13606
  * service/ec2: Add arn attribute and refactor disappears testing in aws_(default_)vpc_dhcp_options (#13606)
  * Update CHANGELOG for #13607
  * resource/aws_ec2_capacity_reservation: Add arn attribute + support for linux sql server `instance_platform` (#13607)
  * Update CHANGELOG for #12668
  * correct the comment about cross-subnet mounts
  * change attributes to computed
  * add support for lambda file systems
  * Update CHANGELOG for #13614
  * service/ec2: Add arn attribute and disappears testing to aws_internet_gateway (#13614)
  * Update CHANGELOG for #13648
  * resource/aws_key_pair: Add arn attribute + minor refactor (#13648)
  * Update CHANGELOG for #13649
  * resource/aws_ec2_tarffic_mirror_target: Add arn attribute (#13649)
  * Update CHANGELOG for #13650
  * service/efs: Add Availability Zone and Mount Target DNS Name attributes to aws_efs_mount_target resource and data source (#13650)
  * Update CHANGELOG for #13656
  * resource/aws_flow_log: Add arn attribute (#13656)
  * Update CHANGELOG for #13697
  * resource/aws_cloudwatch_log_stream: Support resource import (#13697)
  * docs/resource/aws_lambda_alias: Update import example to use correct resource name (#13277)
  * Add doc comment
  * Update CHANGELOG for #13081
  * resource/aws_cloudfront_origin_access_identity: Properly trigger resource recreation when deleted outside Terraform (#13081)
  * Update CHANGELOG for #13020
  * resource/aws_devicefarm_project: Support resource import (#13020)
  * Treat unset values as matched
  * fix validate func based on validation error + docs
  * no longer return default nil in error param
  * New Data Source: aws_ec2_local_gateway_virtual_interface (#13770)
  * add unparam linter to golangci config
  * tech-debt/structure: remove always nil error param from expandElastiCacheParameters func (#13668)
  * add test for `warm_type`
  * New Resource: aws_ec2_local_gateway_route (#13768)
  * use `validation.StringMatch` instead of custom validation func add validation for `volume_type`
  * New Resource: aws_ec2_local_gateway_route_table_vpc_association (#13765)
  * move es funcs to relevant file + use aws ptr funcs where needed
  * add valid values for `warm_count` in doc
  * Update resource_aws_elasticsearch_domain_test.go
  * fix doc
  * fix doc
  * dix indent
  * add support for elasticsearch warm storage
  * add support for elasticsearch warm storage
  * Update module hashicorp/terraform-plugin-sdk to v1.14.0 (#13792)
  * service/guardduty: Implement resource tagging support (#13756)
  * resource/aws_ecs_capacity_provider: Implement API deletion support (#13740)
  * internal/keyvaluetags: Create {SERVICE}GetTag generator, support EC2 list/get, use in aws_ec2_tag implementation (#13745)
  * New Data Sources: aws_ec2_local_gateway_virtual_interface_group(s) (#13767)
  * Update module aws/aws-sdk-go to v1.32.3
  * provider: Add outposts service client (#13773)
  * Add aws_wafv2_web_acl_association
  * Add aws_wafv2_web_acl data source
  * linting
  * fix typo in Access Point docs
  * data/aws_ebs_volumes: Add data source (#13751)
  * Add unit tests and rename pkg
  * Add test case for 50 ip addresses for wafv2 ipset
  * Implement TypeSet resource.TestCheckFuncs
  * docs/resource/aws_ecs_service: Remove EC2 restriction from efs_volume_configuration (#13746)
  * Add documentation for aws_db_snapshot timeouts (#13757)
  * aws_route: Retry if route not found after creating it (#13747)
  * Update module hashicorp/go-multierror to v1.1.0 (#12598)
  * service/servicediscovery: AWS Cloud Map resource tagging (#13750)
  * resource/aws_ec2_tag: Switch resource identifier separator from colon to comma to prevent confusing behavior with ARNs
  * resource/aws_ec2_tag: Finish implementation
  * CodeArtifact new service support (#13735)
  * few typos
  * internal/keyvaluetags: Support servicediscovery and worklink (#13732)
  * tests/provider: Remove TravisCI (#13730)
  * update method params in web_acl test check
  * Add roadmap to issue chooser
  * expand contributing response guidelines
  * Fix rebase change
  * Fix docs
  * Improve error message
  * Apply review comments
  * Refactor after rebase
  * Apply review comments
  * Apply changes based on review
  * Format test config
  * Fix failing build
  * Add calculated wcus attribute
  * Add documentation
  * Add rule_group_reference_statement
  * Add rate_based_statement
  * Add managed_rule_group_statement
  * Add aws_wafv2_web_acl
  * Update module aws/aws-sdk-go to v1.32.0 (#13459)
  * Fixed a typo in the "import" example
  * resource/aws_cognito_user_pool_client: Mark client secret as sensitive (#13680)
  * Add 't' branch prefix for tests (#13682)
  * tests/provider: Setup ignores for current MigrateState usage and enable linter (#13728)
  * tests/provider: Add GitHub Actions workflow for dependency changes (#13657)
  * fixed typo
  * added authorization token format check
  * Cleanup after v2.66.0 release
  * v2.66.0
  * fix maxint in validation func
  * Update autoscaling group doc
  * Add documentation
  * Bump wafv2_ip_set.address limit to match AWS
  * Typo in tag error for resourceAwsSsmParameterRead
  * remove unused var
  * remove unused return error from rule group import
  * remove unused method param
  * remove unused error return param
  * remove unused error return param
  * remove unused error return param
  * run go fmt
  * return string conversion errors
  * remove unused error return param
  * run go fmt
  * remove unused method param
  * format function w/params
  * format function w/params
  * remove unused error param
  * remove unused params
  * remove unused vars
  * run go fmt
  * remove unused params in waf resources
  * remove always nil error param from expandPolicyAttributes func
  * remove always nil error param from expandApiGatewayMethodParametersOperations func
  * remove always nil error param from expandNeptuneParameters func
  * remove always nil error param from expanddocdbparameters func
  * remove always nil error param from expandredshiftparameters func
  * remove always nil error param from expandParameters func
  * remove always nil error param
  * add in CheckDestroy for ec2_tag tests to ensure VPCs cleaned up
  * make an error message more informative
  * remove conditional tag checks for VPC, subnet, and route table, general clean up
  * docs/provider: Fix common review items links (#13646)
  * run format
  * add back missing test
  * fix ipv4 validation check
  * resource/aws_batch_job_definition: Prevent diffs when no command specified in container properties. (#13634)
  * @review Document blank owner attribute
  * @review Rephrase
  * Expand data.aws_workspaces_bundle with owner/name filtering
  * Cleanup after v2.65.0 release
  * v2.65.0
  * remove diffsuppressfunc interfering with attribute setting and update field behaviors
  * Update module hashicorp/terraform-plugin-sdk to v1.13.1 (#13604)
  * resource/aws_acm_certificate: Various small improvements and fixes (#13513)
  * Update resource_aws_instance.go
  * Update resource_aws_instance.go
  * docs
  * fmt + fix error handle for `InvalidParameterCombination`
  * resource/aws_dynamodb_table: Perform individual replica creations/deletions (#13523)
  * tests/provider: Bump GitHub Actions versions and minor adjustments to examples handling (#13534)
  * tests/provider: Small sweeper fixes (#13553)
  * Update resource_aws_instance.go
  * Update resource_aws_instance.go
  * delete TestInstanceTenancySchema unit test (?)
  * use enums
  * add arn attribute + plan time validations for: `client_cidr_block`, `server_certificate_arn` and `root_certificate_chain_arn` minor test refactors
  * apply review comments regarding constants and boolean checks
  * use AWS SDK constant for error and use conversions
  * apply S018 linter rule and add AWS SDK constants for validation
  * use AWS SDK constants where possible
  * update ebs logic after read method
  * set ebs block if root is only volume in instance
  * Fixes some acceptance test errors introduced by code review. Style clean up and updated some ARN checks to TestCheckResourceAttrPair()
  * Update api_gateway_authorizer.html.markdown
  * set ebs block device attributes in addition to the root
  * Update self_service_permissions block
  * Apply review comments
  * Documentation tweak after review.
  * Removes stray comment
  * Removes unused function
  * Removes explicit ARN checks. Other cleanups.
  * Removes ARN checks and replaces them with AttrPair checks. Removes unneeded custom checks and other cleanups.
  * Uses `resource.TestCheckResourceAttrPair` for most attributes in S3 Bucket Object data source acceptance tests. Simplifies most multi-stage tests
  * Uses Pair check function for Route 53 service discovery
  * Uses ARN testing check functions for Redshift service account data source
  * Uses ARN testing check functions for ELB service account data source
  * Uses ARN testing check functions for Cloudtrail service account data source
  * Uses ARN testing check functions for AWS Config recorder
  * Uses Account ID check function for AWS Config aggregator
  * Uses ARN testing check function for billing service account
  * Uses ARN testing check function for Redshift cluster
  * Removes custom ARN check for CloudTrail
  * docs/provider: Add Environment Variable dictionary to Maintaining Guide (#13518)
  * docs/provider: Add Acceptance Test Sweeper section to Contributing Guide (#13526)
  * Rebased
  * Moved findConfigurationSet logic into resource Read function
  * Update based on PR review feedback
  * Fix string handling
  * BAU Fix deps
  * Fix for SES configuration sets state and error handling
  * Fix typo in Athena workgroup validation regex
  * Refactor acceptance test checks
  * Update workspaces_workspace.html.markdown
  * Further clarification around the use of quoted display names.
  * Create Redshift cluster in-VPC.
  * Implement resource.TestCheckResourceAttrPair to check for pair values
  * Implement resource.TestCheckResourceAttrPair to check for pair values
  * Remove lbListenerDefaultRuleActionForward function, use lbListenerRuleActionForward instead
  * Use ActionTypeEnum instead of string values
  * Use testAccMatchResourceAttrRegionalARN instead of resource.TestCheckResourceAttrSet
  * Fix stickiness duration attirbute not changing when stickiness enabled status is set to false
  * Run make website-lint-fix in lb_listener_rule.html.markdown
  * Prevent exiting without retries if one ResourceInUse error is returned when deleting an LB TargetGroup
  * Update lb_listener_rule and lb_listener docs for weighted target groups
  * Implement weighted target group acceptance tests
  * Implement weighted target groups in aws_lb_listener_rule and aws_lb_listener
  * Cleanup after v2.64.0 release
  * v2.64.0
  * minor naming changes
  * document default value
  * reuse disappears func
  * Update security group example
  * reuse disappears func
  * revert connect ips removal
  * Update resource_aws_directory_service_directory.go
  * Update resource_aws_directory_service_directory.go
  * remove sg id
  * remove sg id
  * add attributes to data source
  * refactor test resource names
  * formatting
  * remove computed field validation
  * add `security_group_id` and `availability_zones` attributes to vpc_settings
  * add missing `connect_ips` attribute
  * add plan time validation to `customer_dns_ips` and `dns_ip_addresses` add support for SharedMSAD type
  * refactor
  * refactor tests + add disappearing test case move vpc to base config from each other config
  * Changes after review.
  * r/aws_appmesh_route: Correctly handle routes with 0 weights.
  * service/directoryservice: Fix schema error on `connect_ips` (#13395)
  * Documentation: Additional resources affected by the provider 'skip_requesting_account_id' attribute (#13507)
  * r/aws_kinesis_firehose_delivery_stream: Verify import of 'kinesis_source_configuration' and add '_disappears' test.
  * Update CHANGELOG for #13520
  * resource/aws_iot_topic_rule: Add step_functions configuration block (#13520)
  * Fixes tiny typo in logo title in README.md (#13533)
  * r/aws_kinesis_firehose_delivery_stream: Set 'kinesis_source_configuration' in Read function.
  * Use 'validation.StringInSlice' with SDK-defined string constants.
  * Revised from_email_address to remove &gt; &lt; and incorporate quotes around display name.
  * docs/resource/aws_acm_certificate: Removed erroneous use of "to" (#13531)
  * renamed variable in test
  * implemented PR change requests
  * Fixup: 'principal', not 'principle'.
  * Fixup: Change link to https and remove stray period.
  * update Read method error messaging and acctest
  * Update CHANGELOG.md
  * service/elb: Fix schema errors (#13418)
  * Update CHANGELOG.md
  * service/opsworks: Fix schema error (#13435)
  * Update CHANGELOG.md
  * service/sns: Fix schema error (#13437)
  * save name in resourcename var
  * fix error formatting
  * update destroy/exists methods with id search
  * run go fmt
  * update test random naming and disappears step
  * refine if-condition
  * add disappears conditions in Read methods of ses receipt rule resources
  * add new section on service availablity precheck
  * Update CHANGELOG.md
  * service/apigateway: Fix schema set errors (#13403)
  * docs/resource/aws_ecs_service: Remove ARN mention from capacity_provider argument (#12060)
  * Update CHANGELOG for #13515
  * resource/aws_autoscaling_group: Ignore ordering differences for `tags` argument (#13515)
  * Update CHANGELOG.md
  * service/elasticsearch: Fix schema type mismatch (#13397)
  * Update CHANGELOG for #12371
  * resource/aws_acm_certificate: Update pending DNS validation record creation time from 1 minute to 5 minutes. (#12371)
  * Removes missed test
  * Reorders parameters for ARN checks with specific account IDs
  * Renames Workspaces state functions
  * Moves WorkSpaces waiters to internal package
  * Now assumes that the required IAM role will be present for acceptance tests
  * provider: Update pull request template link to Contributing Guide (#13500)
  * EBS, for typo and rephrase error message on IOPS for non-IO1 (#13465)
  * Update CHANGELOG for #12571 and #12751
  * resource/ecs_task_definition: Ensure `efs_volume_configuration` changes are detected (#12751)
  * resource/aws_ecs_service: Assign efs_volume_configuration when present (#12571)
  * tests/resource/aws_batch_job_definition: Filter sweeper input on ACTIVE status (#13496)
  * Add missing ENHANCEMENTS header
  * Update CHANGELOG for #13464
  * resource/aws_ses_event_destination: Refresh resource state in the Read method (#13466)
  * docs/resource/aws_codestarnotifications_notification_rule: Fix invalid import command (#13486)
  * data-source/aws_lambda_invocation: Deprecate result_map attribute (#13492)
  * docs/resource/aws_rds_cluster: Sort arguments alphabetically (#13443)
  * Update CHANGELOG.md
  * service/lightsail: Fix type mismatch (#13430)
  * fixed PR change requests
  * Add aws_wafv2_rule_group data source
  * Cleanup after v2.63.0 release
  * v2.63.0
  * Update CHANGELOG.md
  * service/ssm: Fix schema errors (#13438)
  * Formatting cleanup
  * tests/service/efs: Fix infinite looping of sweepers (#13415)
  * Updates example for Terraform 0.11 compatibility. Now assumes required IAM role is present and includes instructions when not present.
  * resource/aws_network_acl: Use schema.ImportStatePassthrough (#13419)
  * tests/provider: Remove fixed aws_s3_analytics_configuration ignores from tfproviderdocs (#13448)
  * Removes old test check
  * Removes old test check
  * Removes alternate account test functions
  * Update CHANGELOG for #13440
  * Update resource_aws_cognito_identity_pool_roles_attachment.go
  * docs/resource/aws_db_instance: Clarify replicate_source_db for cross-region (#12518)
  * docs/resource/aws_db_instance: Updated character_set_name for compatibility MSSQL (#12006)
  * docs/service/rds: Replace "a RDS" with "an RDS" (#12605)
  * docs/resource/aws_elasticsearch_domain: Fix incorrect reference in example (#13451)
  * Update CHANGELOG for #13436
  * resource/aws_codebuild_webhook: Support `COMMIT_MESSAGE` value in filter types (#13436)
  * Update CHANGELOG for #13414
  * resource/aws_eks_node_group: Add force_update_version argument (#13414)
  * tests/resource/aws_batch_job_definition: Add sweeper (#13427)
  * update flatten/expand methods to handle new list values
  * Update CHANGELOG for #13404
  * Update CHANGELOG for #11960
  * Update CHANGELOG.md
  * Switch to import state passthrough (#13431)
  * Update CHANGELOG.md
  * service/ram: Fix schema error (#13402)
  * service/emr: Fix schema error (#13413)
  * Current aws_macie resources interact with Macie Classic. (#13441)
  * Update module aws/aws-sdk-go to v1.31.2 (#13399)
  * Update module hashicorp/terraform-plugin-sdk to v1.13.0 (#13429)
  * Update CHANGELOG.md
  * service/cloudwatchlog: Fix schema error (#13411)
  * add new files. Teamcity snippet
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * service/elbv2: Fix elbv2 errors by exporting attributes (#13400)
  * Update CHANGELOG for #12789
  * Update efs_file_system_policy.html.markdown
  * add import support add disappears test
  * Format test config
  * Default 1500 capacity can be increased on request
  * Add documentation
  * Fix state diff caused by api returning lowercase
  * Add mssing retries and set correct validation
  * Rules get ordered by priority
  * Small refactorings
  * Use computed lock token
  * Add regex pattern set reference statement
  * Add ip set reference statement
  * Fix test according to statement depth
  * Add xss match statement
  * Add sql injection match statement
  * Add size constraint statement
  * Add logical statements
  * Temporarly prevent schema changes to break tests
  * Refactor schema
  * Rules are not depending on order
  * Add byte match statment field to match
  * Add byte match statement
  * Add rule action
  * Add geo match statement
  * Add new resource aws_wafv2_rule_group
  * Fix docs
  * Update CHANGELOG for #13407
  * Clarify CloudFront usage
  * Clarify CloudFront usage
  * Fix docs
  * Apply review comments
  * Add documentation
  * Add aws_wafv2_regex_pattern_set data source
  * resource/aws_eks_node_group: Only pass ReleaseVersion during UpdateNodegroupVersion if changed (#13407)
  * Update CHANGELOG for #13382
  * resource/aws_network_acl: Fix issue with updating subnet associations returning InvalidAssociationID.NotFound (#13382)
  * Update CHANGELOG for #12284
  * Fix docs
  * Update docs
  * Apply review comments
  * Fix docs
  * Apply review comments
  * Remove error message condition
  * Apply review comments
  * Apply changes based on review
  * Duplicate code
  * Regex has 200 character limit
  * Regex not required on creation
  * Format config code
  * Retry in case association is being removed
  * Cleanup
  * Make user aware of optimistic lock exception
  * Add docs
  * Add resource aws_wafv2_regex_pattern_set
  * Update CHANGELOG for #12788
  * add golang version update section
  * update URLs for permanently moved sites
  * add extra nil check and correct existing one
  * remove commented out function
  * handle empty expiration
  * run go fmt
  * update disablebinary flag in test and ptr value conversions
  * update from typset to typelist with maxitems of 1
  * update hash strings for secondary_sources
  * change auth attributes to typelist with maxitems of 1 and remove disablebinarydriver flag where applicable
  * tests/resource/aws_db_cluster_snapshot: Add sweeper (#13301)
  * add back binarydriver flag
  * change attribute type to handle update diffs
  * use typelist for attributes with maxitems of 1 and remove DisableBinaryDriver refs
  * provider: Implement examples label (#13325)
  * provider: First batch of unparam linter fixes (#13279)
  * resource/aws_secretsmanager_secret: Move hardcoded timeout to waiter package, allow retries in CheckDestroy (#13183)
  * tests/provider: Add misspell to CHANGELOG GitHub Action workflow (#13249)
  * Update CHANGELOG for #13293
  * resource/aws_iot_topic_rule: Implement tagging support (#13293)
  * docs/contributing: Add Resource Policy Support section, fix tagging documentation heading level (#13322)
  * hashibot: Labeling for top level Markdown files and docs/ directories (#13324)
  * service/eks: markdownlint MD007 fixes (#13356)
  * tests/provider: Add Terraform Provider GitHub Actions workflow (#13248)
  * Update glue_connection.html.markdown
  * arn
  * Use resource.TestCheckResourceAttrPair for security_group_id
  * remove DisableBinaryDriver refs in tests
  * remove DisableBinaryDriver refs in tests
  * Make retry timeout a static 5 minutes
  * Better docs thanks to bflad
  * Remove timeout docs
  * Remove configurable timeouts
  * docs/resource/aws_eks_node_group: Add ignore_changes example, similar to aws_ecs_service resource (#13378)
  * Update CHANGELOG for #13376
  * resource/aws_ecs_service: Add `force_new_deployment` argument and support in-place updates for `ordered_placement_strategy` and `placement_constraints` (#13376)
  * service/eks: Fix testing and eks-getting-started example for EKS API change (#13323)
  * Adjust CHANGELOG formatting for #13362
  * Update CHANGELOG for #11965
  * service/efs: New Resource and Data Source for EFS Access Point (#11965)
  * Add additional validation on sg rule attributes
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * service/asg: Fix schema panic in ASG tags (#13360)
  * Update CHANGELOG.md
  * service/rds: Fix schema panic errors (#13362)
  * move mysql tarball to ./aws/testdata (#13333)
  * Update docs
  * Add extra checks
  * Add missing attributes
  * Add documentation
  * Add aws_wafv2_ip_set data source
  * Update module aws/aws-sdk-go to v1.31.0 (#13358)
  * run go fmt
  * run go fmt
  * remove DisableBinaryDriver refs in tests
  * pr feedback
  * Update CHANGELOG for #12119
  * docs/provider: Various documentation updates for aws_cloudfront_distribution and codecommit (#13319)
  * Disable binary driver for missed tests (#13359)
  * docs/contributing: Initial Resource and Data Source Acceptance Testing sections (#13332)
  * style: Add spacing between principal blocks
  * add docs
  * Update efs_file_system.html.markdown
  * add update case
  * add docs
  * take remove custom arn handling
  * fix
  * Fix aws_security_group_rule description field overwritten to nil on TF state refresh
  * Adds custom KMS key and makes example Terraform v0.11-friendly
  * Adds acceptance test functions for cross-account resources
  * split efs policy to its own resource
  * split efs policy to its own resource
  * fmt
  * efs file system data source - add support for policy
  * add support for efs iam policy
  * add missing attributes to testcheck
  * move assume_role test to provider testing
  * Apply review changes
  * website: Add Synthetics to allowed subcategories
  * service/synthetics: Add service client (#13186)
  * Update module aws/aws-sdk-go to v1.30.28 (#13190)
  * resource/aws_launch_template: Prevent downstream resource errors with unconfigured partition numbers (#13239)
  * Provide examples of placement strategy
  * resource/aws_datasync_task: Support `ONLY_FILES_TRANSFERRED` value in `verify_mode` argument (#12897)
  * Improve nil checks
  * provider: Add Transit Gateway Network Manager service client and resource tagging (#13262)
  * infrastructure/repository: Synchronize recent AWS service labels and bump GitHub provider to latest (#13226)
  * tests/resource/aws_codebuild_project: Add testing for empty value environment variables
  * ROADMAP.md: Fix WAFv2 link (#13240)
  * Update documentation for API gateway integration.
  * Fixes errors, adds README, and makes example easier to run out-of-the-box
  * resource/code_build_project: Support `SECRETS_MANAGER` environment variable type (#12572)
  * resource/aws_codebuild_project: Support `git_submodules_config` with `GITHUB` and `GITHUB_ENTERPRISE` source types  (#13285)
  * Fixes indentation
  * Enables AWSAT001 linter for ARN attribute checks in acceptance tests
  * add branch prefix section
  * Add extra error checking
  * tests/resource/aws_sqs_queue: Add sweeper (#13244)
  * tests/resource/aws_sns_topic: Add sweeper (#13167)
  * Fix Examples Check linting error (#13300)
  * docs/resource/aws_nat_gateway: Fix for misleading subnet name (#13273)
  * docs/resource/aws_lb_listener_rule: fix "-" to "_" (#13299)
  * resource/aws_iot_topic_rule: Remove unused function
  * resource/aws_iot_topic_rule: Refactor for type safety, error checking, and preparation for top level action/error_action configuration blocks
  * resource/aws_iot_topic_rule: Finish dynamodbv2 implementation
  * Add nil check for s.UserId parameter
  * Remove extraneous lines in acc test
  * remove GoReport
  * tests/resource/aws_ecr_repository: Implement sweeper (#12834)
  * tests/resource/aws_cloudtrail: Add sweeper (#13150)
  * tests/resource/aws_flow_log: Add sweeper (#13149)
  * tests/resource/aws_route53_query_log: Skip SerializationError and AccessDeniedException for sweeper
  * Updates Glue acceptance tests to use ARN testing check functions
  * Updates IOT acceptance tests to use ARN testing check functions
  * tests/resource/aws_sns_platform_application: Add sweeper (#13168)
  * tests/resource/aws_kinesis_analytics_application: Add sweeper (#13153)
  * Updates Organizations acceptance tests to use ARN testing check functions
  * return original arn in parsing error
  * Updates Kinesis Firehose acceptance tests to use ARN testing check functions
  * tests/resource/aws_ses_receipt_rule_set: Add sweeper (#13169)
  * Remove error message condition
  * tests/resource/aws_glacier_vault: Add sweeper (#13184)
  * tests/resource/aws_iot_topic_rule: Add sweeper (#13245)
  * Updates RAM acceptance tests to use ARN testing check functions
  * tests/service/ses: Add sweepers for aws_ses_domain_identity and aws_ses_email_identity resources (#13217)
  * add S006 linter rule
  * tests/resource/aws_ses_configuration_set: Add sweeper (#13216)
  * tests/resource/aws_redshift_event_subscription: Add sweeper (#13215)
  * tests/resource/aws_neptune_event_subscription: Add sweeper (#13214)
  * fix kerims handle
  * extra blurb on roadmap
  * add community guidelines link
  * tests/resource/aws_db_event_subscription: Add test sweeper. (#13213)
  * brief triage section
  * Cleanup code and make it consistent across all handlers.
  * Bump lambda runtime Node version.
  * Update AWS SDK version.
  * Updated resource names (aws_apigatewayv2_).
  * API Gateway WebSocket chat application example
  * tests/resource/aws_budgets_budget: Add test sweeper. (#13210)
  * Update CHANGELOG for #12747
  * resource/aws_appsync_resolver: Add CachingConfig support (#12747)
  * Update enabled_cloudwatch_logs_exports description
  * Wording fix: noncurrent object versions
  * Update module bflad/tfproviderdocs to v0.6.0 (#13246)
  * Update module hashicorp/terraform-plugin-sdk to v1.12.0 (#12740)
  * r/organizations_account: tech debt: replace custom validation funcs
  * add breaking changes section
  * add elem attribute to typemaps
  * info > docs
  * FAQ revision
  * code review fixes
  * Update info/FAQ.md
  * Update info/contributing/contribution-checklists.md
  * fix waiting response tag link
  * Update info/MAINTAINING.md
  * Update info/FAQ.md
  * some FAQ changes
  * add link to the label dictionary
  * Update module bflad/tfproviderdocs to v0.5.3 (#13225)
  * Update module bflad/tfproviderdocs to v0.5.2 (#13220)
  * resource/aws_ec2_transit_gateway_peering_attachment: Finish up  implementation
  * infrastructure/repository: Lift and shift Terraform configuration for managing certain repository labels (#13212)
  * switch docs/ to info/ to appease linters
  * use disappears test func
  * refactor iam saml provider to use arn package instead of custom logic + add tests
  * add disappears test case
  * refactor argument name
  * refactor disappears func
  * add core services document
  * Initial commit for tests - WIP
  * reuse
  * remove hardcoded ami id and instance type
  * remove hardcoded ami id and instance type
  * use resource name variable
  * add missing hashibot labeler
  * fix skip test data source filter
  * randomize resource names - fix oops
  * randomize resource names
  * fix missing test
  * use enums + refactor tests
  * hashibot: Capture additional provider and test path labels for pull requests (#13209)
  * Update CHANGELOG for #13125
  * provider: Add skip_collaborators to hashibot opened_pull_request_labeler (#13204)
  * tests/provider: Initial examples checking against Terraform 0.11.14 and 0.12.24 (#13196)
  * Disable binary driver for tests with set addresses (#13194)
  * .github/workflows/issues: Remove outdated GitHub Project handling (#13205)
  * Protect against nil SizeInBytes
  * Updates Neptune acceptance tests to use ARN testing check functions
  * Suppress IPv6 state diffs
  * Q2-2020 Public Roadmap
  * fix typo
  * r/vpn_connection: Remove case-insensitive mode parameter
  * rename `multi_attach` to `multi_attach_enabled`
  * Update module aws/aws-sdk-go to v1.30.21 (#13088)
  * Update module golangci/golangci-lint to v1.26.0 (#12397)
  * Complete implementation of kinesisanalyticsv2 service client. (#13161)
  * add plan time validation to `rules.source` add tags test fix state removal when does not exist
  * Fix workspaces default role
  * Add workspaces_directory sweeper dependency on workspaces_workspace
  * New resource: aws_workspaces_workspace
  * Updates attribute tests with variables instead of strings
  * Update Roadmap Copy - 2020Q2
  * Updates SNS acceptance tests to use ARN testing check functions
  * Updates Lambda acceptance tests to use ARN testing check functions
  * move ssm validation method to resource
  * Apply review comments
  * Format test config
  * Retry in case association is being removed
  * Make user aware of optimistick lock exception
  * Apply review changes
  * Cleanup
  * Sort imports
  * Add docs
  * r/aws_route53_query_log: Add test sweeper.
  * Add tags support
  * Add import
  * Add force new test
  * Add update
  * Fix addresses
  * Basic functionality
  * correct validate fn
  * revert to using a typemap but with schema.Schema defined
  * fixing broken tests for new tagging mechanism for VPC, subnet, and route table resources
  * Updates Secrets Manager acceptance tests to use ARN testing check functions
  * Update CHANGELOG for #13141
  * Update CHANGELOG for #13054
  * support glue connection for kafka
  * enabled R009 linting rule and fixed affected resources
  * enabled S022 check and fix affected resources
  * Implement ignore-tags functionality
  * Add docs for transit gateway peering attachment accepter
  * Checks only for known parameters in destroy check. Style cleanups
  * resource/aws_api_gateway_deployment: Add triggers argument (#13054)
  * resource/aws_apigatewayv2_deployment: Add triggers argument (#13055)
  * merge changes from master for service/ec2: Add Resource & Data Source aws_ec2_transit_gateway_peering_attachment (#11162)
  * Correct type and tests for SizeInBytes to reflect that the value is an integer
  * Add size_in_bytes to efs_file_system data source
  * tests/service/ec2: Minor refactoring for EIP COIP testing
  * service/ec2: Rename aws_local_gateway_route_table(s) to aws_ec2_local_gateway_route_table(s), use AWS_OUTPOST_ARN environment variable
  * service/ec2: Rename aws_local_gateway(s) to aws_ec2_local_gateway(s), use AWS_OUTPOST_ARN environment variable for testing
  * data-source/aws_ec2_coip_pool: Include ignore tags config
  * docs/provider: Fix new aws_ec2_coip_pool(s) links in legacy sidebar
  * service/ec2: Rename aws_coip_pool(s) to aws_ec2_coip_pool(s), hide testing behind consistent AWS_OUTPOST_ARN environment variable
  * Cleanup after v2.60.0 release
  * v2.60.0
  * r/aws_redshift_snapshot_copy_grant: Remove extraneous Exists function (#13052)
  * finish removing `host_resource_group_arn`
  * drop `host_resource_group_arn` from PR expand test
  * add plan time validation for:
  * add more tests to launch template data source
  * add `host_resource_group_arn` and `partition_number` attributes to resource and data source
  * Updates WAF and WAF Regional acceptance tests to use ARN testing check functions
  * Updates Storage Gateway acceptance tests to use ARN testing check functions
  * resource/aws_glue_trigger: Remove incorrectly implemented ConflictsWith (#13110)
  * service/ec2: Add ignore tags handling to aws_ec2_transit_gateway_peering_attachment resource and data source
  * service/ec2: Minor testing fixes and improvements on failing Transit Gateway Peering Attachments
  * service/ec2: Add Resource & Data Source aws_ec2_transit_gateway_peering_attachment (#11162)
  * fix
  * fix
  * Updates SSM acceptance tests to use ARN testing check functions
  * data source docs
  * add to data source
  * fix workspaces tags
  * add docs
  * add tests
  * add `directory_name`, `directory_type`, `customer_user_name`, `alias` attributes
  * refactor to have specific tags test
  * add attributes
  * add support for multi attach
  * service/backup: Fix tfproviderlint AWSR002 errors. (#13106)
  * tests/resource/aws_db_security_group: Include EC2-Classic PreCheck
  * docs: Experimental markdown-link-check testing (#12818)
  * provider: Implement ignore tags functionality across all data sources resources (#13039)
  * service/guardduty: Support GuardDuty Organizations (#13034)
  * Updates aws_rds_cluster acceptance tests to use ARN testing check functions
  * Updates aws_rds_cluster_parameter_group acceptance tests to use ARN testing check functions
  * resource/aws_dms_endpoint: Add kafka_settings configuration block and kafka to engine_name validation (#12835)
  * Updates RDS acceptance tests to use ARN testing check functions
  * provider: Introduce shared IAM propagation timeout, refactor KMS Key creation to that timeout and add KMS Key deletion to internal waiter package (#12863)
  * r/aws_route: Remove extraneous Exists function.
  * Updates EKS acceptance tests to use ARN testing check functions
  * resource/aws_api_gateway_stage: Ignore NotFoundException on destroy (#12826)
  * data-source/aws_api_gateway_rest_api: Prevent error with VPC Endpoint configured APIs (#12825)
  * tests/resource/aws_cloudwatch_log_group: Add sweeper (#12792)
  * Adds Security Group test fix
  * Adds additional test fix
  * Updates EC2 acceptance tests to use ARN testing check functions
  * r/aws_snapshot_create_volume_permission: Remove extraneous Exists function.
  * resource/aws_storagegateway_gateway: Finish gateway_vpc_endpoint implementation
  * Removes some `lintignore` directives
  * tests/provider: Introduce shared disappears TestCheckFunc, refactor Backup testing to implement and verify (#12864)
  * enable lint checks R007 and R008
  * resource/emr_cluster: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#13074)
  * resource/aws_storagegateway_smb_file_share: Add path attribute (#12623)
  * service/ec2: Add outpost_arn attribute to aws_network_interface resource and data source (#12440)
  * service/ec2: Add outpost_arn attribute to aws_ebs_volume resource and data source (#12439)
  * r/aws_rds_cluster_parameter_group: Remove deprecated Partial/SetPartial.
  * service/ec2: Add outposts_arn attribute to resource and data source (#12097)
  * provider: Various data source information for new eu-south-1 (Milan) region (#13061)
  * Update module aws/aws-sdk-go to v1.30.16 (#12970)
  * Replace 'testAccPreCheckOffersEc2InstanceType' with 'aws_ec2_instance_type_offering' data source. (#13076)
  * resource/aws_storagegateway_gateway: Retry 504 status code on activation (#12773)
  * service/storagegateway: Gateway activation stability and test configuration fixes (#12772)
  * resource/aws_appautoscaling_scheduled_action: Include ResourceId in DescribeScheduledActions API call (#12699)
  * resource/aws_efs_file_system: Prevent panic with empty lifecycle_policy configuration block (#12640)
  * tests/service/guardduty: Prevent detector data source concurrency errors, refactor detector resource import testing (#12766)
  * resource/aws_batch_job_queue: Prevent panic when ComputeEnvironmentOrder is updated outside Terraform (#12632)
  * r/aws_route53_health_check: Validate reference_name (#12873)
  * resource/aws_elasticsearch_domain: Support customizable update timeout (#12916)
  * docs/resource/aws_appautoscaling_policy: Additional customized_metric_specification documentation (#12696)
  * Clarified options for `email_sending_account` and associated `source_arn`.  Updated `from_email_address` formatting to properly display in generated pages and replaced smith.com with example.com.
  * r/aws_ami_launch_permission: Remove extraneous Exists function.
  * r/aws_kms_grant: Remove extraneous Exists function.
  * r/aws_ssm_parameter: Remove extraneous Exists function.
  * r/aws_iam_openid_connect_provider: Remove extraneous Exists function.
  * r/aws_glue_crawler: Remove extraneous Exists function.
  * revert local change
  * resource/aws_route53_zone: Guard against missing ChangeInfo during creation (#12634)
  * resource/aws_fsx_windows_file_system: Prevent panic when update includes `self_managed_active_directory` settings (#12630)
  * resource/aws_glue_catalog_table: Prevent various panics with empty configuration blocks (#12611)
  * provider: Replace deprecated helper/validation.ValidateJsonString function (#12378)
  * docs/resource/aws_appautoscaling_target: Additional information about role_arn (#12694)
  * docs/resource/aws_appautoscaling_policy: Link to AWS documentation for policy_type argument documentation (#12695)
  * resource/aws_lb_listener: Prevent panics on creation and refresh when API throttled (#12617)
  * service/ec2: Fix tagging for default route table and add CIDR plan time validation to route table resources (#12858)
  * resource/aws_kinesis_firehose_delivery_stream: Prevent panic with empty `processing_configuration` configuration block (#12613)
  * resource/aws_elastic_transcoder_preset: Refactor testing to ensure unrelated testing does not include description (#12612)
  * Format code
  * adjust delete timout default to 10 min
  * tests/provider: Introduce regional sweeper AWSClient cache (#12604)
  * provider: Ensure aws_prefix_list is labeled service/ec2 (#12588)
  * data-source/aws_elb_hosted_zone_id: Add `us-gov-east-1` and `us-gov-west-1` region values (#12976)
  * set "instance_pools_to_use_count" in import
  * Update aws/resource_aws_spot_fleet_request.go
  * Update aws/resource_aws_spot_fleet_request.go
  * rebase import and add to new test cases
  * fix typo
  * fmt fix
  * add import support
  * resource/aws_spot_fleet_request: Launch Template Support (#12732)
  * docs/resource/aws_iot_topic_rule: Use latest SQL version in example (#13037)
  * resource/aws_wafregional_xss_match_set: Fix 'panic: interface conversion: interface {} is *schema.Set, not []interface {}'. (#13024)
  * Adds one more ARN test fix and replaces many `acctest.RandInt()` calls with `acctest.RandomWithPrefix()`
  * Updates DynamoDB acceptance tests to use ARN testing check functions
  * Updates CodeDeploy acceptance tests to use ARN testing check functions
  * Updates CloudWatch Events acceptance tests to use ARN testing check functions
  * adjust config format spacing
  * CR updates: remove extra fields and update tests
  * Move test code
  * Actually test behaviour of `TestAccAWSCodePipeline_emptyStageArtifacts` other than not crashing
  * Updates CodePipeline acceptance tests to use ARN testing check functions
  * Updates S3 acceptance tests to use ARN testing check functions
  * remove duplicate change of GH-12858
  * Simplify code & add states to trigger recreation.
  * aws_ec2_transit_gateway_peering_attachment_accepter: remove unnecessary items
  * aws_ec2_transit_gateway_peering_attachment_accepter: peer tgw direction
  * aws_ec2_transit_gateway_peering_attachment_accepter: keyvaluetags
  * add data source links to aws provider home
  * add backup_* data sources
  * add support for importing aws_default_route_table resource and setting tags
  * r/aws_glue_catalog_database: Remove extraneous Exists function.
  * service/vpn: tech debt: replace custom validation functions
  * service/redshift: missed the $, change which method we use
  * service/redshift: tech debt: replace existing custom validators
  * docs: update documentation
  * test: add cover test
  * service/iam: Clean up inlining mess I made.
  * service/iam: replace custom SchemaValidateFunc with provided ones
  * feat: support mongodb connection type for AWS Glue
  * fix: route53 setid and type change
  * resource/aws_placement_group: Support tag-on-create (#12963)
  * Update CHANGELOG for #12962
  * resource/aws_key_pair: Support tag-on-create (#12962)
  * Better cleaner code and a build fix
  * More docs beats less docs
  * Update db_snapshot.html.markdown
  * Fix some typos in docs etc
  * add zero tag check
  * Fix some overlooked text
  * fix arn test
  * Add Local Gateway Route Table datasources
  * add tags test case
  * use create out put for setting id
  * add import to db snapshot
  * Updates KMS acceptance tests to use ARN testing check functions
  * Cleanup after v2.59.0 release
  * Adds ARN test for IAM instance profile data source
  * Updates IAM acceptance tests to use ARN testing check functions
  * Updates docdb acceptance tests to use ARN testing check functions
  * Updates Cloud9 acceptance tests to use ARN testing check functions
  * r/aws_apigatewayv2_stage: Correctly handle diffs for HTTP API 'default_route_settings.logging_level' attribute, plus the special '$default' stage.
  * docs: add documentation for Qos field
  * test: add cover test for Qos field
  * feat: add Qos field to IoT republish action
  * Delete mistake part duece
  * Delete mistake
  * Add links to website, fix redundant nil checks.
  * Pool_id(s) instead of id(s)
  * Add Coip to EIP resource and datasource
  * Break dependency on VPC tests
  * Add COIP Datasources
  * docs: Add Federated Principal information to iam_policy_document
  * R005 linting
  * Docs: aws_lambda_permission clarifications.
  * docs: rename documentation file to match resource name
  * Add new docs to index. Run gofmt
  * Add docs, accept state filter
  * Add Outpost Local Gateway support
  * IoT Rule DyanmoDB operation action
  * resource/aws_iam_instance_profile: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial()
  * added data source side navigation link
  * added aws_ecr_authorization_token documentation
  * added data source aws_ecr_authorization_token
  * docs/resource/aws_elasticsearch_domain: Update access policy in example
  * resource/aws_elasticsearch_domain: move master user options in docs
  * resource/aws_elasticsearch_domain: add es domain example
  * resource/aws_elasticsearch_domain: Use len check on master_user_options
  * resource/aws_elasticsearch_domain: update docs to match schema
  * resource/aws_elasticsearch_domain: add read and update support; ignore master user options in tests
  * tests/resouce/aws_elasticsearch_domain: add user db and iam tests for es advanced security
  * tests/data_source/aws_elasticsearch_domain: Assert false for default values
  * resource/aws_elasticsearch_domain: Validation and type assertion improvements for advanced security options
  * resource/aws_elasticsearch_domain: Add advanced security options
  * Fix
  * tests/data-source/aws_elasticsearch_domain: Add advanced_security_options to acceptance tests
  * docs/data-source/aws_elasticsearch_domain: Add advanced_security_options attributes to docs
  * data-source/aws_elasticsearch_domain: Add advanced security options
  * update docs
  * update arn test
  * add import support use enums add plan time validations remove extraneous list tags call add disappearing test case
  * resource/aws_security_group_rule: Prevent resource replacement when source sg id is specified with account id prefix
  * Placate linter
  * Apply eventual consistency mitigation only on create
  * Prevent VPC and Subnet resources from deleting tags created by aws_ec2_tag
  * aws_codebuild_project: allow empty value of environment variables
  * Remove references to default RT propogation
  * Delete old Route53 record when updating name
  * Fix conflicts
  * Resource aws_ec2_transit_gateway_peering_attachment_accepter
  * aws_ec2_transit_gateway_peering_attachment_accepter
  * add subcategory to website doc
  * Switch to terraform-plugin-sdk
  * resource/ecs_service: Add support for customTimeout on delete
  * Added [WARN] prefix in the log
  * Handle tag delete in resourceAwsEc2TagRead
  * Add docs for timeout.
  * updated documentation with new parameter
  * added in changes for storage gateway to accept a vpc endpoint
  * Add docs
  * Add iotEvents action
  * Fix block name
  * Add iotAnalytics action
  * fixing retry logic - DescribeTags returns no err and an empty list of tags if the tag is not yet there
  * Use a retry as the EC2 API is eventually consistent.
  * resource/aws_ecs_service: Add EXTERNAL deployment_controller argument
  * do the same for route tables
  * Check error on delete.
  * Only manage tags if someone has defined them in aws_subnet and aws_vpc.
  * Get tests working minus the VPC resource causing a dirty plan.
  * Get code compiling.
  * Add the resource to the provider and write some docs.
  * Add the initial aws_ec2_tag resource.
  * r/ecs_service: Add EXTERNAL to deployment_controller
  * fix linting error
  * Add support for DynamoDbv2 IoT topic rule action
  * [docs] Clarify mfa_delete cannot toggle state
  * Add acceptance test for non-zero min_vcpus
  * Revert "Ensure desired_vcpus is set before including it in update"
  * Ensure desired_vcpus is set before including it in update
* Mon Apr 27 2020 rjschwei@suse.com
- Add symlink required by terraform execution
- Update to version 2.59.0: (bsc#1170264)
  * v2.59.0
  * update expected ID example for ssm_maintenance_window_target
  * resource/aws_waf_xss_match_set: Add plan-time validation for xss_match_tuples configuration block arguments (#12777)
  * resource/aws_waf_ipset: Add plan-time validation for ip_set_descriptors configuration block arguments (#12775)
  * resource/aws_wafregional_web_acl: Add plan-time validation to various arguments (#12793)
  * resource/aws_rds_cluster: Support aurora-mysql and aurora-postgres Global Clusters (#12867)
  * provider: Support af-south-1 (Cape Town) in various data sources (#12967)
  * docs/provider: Fix formatting of code block in Contributing Guide (#12965)
  * add changelog entry for PR #12929
  * add changelog entry for PR #12948
  * entry for adding import support network_acl_rule
  * update import id expected value formatting
  * add import note
  * fix tag list + expand test
  * resource/aws_route: Allow using compressed IPV6 CIDR (#12890)
  * data-source/aws_launch_template: Prevent type error with network_interfaces associate_public_ip_address (#12936)
  * docs/resource/aws_acm_certificate_validation: Use explicit zone_id attribute references (#12885)
  * docs/provider: Change "mapping" to "map" (when referring to the data structure) (#12908)
  * docs/resource/aws_iam_role_policy: Explicitly call out inline policy (#12905)
  * Update module aws/aws-sdk-go to v1.30.12 (#12715)
  * resource/aws_codepipeline: Add stage action namespace argument (#11910)
  * docs/provider: Correct ELB, S3 and Elastic Beanstalk links for new AWS regions in Contributing Guide (#12946)
  * update comments in test
  * add support for importing aws_volume_attachment resouce
  * add support for importing aws_ssm_maintenance_window_target resource
  * add support for importing aws_ssm_activation resource
  * code review updates and doc update
  * run linters
  * change delimiter and namespace attribute name
  * add vpc-related example/docs
  * add support for importing aws_service_discovery_private_dns_namespace
  * move linux wording
  * docs/provider: make website-lint-fix
  * add support for importing aws_default_etwork_acl resources
  * rename example resource
  * formatting with linter
  * update documentation for acl_rule importing
  * resource/aws_appsync_graphql_api: Add `log_config` configuration block `exclude_verbose_content` argument (#12884)
  * add support for importing aws_network_acl_rule resources
  * resource/aws_ssm_maintanance_window_target: Add plan-time validation to `resource_type` argument (#11783)
  * tests/resource/aws_glue_security_configuration: Keep empty string test in TestAccAWSGlueSecurityConfiguration_S3Encryption_S3EncryptionMode_SSES3
  * Do not send kms_arn in glue security configuration if mode is SSES3
  * resource/aws_iam_user: Ensure `force_destroy` removes signing certificates (#10542)
  * docs/resource/aws_dms_endpoint: Add missing aurora-postgresql to engine_name valid values (#12899)
  * resource/aws_lambda_alias: Suppress differences for equivalent function_name name and ARN (#12902)
  * .github/workflows/issues: Try removing curly braces from JSON to prevent error
  * r/aws_acm_certificate: Add test sweeper.
  * r/aws_apigatewayv2_api: Add test sweeper dependency on 'aws_apigatewayv2_domain_name'.
  * Removes "magic string" error code from error conditionals
  * Updates ARN test missed by linter
  * r/aws_apigatewayv2_vpc_link: Move waiter logic into its own package.
  * Add aws_apigatewayv2_vpc_link resource.
  * Fix lint warning.
  * Fix broken documentation links.
  * r/aws_apigatewayv2_api_mapping: Create ACM certificate outside of Terraform configuration.
  * Renamed resource to 'aws_apigatewayv2_api_mapping'.
  * Add 'aws_api_gateway_v2_api_mapping' resource.
  * Cleanup after v2.58.0 release
  * v2.58.0
  * .github/workflows/issues: Remove extra closing parenthesis
  * .github/workflows/issues: Add curly braces in JSON
  * .github/workflows/issues: Try using fromJSON() to prevent errors
  * .github/workflows/issues: Ignore collaborators for needs-triage issue labeling (#12857)
  * Adds checks for nil results to prevent panics
  * Removes extraneous API call when updating root EBS volume
  * Test that route_settings are removed when empty.
  * Rename resource to 'aws_apigatewayv2_stage'.
  * tests/service/rds: Remove rds-ca-2015 from CA Certificate Identifier testing (#12855)
  * Add 'aws_api_gateway2_stage' resource.
  * service/servicediscovery: Refactor waiter logic into separate package, add test sweepers (#12765)
  * Change after review.
  * resource/aws_dms_endpoint: Finish initial elasticsearch implementation and refactor schema/testing
  * Add deployment status waiter.
  * Rename resource to 'aws_apigatewayv2_deployment'.
  * Add 'aws_api_gateway2_deployment' resource.
  * Rename resource to 'aws_apigatewayv2_route_response'.
  * Add 'aws_api_gateway2_route_response' resource.
  * resource/aws_dms_endpoint: Minor adjustments to finish kinesis implementation and back out mongodb changes from #8633
  * resource/aws_dms_event_subscription: Finish initial implementation
  * docs/resource/aws_ram_resource_share: Fix typo (#12827)
  * Rename aws_apigatewayv2_integration_response resource source files to match standard naming convention.
  * Add note to documentation on inability to import API Gateway managed resources created as part of API quick create.
  * tests/resource/aws_backup_plan: Remove unused testAccCheckAwsBackupPlanRuleAttrSet
  * Fix and enable tfproviderlint S023 check (#12781)
  * resource/aws_cognito_identity_provider: Address PR #10705 feedback
  * resource/aws_backup_plan: Finish initial copy_action implementation
  * data-source/aws_regions: Finish initial implementation
  * data-source/aws_regions: Apply suggestions from code review
  * docs/resource/aws_pinpoint_email_channel: Fix description (#12824)
  * resource/aws_ec2_client_vpn_endpoint: Allow two `authentication_options`  configuration blocks (#12819)
  * resource/aws_dynamodb_table: Finish up initial Global Table Version 2019.11.21 implementation
  * deps: Vendor github.com/aws/aws-sdk-go/service/route53domains (#12797)
  * Fixes tests
  * fmt updates
  * Apply suggestions from code review
  * docs/data-source/aws_route_tables: Update ids attribute type (#12802)
  * resource/aws_dlm_lifecycle_policy: Ensure plan-time validation for times argument only allows 24 hour format (#12800)
  * provider: Fix and enable tfproviderlint S024 check: ForceNew is extraneous in data source schema attributes  (#12778)
  * tests(staticcheck): fix failing tests (#12782)
  * add extra line to indicate issue may exist in linux
  * add glob to provider pr labeller
  * tests/resource/aws_ecs_task_definition: Add sweeper (#12760)
  * Cleanup after v2.57.0 release
  * v2.57.0
  * r/aws_apigatewayv2_route: Add support for JWT authorizers.
  * resource/aws_rds_global_cluster: Add aurora-postgresql to engine argument plan-time validation (#12401)
  * 'aws_api_gateway2_route' -> 'aws_apigatewayv2_route'.
  * Add 'aws_api_gateway_v2_route' resource.
  * 'aws_api_gateway2_integration_response' -> 'aws_apigatewayv2_integration_response'.
  * Add 'aws_api_gateway_v2_integration_response' resource.
  * Add message to highlight ulimit option which can prevent issues with AT runs
  * Fix missing side navigation links. (#12746)
  * resource/aws_network_acl: Ensure tags are handled on creation
  * resource/aws_vpc_peering_connection_accepter: Do not overwrite incoming ResourceData on creation
  * resource/aws_kms_key: Prevent eventual consistency related errors on creation
  * service/ec2: Switch tagging during resource creation to keyvaluetags.CreateEc2Tags implementation
  * internal/keyvaluetags: Initial tagging function generator for handling tagging of new resources
  * Updates AWS Config acceptance tests to use ARN testing check functions
  * Updates CloudFront acceptance tests to use ARN testing check functions
  * internal/keyvaluetags: Move all generator customization functions into shared service_generation_customizations.go
  * service/lambda: Support for .NET Core 3.1 (#12712)
  * resource/aws_egress_only_internet_gateway: Finish tags implementation and fix errors
  * resource/aws_cloudhsm_v2_cluster: Support tag-on-create (#11683)
  * resource/aws_spot_fleet_request: Add tags argument, support more plan-time validations, refactor testing (#12295)
  * Updates App Autoscaling acceptance tests to use ARN testing check functions
  * tests/resource/aws_db_instance: Add covering acceptance testing for db_subnet_group_name and replicate_source_db arguments
  * Updates API Gateway acceptance tests to use ARN testing check functions
  * Use 'testAccCheckResourceAttrEquivalentJSON'.
  * Updates ECS acceptance tests to use ARN testing check functions
  * Updates ECR acceptance tests to use ARN testing check functions
  * 'aws_api_gateway2_model' -> 'aws_apigatewayv2_model'.
  * Add 'aws_api_gateway_v2_model' resource.
  * Updates ACM acceptance tests to use ARN testing check functions
  * provider: Update preview ignore tags handling to configuration block and shared struct type (#12586)
  * Update module aws/aws-sdk-go to v1.30.5 (#12706)
  * Update aws/resource_aws_db_instance.go
  * Update module hashicorp/terraform-plugin-sdk to v1.9.0 (#12531)
  * resource/aws_docdb_cluster: Add deletion_protection argument (#12650)
  * Update module aws/aws-sdk-go to v1.30.4 (#12414)
  * docs/resource/aws_ssm_maintenance_window_task: Fix example value for `notification_type` (#12705)
  * resource/aws_redshift_snapshot_copy_grant: Finish import implementation
  * resource/aws_lb_target_group: Ensure unconfigured health checks for Network LB do not trigger recreation and add covering acceptance testing
  * Adds `device_name` to `data-source/aws_instance`
  * Adds EBS root volume delete-on-termination modification
  * resource/aws_lb_target_group: go fmt after fixing merge conflict
  * Adds EBS root volume type and IOPS modification
  * Fix for creating an RDS read replica in shared subnets.
  * tests/resource/aws_appautoscaling_policy: Ensure covering acceptance testing for DynamoDB index policy
  * New Data Source: aws_cloudfront_distribution (#6468)
  * service/elastictranscoder: Refactor out SetMap usage (#12641)
  * docs/resource/aws_cloudtrail: Fix broken link to Cloudtrail Data Events (#12687)
  * docs/resource/aws_launch_template: fix documentation for EBS block kms_key_id property (#12672)
  * docs/resource/aws_neptune_cluster: Fix attribute name typo deletion_protection (#12649)
  * enable s20 lint check and fix issues
  * Adds test for retrieving computed root EBS device values
  * Cleanup after v2.56.0 release
  * v2.56.0
  * Updates documentation
  * Stops waiting for volume update when state is `optimizing`, since the volume is useable in that state
  * Updates root volume resize to work when multiple EBS volumes are attached
  * Uses AWS SDK provided functions for value dereference
  * Consolidates EC2 instance retrieval
  * service/sagemaker: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12462)
  * resource/aws_s3_bucket: Fix lint error (#12626)
  * Updates to current framework
  * Improve code quality and fix tests as requested
  * resource_aws_instance: Modify root volume size without instance recreation
  * resource/aws_s3_bucket: Prevent various panics with empty configuration blocks (#12614)
  * Removes nested resource testing in favour of `ImportStateVerify` and adds missing CodePipeline precheck
  * resource/aws_elastic_transcoder_preset: Remove stringptr and refactor tests (#12581)
  * resource/aws_volume_attachment: Do not swallow error when detaching volume (#12596)
  * resource/aws_elastic_transcoder_preset: Remove `getStringPtr` calls, refactor tests, validate role argument (#12575)
  * resource/aws_kms_grant: Remove resource from Terraform state instead of error if removed outside Terraform (#12560)
  * tests/resource/aws_codebuild_project: Fix typo in error message testing for buildspec
  * resource/aws_codebuild_project: Fix typo of buildspec (#12590)
  * resource/aws_codestarnotifications_notification_rule: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12469)
  * resource/aws_lb_listener: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12468)
  * resource/aws_api_gateway_stage: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12467)
  * resource/aws_lambda_function: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12466)
  * service/ec2: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12465)
  * resource/aws_autoscaling_group: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12464)
  * resource/aws_directory_service_directory: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12463)
  * service/redshift: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12461)
  * service/route53resolver: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12460)
  * service/elb: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12459)
  * service/docdb: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12457)
  * Consolidates artifact stores into a single argument
  * Typo fix
  * Change naming according to #9950
  * Switch to filter for more flexibility
  * Add data source "aws_regions"
  * Adds tests for converting CodePipeline actions from single- to cross-region
  * Adds tests for updating cross-region CodePipeline actions
  * Properly hashes artifact stores
  * Adds test for changing artifact store location
  * service/rds: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12477)
  * Removes "foo" and "bar"
  * (docs) show AWS recommended EFS volume mount options (#12576)
  * service/directconnect: Support 2Gbps and 5Gbps values in plan-time validation for bandwidth argument (#12559)
  * resource/aws_kms_grant: Support resource import (#11991)
  * service/ec2: Add hibernation_options to aws_launch_template resource and data source (#12492)
  * resource/aws_codedeploy_deployment_group: Fix blue_green_deployment_config updates for ECS (#11885)
  * tests/service/rds: Sweeper and randomization of Database Snapshots (#12546)
  * resource/aws_opsworks_rds_db_instance: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12476)
  * resource/aws_route53_zone: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12475)
  * resource/aws_qldb_ledger: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12474)
  * resource/aws_globalaccelerator_accelerator: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12472)
  * resource/aws_elasticache_parameter_group: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12471)
  * resource/aws_licensemanager_license_configuration: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial() (#12470)
  * Handles creation and import of cross-region CodePipeline actions
  * Removes redundant CodePipelineExists test from CodePipleline webhook tests
  * Fixes rebase errors and adds `depends_on` for IAM policy attachments
  * Cleanup after v2.55.0 release
  * v2.55.0
  * resource/aws_neptune_cluster_instance: Add missing configuring-log-exports as allowed pending state (#12079)
  * service/ec2: Support metadata_options in aws_instance and aws_launch_template resources/data sources (#12491)
  * tests/data-source/aws_vpc_endpoint_service: Fix EC2 policy check (#12544)
  * provider: Updates to verify hashibot behaviors and increase stale handling per run (#12556)
  * Removes unneeded test
  * Applies `terrafmt fmt`
  * Adds tests for adding and reordering `bootstrap_actions`
  * Corrects type of `bootstrap_action` from TypeSet to TypeList
  * resource/aws_ecs_task_definition: Remove pluralization from inference_accelerator configuration block argument
  * docs/provider: Run make website-lint-fix
  * resource/aws_ecs_task_definition: Add inference_accelerator configuration block (#11757)
  * resource/aws_msk_cluster: Add logging_info configuration block (support CloudWatch, Firehose, and S3 logging) (#12215)
  * docs/resource/aws_api_gateway_deployment: Fixed documentation example (#12486)
  * Corrects error in destroy check
  * Fixes and test updates
  * [WIP] Test for multi region codepipeline.
  * Use expandAwsCodePipelineArtifactStore to expand artifactStores
  * One definition of the artifactStoreSchema
  * Add support for Codepipeline artifact_stores
  * Add Codepipeline action region support
  * resource/aws_flow_log: Add max_aggregation_interval argument (#12483)
  * Reorders parameters for composed configurations for cleaner formatting
  * data-source/aws_ec2_transit_gateway_dx_gateway_attachement: Add filter and tags arguments (#12516)
  * resource/aws_storagegateway_nfs_file_share: Implement path attribute (#12530)
  * provider: Switch stale handling from hashibot to official GitHub Action (#12542)
  * data-source/aws_ec2_transit_gateway_vpn_attachment: Add filter and tags arguments (#12415)
  * data-source/aws_vpc_endpoint_service: Add filter argument (#12404)
  * data-source/aws_prefix_list: Add filter argument (#12416)
  * docs/data-source/aws_launch_template: Add missing tags argument
  * tests/provider: Bulk update aws_availability_zones data sources in test configurations to exclude Local Zones (#12517)
  * docs/resource/aws_cognito_user_pool: Update the resource definition (#12529)
  * plan only test for change revert
  * resource/aws_db_instance: Use expandStringSet and add testing for snapshot_identifier with db_subnet_group_name
  * Removes extra attributes.
  * Correcting possible values for encryption_option (#12510)
  * resource/aws_athena_workgroup: Add force_destroy argument (#12254)
  * resource/aws_mq_configuration: Remove extraneous call to ListTags during refresh and add ValidateFunc to engine_type (#11843)
  * resource/aws_cloudwatch_log_metric_filter: Support resource import (#11992)
  * plan only test for change
  * Adds fix to filter out Local Zones from list of Availability Zones
  * Update resource_aws_route53_health_check_test.go
  * Adds functions to compose acceptance test configurations
  * Replaces `RandInt()` with `RandomWithPrefix()`
  * Removes unneeded `bootstrap_action` arguments from tests. Adds check to `TestAccAWSEMRCluster_security_config` to test `security_configuration`
  * Refactors IAM roles and policies
  * Fixes linting error
  * Cleans up some formatting and adds some tests to actually test some cases
  * Use availability zone filter (https://github.com/terraform-providers/terraform-provider-aws/pull/12400 merged).
  * Remove 'tls_config' attribute. It doesn't seem to do anything right now.
  * r/aws_apigatewayv2_integration: Add 'payload_format_version' and 'tls_config' attributes.
  * r/aws_apigatewayv2_integration: Don't import API Gateway managed integrations.
  * 'aws_api_gateway2_integration' -> 'aws_apigatewayv2_integration'.
  * Add 'aws_api_gateway_v2_integration' resource.
  * Adds fix to filter out Local Zones from list of Availability Zones
  * Corrects function name
  * Terraform formatting fixes
  * Corrects test for Elastic Beanstalk Platform ARN
  * Formatting fixes
  * Consolidates Elastic Beanstalk Environment deletion
  * Adds option to ignore error events when terminating Elastic Beanstalk Environment
  * Formatting fixes
  * Updates Elastic Beanstalk Platform ARN to supported platform version
  * No longer stops sweepers for Elastic Beanstalk Applications and Environments on the first error
  * Update launch_template.html.markdown
  * service/ec2: Initial support for Local Zones (#12400)
  * Update module bflad/tfproviderlint to v0.14.0 (#12505)
  * Rename test.
  * r/aws_apigatewayv2_api: Add CORS configuration and quick start attributes.
  * Cleanup after v2.54.0 release
  * v2.54.0
  * service/neptune: Remove deprecated (helper/schema.ResourceData).Partial() and (helper/schema.ResourceData).SetPartial()
  * docs/resource/aws_securityhub_standards_subscription: Add PCI standard examples and docs (#12090)
  * Update module bflad/tfproviderlint to v0.12.0 (#12456)
  * Moved VPC SGs from ModifyDB to RestoreDB API Call
  * resource/aws_vpc_dhcp_options_association: Minor testing and linting fixes
  * New Resource: aws_securityhub_member (#6975)
  * resource/aws_cognito_user_pool_client: Add prevent_user_existence_errors argument (#11604)
  * resource/aws_cognito_user_pool: Add username_configuration configuration block (Support case insensitive usernames) (#12317)
  * resource/aws_cognito_user_pool: Add email_configuration configuration block from_email_address argument (#11607)
  * resource/aws_cognito_user_pool_client: Add analytics_configuration configuration block (Support Pinpoint analytics) (#11762)
  * Moves `replica` to `aws_dynamodb_table`.
  * resource/aws_api_gateway_rest_api: Ignore ordering differences for endpoint_configuration configuration block vpc_endpoint_ids argument (#12350)
  * tests/resource/aws_launch_template: Add test for network interface ipv4 addresses (#12307)
  * resource/aws_lambda_function: Add plan-time validation for handler argument (#12411)
  * resource/aws_s3_bucket: Retry NoSuchBucket error when setting tags during resource creation (#12418)
  * resource/aws_cognito_user_pool_client: Ignore ordering differences for callback_urls, logout_urls, and supported_identity_providers arguments (#12388)
  * resource/aws_dlm_lifecycle_policy: Add 1 hour backup interval (#12327)
  * service/opsworks: Layers tagging support (#11667)
  * service/opsworks: Add Sensitive flag to private ssh_key properties (#11984)
  * resource/aws_opsworks_application: Support resource import and add plan-time validations (#12383)
  * service/docdb: Add length checking to identifier value validation (#10826)
  * 'aws_api_gateway2_domain_name' -> 'aws_apigatewayv2_domain_name'.
  * Add 'aws_api_gateway_v2_domain_name' resource.
  * r/aws_apigatewayv2_authorizer: Add support for JWT.
  * 'aws_api_gateway2_authorizer' -> 'aws_apigatewayv2_authorizer'.
  * Add 'aws_api_gateway_v2_authorizer' resource.
  * docs/resource/aws_default_network_acl: Fix terraform 0.12 warning (#12406)
  * resource/aws_kinesis_stream: Ensure kms_key_id argument in-place updates complete successfully (#12008)
  * docs/service/ec2: Clarify usage of 'service_name' and 'service' attributes for VPC Endpoints and VPC Endpoint Services (#11842)
  * resource/aws_lambda_alias: Add ForceNew to function_name attribute (#11170)
  * remove check
  * Update launch_template.html.markdown
  * docs/resource/aws_security_group_rule: restore "required" field in example (#12392)
  * add filter support - docs
  * rename tests
  * rename tests
  * add support for filtering launch templates
  * Update module aws/aws-sdk-go to v1.29.24 (#12359)
  * Update module hashicorp/terraform-plugin-sdk to v1.8.0 (#12357)
  * service/elbv2: Add drop_invalid_header_fields attributes to aws_lb resource and datasource (#11257)
  * resource/aws_backup_vault: Remove from state on AccessDeniedException (#11845)
  * resource/aws_backup_selection: Automatically retry on additional IAM Role eventual consistency error (#10687)
  * data-source/aws_iam_role: Add tags attribute (#12349)
  * resource/aws_backup_plan: Support resource import (#12381)
  * docs/resource/aws_ssm_activation: Update example IAM Policy (#12385)
  * resource/aws_nat_gateway: Support tag-on-create (#12347)
  * resource/aws_inspector_assessment_template: Add tags argument and support resource import (#12375)
  * resource/aws_elastic_beanstalk_environment: make fmt (Go 1.14 support) (#12393)
  * docs/resource/aws_kinesis_video_stream: Fix example HCL formatting
  * New Resource: aws_kinesis_video_stream (#8291)
  * provider: Consistent service client naming for API Gateway v1 and SES services (#12372)
  * resource/aws_ebs_snapshot_copy: Return API errors instead of panic if unable to read snapshot (#12283)
  * Cleanup after v2.53.0 release
  * v2.53.0
  * Tweaks documentation subcategory for API Gateway v2
  * resource/aws_cognito_user_pool: Support Software Token MFA Configuration (#12358)
  * Adds missing comma in hashibot config
  * provider: Enable automatic terrform formatting enforcement in CI for documentation (#12232)
  * Rename resource to 'aws_apigatewayv2_api'.
  * docs/resource/aws_lambda_function: Update to supported nodejs version (#12355)
  * Lint fixes.
  * provider: Add AWSClient PartitionHostname() and RegionalHostname() receiver methods and AWSR001 linter (#12189)
  * Correct the dropdown section title.
  * Spell check.
  * Adds rest of Replica schema.
  * Use resourceAwsDynamoDbTable to drive main schema.
  * Basic support for HTTP APIs - No new attributes yet.
  * Changes `region` to `region_name`.
  * Uses flattenAwsDynamoDbTableResource.
  * Removes comments.
  * Uses resourceAwsDynamoDbTableUpdate.
  * Continue with sweep after any individual API fails deletion and capture all errors.
  * Uses resourceAwsDynamoDbTableCreate
  * Rename resource to 'aws_api_gatewayv2'.
  * Removes comments.
  * Adds support for DynamoDB v2019.11.21.
  * tests/provider: Enable tfproviderlint R002 check (#12033)
  * provider: Fix and enable tfproviderlint V002, V004, V007, and V008 (#12233)
  * provider: Fix and enable tfproviderlint S031, S032, and S033 (#12234)
  * tests/resource/aws_key_pair: Randomize name in test configurations (#11890)
  * tests/data-source/aws_ssm_parameter: Randomize naming (#12174)
  * tests/resource/aws_launch_template: Randomize naming in network interface test configurations (#11959)
  * resource/aws_opsworks_stack: Fixes for tfproviderlint R002 (#12028)
  * tests/provider: Enable passing tfproviderlint v0.10.0 checks (#12088)
  * tests/resource/aws_ssm_activation: Remove broken ExpectError testing from TestAccAWSSSMActivation_expirationDate (#12173)
  * service/ec2: Automatically retry on DetachVpnGateway calls receiving `InvalidParameterValue: This call cannot be completed because there are pending VPNs or Virtual Interfaces` (#11720)
  * provider: Additional hashibot pull request labeling (#12241)
  * Updates hashibot config to identify `apigatewayv2` service name
  * Update index.html.markdown (#12328)
  * tests/service/storagegateway: Refactor to use aws_ec2_instance_type_offering and aws_ssm_parameter data sources (#12247)
  * tests/data-source/aws_internet_gateway: Remove hardcoded provider region and ExpectNonEmptyPlan (#12253)
  * tests/provider: Remove extraneously hardcoded provider configurations in test configurations (#12277)
  * docs: fix S3 ACL permissions
  * Correct test check function name.
  * Clean up function names - https://github.com/terraform-providers/terraform-provider-aws/pull/12299.
  * Add TestAccAWSAPIGateway2Api_disappears acceptance test.
  * Fix website documentation errors.
  * Fix go.mod/go.sum conflicts.
  * r/aws_api_gateway2_api: Tag-on-create.
  * Add 'subcategory'.
  * Replace 'testAccMatchResourceAttrAnonymousRegionalARN' with 'testAccMatchResourceAttrRegionalARNNoAccount'.
  * Use new internal/keyvaluetags functionality.
  * Add API Gateway v2 list tags code generation.
  * Terraform Plugin SDK migration.
  * Add 'execution_arn' attribute to 'aws_api_gateway2_api' resource.
  * Minor enhancement to error message.
  * Test API ARN in acceptance tests.
  * Add test sweeper.
  * API Gateway v2 API tags.
  * Better acceptance tests when all attributes are set.
  * Update resource name in tests.
  * More anonynous API ID for import example.
  * Get 'aws_api_gateway_v2_api' acceptance tests passing.
  * Add 'aws_api_gateway_v2_api' documentation.
  * Move 'aws_api_gateway_v2_route' to its own PR.
  * Rename resource methods to match CloudHSM v2 resource method naming.
  * Rename files to match CloudHSM v2 file naming.
  * Get tests to compile after rebase.
  * adding some routes
  * cleaning out some files
  * WIP on additional v2 resources
  * fixing tests
  * can create and delete
  * initial addition of v2 definition
  * Update module aws/aws-sdk-go to v1.29.20
  * resource/aws_flow_log: Add tags argument (#12273)
  * Add AT005 lint rule and fix tests (#12308)
  * docs/resource/aws_ram_resource_share_accepter: Fixed wrong resource name (#12314)
  * service/ec2: Finish refactoring to keyvaluetags package (#12289)
  * resource/aws_globalaccelerator_accelerator: Add tags argument (#12309)
  * resource/aws_vpc_endpoint_service: Support tag-on-create and add network_load_balancer_arns plan-time validation (#12290)
  * resource/aws_appsync_graphql_api: Add xray_enabled argument (#11972)
  * resource/aws_cloud9_environment_ec2: Add tags argument (#12132)
  * resource/aws_ec2_traffic_mirror_filter: Add tags argument (#12133)
  * resource/aws_ec2_traffic_mirror_session: Add tags argument (#12134)
  * resource/aws_ec2_traffic_mirror_target: Add tags argument and network_load_balancer_arn plan-time validation (#12135)
  * resource/aws_vpc_endpoint: Support tag-on-create (#12288)
  * add disappears test case
  * suppress diff when expanded ipv6 address is the same
  * Updates naming of HSM v2 functions to match conventions
  * Renames documentation subcategory for API Gateway v1 to prepare for v2
  * docs/resource/aws_launch_template: Fix typo (#12244)
  * resource/aws_elasticsearch_domain: Clarify zone_awareness_enabled argument (#12296)
  * Securityhub is no longer in preview - update docs (#12256)
  * docs/resource/aws_sns_topic_policy: Update resource name to snake case (#12274)
  * Update module golangci/golangci-lint to v1.23.8 (#12242)
  * service/workspaces: Refactor to use keyvaluetags package (#11645)
  * Cleanup after v2.52.0 release
  * v2.52.0
  * service/ec2: Refactor Security Group data sources and resources to use keyvaluetags package (#11918)
  * resource/aws_eks_cluster: Add encryption_config configuration block (#12280)
  * Update module aws/aws-sdk-go to v1.29.18 (#12258)
  * service/ec2: Refactor aws_internet_gateway data source and resource to use keyvaluetags package (#11907)
  * Update module bflad/tfproviderlint to v0.11.0 (#12259)
  * s3 bucket grant implementation: fix fmt
  * Update module aws/aws-sdk-go to v1.29.16 (#12214)
  * tests/resource/aws_cloudwatch_metric_alarm: Blacklist usw2-az4 AZ for instance testing
  * tests/resource/aws_eks_node_group: Update TestAccAWSEksNodeGroup_ReleaseVersion argument value (#12172)
  * resource/aws_lambda_function_event_invoke_config: Retry on additional IAM eventual consistency error with SNS Topic destinations (#12171)
  * resource/aws_media_store_container: Prevent ValidationException on creation when no tags are configured (#12170)
  * New Data Sources: aws_ec2_instance_type_offering and aws_ec2_instance_type_offerings (#12139)
  * docs/resource/aws_msk_cluster: Correct default value for client-broker encryption setting. (#12177)
  * docs/data-source/aws_pricing_product: Add capacitystatus filter (#12122)
  * service/elastictranscoder: Fix tfproviderlint R009 check in structure.go (#12137)
  * default EBS Volume type (#12155)
  * docs/resource/aws_cloudtrail: Fix spelling typo (#12180)
  * fixup(cloudwatch_log_group) documentation (#12193)
  * docs/data-source/aws_subnet_ids: Fixing example resource (#12224)
  * docs/resource/aws_s3_bucket_notification: Fix race condition in examples (#12228)
  * resource/aws_lb_target_group: Add `load_balancing_algorithm_type` argument (support Least Outstanding Requests algorithm for Application Load Balancers) (#11141)
  * provider: Replace local version of schema validators with identical versions from terraform-plugin-sdk helper/validation package (#12207)
  * internal/keyvaluetags: Support Quicksight service (#12220)
  * resource/aws_vpc_peering_connection: Refactor to use keyvaluetags package (#11935)
  * service/ec2: Refactor Spot Instance and Fleet resources to use keyvaluetags package (#11934)
  * service/ec2: Refactor aws_route_table(s) data sources and resource to use keyvaluetags package (#11915)
  * service/ec2: Refactor VPC Endpoint (Service) data sources and resource to use keyvaluetags package (#11931)
  * resource/aws_vpn_connection: Refactor to use keyvaluetags package (#11932)
  * service/ec2: Refactor Network ACL data source and resources to use keyvaluetags package (#11913)
  * resource/aws_iam_service_linked_role: Allow aws_service_name validation to accept values in AWS partitions outside AWS Commercial and AWS GovCloud (US) (#11919)
  * docs/provider: Fix invalid HCL in example configurations (#12209)
  * Skips CloudFormation StackSets acceptance tests when not supported
  * Fixes naming of CloudFormation StackSet
  * Skips CloudFormation StackSet sweepers when not supported
  * add dms elasticsearch target
  * resource/aws_globalaccelerator_accelerator: go fmt
  * resource/aws_globalaccelerator_accelerator: Add dns_name and hosted_zone_id attributes (#11670)
  * Update module aws/aws-sdk-go to v1.29.12 (#12128)
  * Update module golangci/golangci-lint to v1.23.7 (#12205)
  * Cleanup after v2.51.0 release
  * v2.51.0
  * New Data Source: aws_sfn_activity (#11080)
  * resource/aws_lambda_function: Support plan-time validation for runtime argument ruby2.7 value (#12116)
  * service/directconnect: Refactor tagging logic to keyvaluetags package and add 'amazon_side_asn' attribute (#11415)
  * service/ec2: Refactor aws_network_interface(s) data sources and resource to use keyvaluetags package (#11912)
  * resource/aws_ec2_client_vpn_endpoint: Refactor to use keyvaluetags package (#11917)
  * data-source/aws_iam_server_certificate: Fixes for tfproviderlint R002 (#11920)
  * service/cloudwatchlogs: Fixes for tfproviderlint R002 (#11921)
  * service/cognito: Fixes for tfproviderlint R002 (#11943)
  * service/elastictranscoder: Fixes for tfproviderlint R002 (#11944)
  * resource/aws_elastic_beanstalk_environment: Fixes for tfproviderlint R002 (#11945)
  * service/ec2: Fixes for tfproviderlint R002 (#11947)
  * Adds validation on CloudFront distribution georestriction type
  * Adds `.go-version` file and sets version to 1.13.7
  * Fixes Elastic Beanstalk sweeper names to match resource and prevent warnings in sweeper runs
  * s3 bucket grant implementation: fix docs and tests
  * tests/resource/aws_s3_access_point: Fix log.Printf linting issue
  * resource/aws_s3_access_point: Address minor PR #11276 feedback
  * New Resource: aws_s3_access_point (#11276)
  * resource/aws_workspaces_directory: Prevent panic and remove resource from Terraform state if removed outside Terraform (#11837)
  * docs/provider: Fix aws_ec2_traffic_mirror_* location in terraform.io sidebar
  * Fix example of IP ranges usage (#11320)
  * resource/aws_glue_job: Add notification_property configuration block (#12115)
  * docs/resource/aws_glue_job: Updating pythonshell details (#12114)
  * resource/aws_msk_cluster: Support Cluster expansion and Open Monitoring (#11451)
  * resource/aws_lambda_event_source_mapping: Adding ParallelizationFactor, MaximumRecordAgeInSeconds, BisectBatchOnFunctionError, MaximumRetryAttempts, DestinationConfig (#11100)
  * New Data Source: aws_sfn_state_machine (#10932)
  * tests/resource/aws_ec2_traffic_mirror_session: Fix TestAccAWSEc2TrafficMirrorSession_basic
  * service/ec2: New Resources for EC2 Traffic Mirroring (#9372)
  * Update module aws/aws-sdk-go to v1.29.7 (#11893)
  * resource/aws_glacier_vault: Fixes for tfproviderlint R002 (#11946)
  * tests/provider: Enable tfproviderlint R006 check (#12048)
  * tests/service/elasticache: Replace deprecated cache.m1 with cache.t3, refactor data source testing (#11956)
  * resource/aws_iot_certificate: Fixes for tfproviderlint R002 (#12026)
  * resource/aws_iam_saml_provider: Fixes for tfproviderlint R002 (#12027)
  * resource/aws_redshift_security_group: Fixes for tfproviderlint R002 (#12029)
  * resource/aws_proxy_protocol_policy: Fixes for tfproviderlint R002 (#12030)
  * resource/aws_route53_record: Fixes for tfproviderlint R002 (#12031)
  * resource/aws_ses_receipt_rule: Fixes for tfproviderlint R002 (#12032)
  * Cleanup after v2.50.0 release
  * v2.50.0
  * docs/resource/aws_codestarnotifications_notification_rule: Fixed spacing and spelling (#12109)
  * resource/aws_transfer_server: Minor adjustments to new host_key handling
  * resource/aws_transfer_server: Add host_key argument and host_key_fingerprint attribute (#8913)
  * resource/aws_iam_access_key: Add ses_smtp_password_v4 attribute (#11144)
  * resource/aws_lambda_function: Publish new version on config-only function updates (#11211)
  * data-source/aws_lambda_alias: Modernization for codebase and testing changes since submission, use name instead of alias_name to match resource
  * Update default EBS Volume type (#12092)
  * Make weight in default_capacity_provider_strategy optional. (#12091)
  * docs/guides/custom-service-endpoints: Use fully HTML list for Terraform Registry compatibility (#12004)
  * tests/resource/aws_launch_template: Add sweeper (#11962)
  * tests/resource/aws_organizations_policy: Add missing testAccOrganizationsAccountPreCheck (#12035)
  * resource/aws_codedeploy_deployment_group: Fixes for tfproviderlint R006 (#12042)
  * resource/aws_iam_policy_attachment: Fixes for tfproviderlint R006 (#12043)
  * resource/aws_lambda_permission: Fixes for tfproviderlint R006 (#12044)
  * resource/aws_redshift_snapshot_copy_grant: Fixes for tfproviderlint R006 (#12045)
  * resource/aws_ssm_document: Fixes for tfproviderlint R006 (#12046)
  * service/sfn: Fixes for tfproviderlint R006 (#12047)
  * internal/naming: New package for shared naming logic (#12052)
  * Limits directories for sweepers to just `./aws`
  * Update module bflad/tfproviderlint to v0.10.0 (#12074)
  * Update module hashicorp/terraform-plugin-sdk to v1.7.0 (#12012)
  * changes
  * Fix Doc: InvalidParameterValue: 'MaxAgeRule' and 'MaxCountRule' cannot be enabled simultaneously. (#12064)
  * Be clear about type for aws_subnet_ids (#12020)
  * Update the syntax of the examples in sns_topic_subscription to terraform (#12068)
  * update r/aws_globalaccelerator_endpoint_group documentation (#12063)
  * resource/aws_ram_resource_share_accepter: Minor PR review feedback changes
  * add acceptance tests
  * Cleanup after v2.49.0 release
  * v2.49.0
  * Adds `terraform-remote-s3-test` pattern for S3 backend
  * Compiles regexp once
  * Converts LB subnets to use splat expressions
  * Passes correct number of subnets to test
  * Updates Elastic Transcoder bucket names to match S3 sweeper patterns
  * Updates Macie S3 association bucket names to match S3 sweeper patterns
  * Updates Global Accelerator flow log bucket names to match S3 sweeper patterns
  * Updates Redshift bucket names to match S3 sweeper patterns
  * Updates Athena database and Athena named query bucket names to match S3 sweeper patterns
  * Updates ALB and NLB access log bucket names to match S3 sweeper patterns
  * Updates ELB access log bucket names to match S3 sweeper patterns
  * Adds default S3 bucket name to S3 sweeper
  * resource/aws_launch_configuration: Allow missing EC2 Image during root block device lookup (#12009)
  * resource/aws_batch_job_definition: Prevent extraneous differences with container properties missing environment, mount point, ulimits, and volumes configuration (#12000)
  * resource/aws_cognito_user_pool: Allow admin_create_user_config configuration block unused_account_validity_days to be omitted (#12001)
  * Update module golangci/golangci-lint to v1.23.6 (#11981)
  * service/s3: Refactor S3 Bucket Object data source and resource to use keyvaluetags package (#11964)
  * tests/resource/aws_instance: Refactor TestAccAWSInstance_hibernation to use aws_ami data source and launch with encrypted volume instead of copying AMI
  * resource/aws_instance: Add `hibernation` argument (#6961)
  * tests/resource/aws_launch_configuration: Refactor TestAccAWSLaunchConfiguration_withInstanceStoreAMI to use Amazon Linux and filter root device by instance-store
  * resource/aws_launch_configuration: Fix regression from version 2.22.0 with instance store AMIs returning an unexpected error (#9810)
  * resource/aws_launch_template: Add `cpu_options` configuration block (support disabling multithreading) (#6552)
  * docs/provider: Fix and enable markdownlint rules MD003, MD018, MD019, MD026, MD030, MD033, and MD046 (#12002)
  * Removes hardcoded partition checks and uses error values and acceptance pre-check to control test skip
  * internal/keyvaluetags: Fix CodestarnotificationsUpdateTags generation from old pull request
  * New Resource: aws_codestarnotifications_notification_rule (#10991)
  * docs/resource/aws_kinesis_firehose_delivery_stream: Fixed Splunk configuration option description (#11995)
  * tests/provider: Increase make test timeout for Docker environments (#11996)
  * data-source/aws_route53_zone: Filter on tags is containment, not exact equality. (#11953)
  * resource/aws_neptune_cluster: Add deletion_protection argument (#11731)
  * resource/aws_db_instance: Add delete_automated_backups argument (#8461)
  * docs/data-source/aws_api_gateway_rest_api: Alphabetize attributes and add missing execution_arn attribute
  * data-source/aws_api_gateway_rest_api: Add attributes (#10971)
  * resource/aws_db_instance: Enable RDS MSSQL agent log export to CloudWatch (#11472)
  * resource/aws_rds_global_database: Allow Aurora MySQL 5.7 as a Global Database Engine (#11790)
  * resource/aws_neptune_cluster: Add enable_cloudwatch_logs_exports argument (support audit logging) (#11949)
  * aws/resource_aws_route53_record.go: update change record set to use SDK backoff (#11895)
  * resource/aws_gamelift_fleet: Add tags argument (#11559)
  * docs/resource/aws_lb_listener_rule: Fix attribute names (#11985)
  * Adds TEST_COUNT makefile parameter
  * Add documentation on custom keyvaluetags functions. (#11974)
  * Update module golangci/golangci-lint to v1.23.4 (#11979)
  * docs/resource/aws_codebuild_project: Fix documentation example for 'source_version' attribute. (#11975)
  * docs/data-source/aws_kms_secrets: use identical text string for file and string arguments (#11980)
  * Update module bflad/tfproviderdocs to v0.5.0 (#11978)
  * New Service: WorkMail (#11958)
  * Refactors to use keyvaluetags package
  * Removes panics adding during debugging
  * r/_aws_s3_bucket_metric: Refactor to use keyvaluetags package.
  * Tidy up use of keyvaluetags.
  * Revert "r/aws_s3_bucket_object: Refactor to use keyvaluetags package."
  * Replace 'tagsMapToHash' with 'KeyValueTags.Hash' method.
  * r/aws_s3_bucket_object: Refactor to use keyvaluetags package.
  * Cleanup after v2.48.0 release
  * Fixes Route 53 resolver endpoint sweeper to return errors. Adds sweepers for Route 53 resolver rules and resolver rule associations
  * v2.48.0
  * tests/resource/aws_batch_job_queue: Revert errant ImportState testing in _disappears test
  * resource/aws_kinesis_firehose_delivery_stream: Allow processor clearing (#11649)
  * removing unnecessary nil check
  * go fmt
  * update to re-create resoure when lambda policy sid not found
  * fixing bugs, adding tests, updating docs
  * resource/aws_cloudwatch_log_stream: Prevent early state removal (#11617)
  * services/organization: Support TAG_POLICY type in policy and policy attachment resources (#11612)
  * resource/aws_default_security_group: Ensure description attribute is written into Terraform state (#11650)
  * resource/aws_network_acl_rule: Fix provider error when missing rule (#11544)
  * docs/provider: Fixed link and modified sentence in README (#11816)
  * fix typo in aws_lb_listener_rule doc (#11856)
  * resource/aws_fsx_lustre_file_system: Lower minimum storage cap to 1200Gb (#11847)
  * resource/aws_ec2_client_vpn_endpoint: Ensure dns_servers attribute is refreshed in Terraform state (#11889)
  * deps: Update renovate ignoreDeps to include golang.org/x/tools, remove unused dependencies, and alphabetize list (#11886)
  * service/ec2: Refactor aws_vpn_gateway data source and resource to use keyvaluetags package (#11909)
  * service/ec2: Refactor aws_nat_gateway data source and resource to use keyvaluetags package (#11908)
  * service/ec2: Refactor aws_customer_gateway data source and resource to use keyvaluetags package (#11906)
  * resource/aws_glacier_vault: Refactor to use keyvaluetags package (#11900)
  * r/aws_s3_bucket: Refactor to use keyvaluetags package.
  * resource/aws_s3_bucket: Retry read after creation for 404 status code (#11894)
  * tests/provider: Enable tfproviderlint R004 check (#11499)
  * Update website/aws.erb
  * service/ec2: Refactor aws_vpc_dhcp_options data source and resource to use keyvaluetags package (#11904)
  * internal/keyvaluetags: Use build constraint with custom implementation files, add gencheck Makefile target and add to CI (#11638)
  * data-source/aws_route53_zone: Refactor to use keyvaluetags package (#11661)
  * resource/aws_vpc_endpoint: Refactor to use keyvaluetags package (#11730)
  * New Resource: aws_datasync_location_smb (#10381)
  * resource/aws_batch_job_definition: Properly set container_properties and name into Terraform state and fix basic test (#11488)
  * docs/provider: Fix markdownlint MD032 failures and enable rule (#11875)
  * Sets `Force` parameter when deleting CloudWatch event targets and event rules. Allows deletion of managed resources
  * Inlines `tags` field definition
  * Addresses code review comments
  * Adds documentation navigation link
  * Add resource documentation links which is omitted (#11877)
  * Update module golangci/golangci-lint to v1.23.3 (#11876)
  * awsproviderlint: Initial implementation with AWSAT001 check (#11532)
  * deps: Migrate from github.com/kubernetes-sigs/aws-iam-authenticator/pkg/token to internal implementation (#11822)
  * resource/aws_cloudformation_stack_set: Wait for update operation completion and report any errors (#11726)
  * tests/service/cloudformation: Add sweepers and export randomization (#11725)
  * tests/resource/aws_guardduty_detector: Add sweeper (#11722)
  * tests/provider: Enable new passing tfproviderlint checks (#11873)
  * docs/provider: Add information for tfproviderdocs, tfproviderlint, and yaml.v2 in Maintaining Guide Dependency Updates section (#11820)
  * docs/provider: Fix markdownlint MD031 failures and enable rule (#11861)
  * Adds documentation
  * Adds `TESTARGS` parameter to `make test` to narrow unit tests
  * Implements Import operation
  * Implements flattening and expansion of Storage Class Analytics values
  * resousrce/aws_codebuild_project: Add source_version argument (#9877)
  * tests/resource/aws_cloud9_environment_ec2: Remove dependency on Default VPC and blacklist usw2-az4 (#11704)
  * tests/resource/aws_lb_target_group_attachment: Refactoring for region/partition agnostic and blacklist usw2-az4 (#11714)
  * tests/resource/aws_elastic_beanstalk_environment: Refactoring and modernization (#11702)
  * Update module golangci/golangci-lint to v1.23.2 (#11851)
  * Update module bflad/tfproviderlint to v0.9.0 (#11860)
  * resource/aws_ecs_cluster: Delay check of ECS Cluster status during creation for ECS eventual consistency (#11701)
  * resource/aws_appautoscaling_scheduled_action: Automatically retry creation on `ValidationException: ECS service doesn't exist` for ECS eventual consistency (#11693)
  * resource/aws_dynamodb_table: Skip ResourceNotFoundException during deletion (#11692)
  * tests/resource/aws_ssm_maintenance_window: Add sweeper (#11689)
  * tests/provider: Add markdownlint to website-lint target (#11838)
  * initial commit
  * Update to use keyvaluetags.
  * Update Changelog for #10017
  * resource/elasticache_cluster: Add Computed flag for Port property and set to true (#10017)
  * New Data Source: aws_ssm_patch_baseline (#9486)
  * resource/aws_placement_group: Additional handling for creation and deletion eventual consistency (#11671)
  * Fix broken documentation formatting for ssm_patch_baseline.html.markdown (#11825)
  * resource/aws_codebuild_project: Implements git_submodules_config block (#10952)
  * resource/aws_appautoscaling_target: Prevent state removal at creation (#11819)
  * Adds storage class analysis data export parameters to resource. Adds tests for empty case
  * Prevents acc tests and sweeper for AWS Glue workflows in GovCloud, since it's not supported
  * Update module yaml to v2.2.8 (#11740)
  * Update module aws/aws-sdk-go to v1.28.9 (#11753)
  * Update module hashicorp/terraform-plugin-sdk to v1.6.0 (#11802)
  * Update module bflad/tfproviderlint to v0.8.0 (#11815)
  * Cleanup after v2.47.0 release
  * Adds test for removing filter
  * Adds tests for filter with tags and combined prefix and tags
  * Adds tests for filter with prefix. Since the API only has a Put operation, use a single function for Create and Update
  * Updates test S3 bucket name to match sweeper patterns
  * Prevents empty filter parameter
  * Adds tests for basic update with `ForceNew` parameters
  * Adds wait function for deletes
  * Adds basic CRD operations for the resource with only required fields
  * Updates tests for Terraform v0.12 format
  * Renames test values to remove "foo" and "bar". Some additional reformatting
  * r/aws_appmesh_route: Add support for HTTP header-based routing and route priorities.
  * add docs
  * add tags to acm cert data source
  * add import step to all tests
  * add import support refactor errors + tests
  * Adds `BLUE_GREEN` deployment type as needed to tests. AWS ignores `blue_green_deployment_config` if it is not set
  * r/aws_egress_only_internet_gateway: Support tagging.
  * Allows deleting `deployment_style`, and resets to default values
  * Allows deleting `load_balancer_info` blocks
  * Remove unneeded argument + fix import still not working
  * Fix Read operation since invitations are purged after 7 days
  * formatting fix
  * Add import support for aws_batch_job_definition
  * Add import support for aws_batch_job_queue #11207
  * Detect and handle DynamoDB resource IDs pointing to an index
  * Add failing testcase
  * Various aws_cognito_identity_provider improvements
  * allow snapshot copy grants to be imported
  * data/aws_lambda_alias: added docs
  * data/aws_lambda_alias: added basic test
  * data/aws_lambda_alias: new data source
  * fix lint
  * docs update
  * aws_dms_endpoint: Add support for Kinesis target endpoint
  * removed unused validator
  * fix docs
  * change grant to schema.HashSet type, re-evaluate grant logic, fix minor comments
  * Error check on fallback
  * add tests
  * add docs
  * add import functionality
  * Add dms_event_subscription resource
  * r/aws_lb_target_group: use diff.ForceNew
  * Fix diff.GetChange on previous commit
  * r/lb_target_group health chk proto chg req taint
  * Implementation of acl grants and update in docs
* Wed Feb  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.47.0:
  NOTES:
  * resource/aws_efs_file_system: Tagging API calls have been refactored to the AWS
    standardized `TagResource` and `UntagResource` API calls (from `CreateTags` and
    `DeleteTags` respectively). Restrictive IAM Policies for Terraform execution may
    require updates. ([#11654](https://github.com/terraform-providers/terraform-provider-aws/issues/11654))
  ENHANCEMENTS:
  * data-source/aws_api_gateway_vpc_link: Add `description`, `status`, `status_message`,
    `tags`, and `target_arns` attributes
    ([#10822](https://github.com/terraform-providers/terraform-provider-aws/issues/10822))
  * data-source/aws_dynamodb_table: Add `server_side_encryption` `kms_key_arn` attribute
    ([#11081](https://github.com/terraform-providers/terraform-provider-aws/issues/11081))
  * data-source/aws_efs_file_system: Add `lifecycle_policy`, `provisioned_throughput_in_mibps`,
    and `throughput_mode` attributes
    ([#11647](https://github.com/terraform-providers/terraform-provider-aws/issues/11647))
  * data-source/aws_kms_key: Add `customer_master_key_spec` attribute
    ([#11062](https://github.com/terraform-providers/terraform-provider-aws/issues/11062))
  * resource/aws_dynamodb_table: Add `server_side_encryption` configuration block `kms_key_arn`
    argument (support customer managed CMKs for server-side encryption)
    ([#11081](https://github.com/terraform-providers/terraform-provider-aws/issues/11081))
  * resource/aws_dynamodb_table: Support in-place updates for `server_side_encryption`
    configurations ([#11081](https://github.com/terraform-providers/terraform-provider-aws/issues/11081))
  * resource/aws_elasticsearch_domain: Add `domain_endpoint_options` configuration block
    (support enforcing HTTPS)
    ([#10430](https://github.com/terraform-providers/terraform-provider-aws/issues/10430))
  * resource/aws_gamelift_fleet: Add `fleet_type` argument (support Spot Fleets)
    ([#8234](https://github.com/terraform-providers/terraform-provider-aws/issues/8234))
  * resource/aws_kms_key: Add `customer_master_key_spec` argument and plan-time validation
    support for `key_usage` value `SIGN_VERIFY` (support asymmetric keys)
    ([#11062](https://github.com/terraform-providers/terraform-provider-aws/issues/11062))
  * resource/aws_sagemaker_notebook_instance: Add `direct_internet_access` argument
    ([#8618](https://github.com/terraform-providers/terraform-provider-aws/issues/8618))
  * resource/aws_ssm_activation: Add `automation_target_parameter_name` argument
    ([#11755](https://github.com/terraform-providers/terraform-provider-aws/issues/11755))
  * resource/aws_ssm_document: Add `target_type` argument
    ([#11479](https://github.com/terraform-providers/terraform-provider-aws/issues/11479))
  * resource/aws_ssm_maintenance_window: Add `description` argument
    ([#11478](https://github.com/terraform-providers/terraform-provider-aws/issues/11478))
  * resource/aws_storagegateway_gateway: Add `cloudwatch_log_group_arn` argument
    ([#10939](https://github.com/terraform-providers/terraform-provider-aws/issues/10939))
  BUG FIXES:
  * data-source/aws_api_gateway_rest_api: Fixes `root_resource_id` not being set on correctly
    when REST API contains more than 25 resources
    ([#11705](https://github.com/terraform-providers/terraform-provider-aws/issues/11705))
  * resource/aws_cloudwatch_log_subscription_filter: Perform eventual consistency retries
    on update ([#11739](https://github.com/terraform-providers/terraform-provider-aws/issues/11739))
  * resource/aws_cognito_user_pool: Deprecate `unused_account_validity_days` argument and
    add support for `temporary_password_validity_days` argument
    ([#10890](https://github.com/terraform-providers/terraform-provider-aws/issues/10890))
  * resource/aws_elasticsearch_domain: Automatically retry resource creation on additional
    error messages relating to eventual consistency
    ([#11663](https://github.com/terraform-providers/terraform-provider-aws/issues/11663))
  * resource/aws_elasticsearch_domain: Ensure in-place version upgrade is fully successful
    before returning
    ([#11793](https://github.com/terraform-providers/terraform-provider-aws/issues/11793))
  * resource/aws_emr_instance_group: Wait for `RUNNING` status on creation
    ([#11688](https://github.com/terraform-providers/terraform-provider-aws/issues/11688))
  * resource/aws_ssm_activation: Properly trigger resource recreation when deleted outside
    Terraform ([#11658](https://github.com/terraform-providers/terraform-provider-aws/issues/11658))
  * resource/aws_ssm_parameter: Prevent `KeyId` error when switching `type` value from `SecureString`
    to `String` ([#10819](https://github.com/terraform-providers/terraform-provider-aws/issues/10819))
  * service/efs: Generate proper `dns_name` attribute hostname suffix in AWS China, AWS C2S, and
    AWS SC2S partitions ([#11746](https://github.com/terraform-providers/terraform-provider-aws/issues/11746))
- For the changes between 2.29.0 and 2.47.0, see CHANGELOG.md included in this package
- Update _service file
- Include CHANGELOG.md in %%doc section
- Increase golang API in BuildRequires to > 1.13
* Tue Feb  4 2020 David Cassany <dcassany@suse.com>
- terraform-provider-aws upgrade is part of bsc#1162585 and jsc#ECO-134
* Wed Jan 22 2020 Jean-Philippe Evrard <jevrard@suse.com>
  Please pay a special attention to the "Notes" section in each of the updates below.
- Updated to v2.29.0
  ENHANCEMENTS:
  * data-source/aws_s3_bucket_object: Add `object_lock_legal_hold_status`, `object_lock_mode` and `object_lock_retain_until_date` attributes ([#9942](https://github.com/terraform-providers/terraform-provider-aws/issues/9942))
  * resource/aws_glue_job: Add ability to specify python version for pythonshell in glue jobs ([#9409](https://github.com/terraform-providers/terraform-provider-aws/issues/9409))
  * resource/aws_s3_bucket_object: Add `force_destroy`, `object_lock_legal_hold_status`, `object_lock_mode` and `object_lock_retain_until_date` attributes ([#9942](https://github.com/terraform-providers/terraform-provider-aws/issues/9942))
  * resource/aws_ssm_association: Add import support ([#10055](https://github.com/terraform-providers/terraform-provider-aws/issues/10055))
  * resource/aws_waf_rate_based_rule: Update rate based rule limit for WAF ([#9946](https://github.com/terraform-providers/terraform-provider-aws/pull/9946))
  * resource/aws_wafregional_rate_based_rule: Update rate based rule limit for WAF ([#9946](https://github.com/terraform-providers/terraform-provider-aws/pull/9946))
  BUG FIXES:
  * ecs_task_definition_equivalency: Fix a crash if environment name is missing ([#10074](https://github.com/terraform-providers/terraform-provider-aws/issues/10074))
  * Revert "resource/aws_cloudfront_distribution: Fix `active_trusted_signers` attribute for Terraform 0.12" ([#10093](https://github.com/terraform-providers/terraform-provider-aws/issues/10093))
- Updated to v2.28.0
  NOTES:
  * resource/aws_cloudfront_distribution: This attribute implemented a legacy Terraform library (flatmap), which does not work with Terraform 0.12's data types and whose only usage was on this single attribute across all Terraform Providers. The attribute now implements (in the closest approximation to the previous implementation) the nested object data into the Terraform state in all Terraform versions. Any references to nested attributes such as `active_trusted_signers.enabled` will need to be updated to `active_trusted_signers.0.enabled`. ([#10013](https://github.com/terraform-providers/terraform-provider-aws/issues/10013))
  FEATURES:
  * **New Data Source:** `aws_route53_resolver_rule` ([#9805](https://github.com/terraform-providers/terraform-provider-aws/issues/9805))
  * **New Data Source:** `aws_route53_resolver_rules` ([#9805](https://github.com/terraform-providers/terraform-provider-aws/issues/9805))
  ENHANCEMENTS:
  * data-source/aws_eks_cluster: Add `identity` attribute (support getting OIDC issuer URL) ([#10006](https://github.com/terraform-providers/terraform-provider-aws/issues/10006))
  * resource/aws_eks_cluster: Add `identity` attribute (support getting OIDC issuer URL) ([#10006](https://github.com/terraform-providers/terraform-provider-aws/issues/10006))
  * resource/aws_elasticache_cluster: Support `cluster_id` validation up to 50 characters ([#9941](https://github.com/terraform-providers/terraform-provider-aws/issues/9941))
  * resource/aws_elasticache_replication_group: Support `replication_group_id` validation up to 40 characters ([#9941](https://github.com/terraform-providers/terraform-provider-aws/issues/9941))
  BUG FIXES:
  * resource/aws_instance: Final retries after timeouts creating and updating instance and getting instance password data
  * resource/aws_cloudfront_distribution: Support accessing `active_trusted_signers` attribute `items` in Terraform 0.12 ([#10013](https://github.com/terraform-providers/terraform-provider-aws/issues/10013))
  * resource/aws_cognito_user_pool: Fix perpetual diffs on `sms_verification_message` ([#9758](https://github.com/terraform-providers/terraform-provider-aws/issues/9758))
  * resource/aws_elasticsearch_domain: Final retries after timeouts creating, updating, and deleting domains ([#9892](https://github.com/terraform-providers/terraform-provider-aws/issues/9892))
  * resource/aws_elasticsearch_domain_policy: Final retries after timeouts upserting and deleting domain policies ([#9892](https://github.com/terraform-providers/terraform-provider-aws/issues/9892))
  * resource/aws_iam_policy_attachment: Revert a change causing errors with policies not being found during attachment ([#10063](https://github.com/terraform-providers/terraform-provider-aws/issues/10063))
  * resource/aws_lightsail_instance: Fixes an issue where 2-character lightsail instance names didn't get validated properly ([#10046](https://github.com/terraform-providers/terraform-provider-aws/issues/10046))
- Updated to v2.27.0
  ENHANCEMENTS:
  * data-source/aws_ecs_cluster: Add `setting` attribute ([#9720](https://github.com/terraform-providers/terraform-provider-aws/issues/9720))
  * provider: Support AWS C2S and SC2S endpoints ([#9998](https://github.com/terraform-providers/terraform-provider-aws/issues/9998))
  * resource/aws_ecs_cluster: Add `setting` configuration blocks (support enabling Container Insights) ([#9720](https://github.com/terraform-providers/terraform-provider-aws/issues/9720))
  * resource/aws_kinesis_firehose_delivery_stream: Add `server_side_encryption` configuration block (support Server Side Encryption) ([#6523](https://github.com/terraform-providers/terraform-provider-aws/issues/6523))
  BUG FIXES:
  * resource/aws_s3_bucket: Include any system tags that Terraform ignores when setting S3 bucket tags ([#7342](https://github.com/terraform-providers/terraform-provider-aws/issues/7342))
- Updated to v2.26.0
  FEATURES:
  * **New Data Source:** `aws_elasticsearch_domain` ([#1867](https://github.com/terraform-providers/terraform-provider-aws/issues/1867))
  BUG FIXES:
  * resource/aws_ec2_capacity_reservation: Fixes error handling when an EC2 Capacity Reservation is deleted manually but is still in state ([#9862](https://github.com/terraform-providers/terraform-provider-aws/issues/9862))
  * resource/aws_s3_bucket: Final retries after timeouts creating, updating and updating replication configuration for s3 buckets ([#9861](https://github.com/terraform-providers/terraform-provider-aws/issues/9861))
  * resource/aws_s3_bucket_inventory: Final retries after timeous reading and putting bucket inventories ([#9861](https://github.com/terraform-providers/terraform-provider-aws/issues/9861))
  * resource/aws_s3_bucket_metric: Final retry after timeout putting bucket metric ([#9861](https://github.com/terraform-providers/terraform-provider-aws/issues/9861))
  * resource/aws_s3_bucket_notification: Final retry after timeout putting notification ([#9861](https://github.com/terraform-providers/terraform-provider-aws/issues/9861))
  * resource/aws_s3_bucket_policy: Final retry after timeout putting policy ([#9861](https://github.com/terraform-providers/terraform-provider-aws/issues/9861))
  * resource/aws_s3_bucket_public_access_block: Final retries after timeouts creating and reading blocks ([#9861](https://github.com/terraform-providers/terraform-provider-aws/issues/9861))
- Updated to v2.25.0
  ENHANCEMENTS:
  * resource/aws_rds_cluster: Support `postgresql` in plan time validation for `enabled_cloudwatch_logs_exports` argument ([#9740](https://github.com/terraform-providers/terraform-provider-aws/issues/9740))
  BUG FIXES:
  * resource/aws_cloudwatch_event_target: Add default setting for ecs_target task_count ([#9773](https://github.com/terraform-providers/terraform-provider-aws/issues/9773))
  * resource/aws_cloudwatch_log_subscription_filter: Prevent difference when omitting default `distribution` argument value of `ByLogStream` ([#9265](https://github.com/terraform-providers/terraform-provider-aws/issues/9265))
  * resource/aws_db_instance: Fix enabling Enhanced Monitoring on update to handle IAM eventual consistency ([#9747](https://github.com/terraform-providers/terraform-provider-aws/issues/9747))
  * resource/aws_elb: Final retries after timeouts creating and updating ELBs ([#9765](https://github.com/terraform-providers/terraform-provider-aws/issues/9765))
  * resource/aws_elb_attachment: Final retry after timout creating ELB attachment ([#9765](https://github.com/terraform-providers/terraform-provider-aws/issues/9765))
  * resource/aws_iam_instance_profile: Final retry after timeout adding role to profile ([#9766](https://github.com/terraform-providers/terraform-provider-aws/issues/9766))
  * resource/aws_iam_policy: Final retry after timeout reading policy ([#9766](https://github.com/terraform-providers/terraform-provider-aws/issues/9766))
  * resource/aws_iam_role: Final retries after timeouts creating and deleting IAM roles ([#9766](https://github.com/terraform-providers/terraform-provider-aws/issues/9766))
  * resource/aws_iam_user: Final retry after timeout deleting user login profile ([#9766](https://github.com/terraform-providers/terraform-provider-aws/issues/9766))
  * resource/aws_inspector_assessment_target: Final retry after timeout deleting target ([#9767](https://github.com/terraform-providers/terraform-provider-aws/issues/9767))
  * resource/aws_internet_gateway: Final retries after timeouts creating, attaching, and deleting gateways ([#9779](https://github.com/terraform-providers/terraform-provider-aws/issues/9779))
  * resource/aws_iot_thing_type: Final retry after timeout deleting IOT thing type ([#9780](https://github.com/terraform-providers/terraform-provider-aws/issues/9780))
  * resource/aws_kinesis_firehose_delivery_stream: Prevent differences with disabled `data_format_conversion_configuration` and `processing_configuration` after changes outside Terraform ([#9103](https://github.com/terraform-providers/terraform-provider-aws/issues/9103))
  * resource/aws_launch_configuration: Final retry after timeout creating launch configuration ([#9781](https://github.com/terraform-providers/terraform-provider-aws/issues/9781))
  * resource/aws_lb: Final retry after timeout waiting for network interfaces to detach ([#9787](https://github.com/terraform-providers/terraform-provider-aws/issues/9787))
  * resource/aws_lb_listener_certificate: Final retry after timeout reading listener certificate ([#9787](https://github.com/terraform-providers/terraform-provider-aws/issues/9787))
  * resource/aws_lb_listener_rule: Final retries after timeout reading and creating listener rules ([#9787](https://github.com/terraform-providers/terraform-provider-aws/issues/9787))
  * resource/aws_msk_cluster: Final retries after timeouts creating and deleting clusters ([#9793](https://github.com/terraform-providers/terraform-provider-aws/issues/9793))
  * resource/aws_network_acl: Final retry after timeout deleting ACLs ([#9830](https://github.com/terraform-providers/terraform-provider-aws/issues/9830))
  * resource/aws_network_acl_rule: Final retry after timeout creating ACL rules ([#9830](https://github.com/terraform-providers/terraform-provider-aws/issues/9830))
  * resource/aws_network_acl_rule: Remove resource from Terraform state on `InvalidNetworkAclID.NotFound` errors ([#9710](https://github.com/terraform-providers/terraform-provider-aws/issues/9710))
  * resource/aws_opsworks_stack: Final retry after timeout creating stack ([#9818](https://github.com/terraform-providers/terraform-provider-aws/issues/9818))
  * resource/aws_rds_cluster_instance: Ensure `monitoring_interval` and `monitoring_role_arn` attributes are always written to the Terraform state ([#9748](https://github.com/terraform-providers/terraform-provider-aws/issues/9748))
  * resource/aws_redshift_cluster: Final retry after timeout deleting cluster ([#9796](https://github.com/terraform-providers/terraform-provider-aws/issues/9796))
  * resource/aws_redshift_snapshot_copy_grant: Final retries after timeouts finding and deleting grants ([#9796](https://github.com/terraform-providers/terraform-provider-aws/issues/9796))
  * resource/aws_route: Final retry after timeout creating route ([#9797](https://github.com/terraform-providers/terraform-provider-aws/issues/9797))
  * resource/aws_route_table: Final retry after timeout updating route table ([#9797](https://github.com/terraform-providers/terraform-provider-aws/issues/9797))
  * resource/aws_route_table_association: Final retry after timeout creating route table association ([#9797](https://github.com/terraform-providers/terraform-provider-aws/issues/9797))
  * resource/aws_s3_bucket_object: Allow using SSE-S3 encryption with `etag` argument ([#9442](https://github.com/terraform-providers/terraform-provider-aws/issues/9442))
  * resource/aws_sagemaker_model: Final retry after timeout deleting model ([#9799](https://github.com/terraform-providers/terraform-provider-aws/issues/9799))
  * resource/aws_sagemaker_notebook_instance: Final retry after timeout updating instance ([#9799](https://github.com/terraform-providers/terraform-provider-aws/issues/9799))
  * resource/aws_security_group: Final retry after timeout deleting security group ([#9812](https://github.com/terraform-providers/terraform-provider-aws/issues/9812))
  * resource/aws_security_group_rule: Final retry after timeout creating security group rule ([#9812](https://github.com/terraform-providers/terraform-provider-aws/issues/9812))
  * resource/aws_sqs_queue: Final retry after timeout creating queue ([#9813](https://github.com/terraform-providers/terraform-provider-aws/issues/9813))
  * resource/aws_sqs_queue_policy: Final retru after timeout updating queue policy ([#9813](https://github.com/terraform-providers/terraform-provider-aws/issues/9813))
  * resource/aws_transfer_server: Final retry after timeout waiting for transfer server deletion ([#9815](https://github.com/terraform-providers/terraform-provider-aws/issues/9815))
  * resource/aws_wafregional_web_acl_association: Final retry after timeout creating association ([#9820](https://github.com/terraform-providers/terraform-provider-aws/issues/9820))
  * service/dynamodb: Final retries after timeouts setting dynamodb tags ([#9821](https://github.com/terraform-providers/terraform-provider-aws/issues/9821))
  * service/sagemaker: Final retries after timeouts setting sagemaker tags ([#9821](https://github.com/terraform-providers/terraform-provider-aws/issues/9821))
  * service/waf: Final retry after timeout getting change token ([#9826](https://github.com/terraform-providers/terraform-provider-aws/issues/9826))
  * service/wafregional: Final retry after timeout getting change token ([#9826](https://github.com/terraform-providers/terraform-provider-aws/issues/9826))
- Updated to v2.24.0
  FEATURES:
  * **New Resource:** `aws_config_organization_custom_rule` ([#9716](https://github.com/terraform-providers/terraform-provider-aws/issues/9716))
  * **New Resource:** `aws_config_organization_managed_rule` ([#9716](https://github.com/terraform-providers/terraform-provider-aws/issues/9716))
  * **New Resource:** `aws_fsx_lustre_file_system` ([#7074](https://github.com/terraform-providers/terraform-provider-aws/issues/7074)] / [[#9761](https://github.com/terraform-providers/terraform-provider-aws/issues/9761))
  * **New Resource:** `aws_fsx_windows_file_system` ([#7074](https://github.com/terraform-providers/terraform-provider-aws/issues/7074)] / [[#9761](https://github.com/terraform-providers/terraform-provider-aws/issues/9761))
  * **New Resource:** `aws_ram_resource_share_accepter` ([#8259](https://github.com/terraform-providers/terraform-provider-aws/issues/8259))
  ENHANCEMENTS:
  * resource/aws_codebuild_project: Add `artifacts` configuration block `artifact_identifier` argument ([#9652](https://github.com/terraform-providers/terraform-provider-aws/issues/9652))
  * resource/aws_codebuild_project: Add plan time validation for `artifacts` and `secondary_artifacts` configuration blocks `packaging` argument ([#9652](https://github.com/terraform-providers/terraform-provider-aws/issues/9652))
  * resource/aws_rds_cluster: Add `multimaster` to `engine_mode` argument validation (support Aurora Multi-Master Clusters) ([#9691](https://github.com/terraform-providers/terraform-provider-aws/issues/9691))
  * resource/aws_rds_cluster_instance: Allow `aurora-mysql` (MySQL 5.7) engine to enable Performance Insights ([#9635](https://github.com/terraform-providers/terraform-provider-aws/issues/9635))
  * resource/aws_wafregional_regex_match_set: Support resource import ([#9699](https://github.com/terraform-providers/terraform-provider-aws/issues/9699))
  * resource/aws_wafregional_regex_pattern_set: Support resource import ([#9712](https://github.com/terraform-providers/terraform-provider-aws/issues/9712))
  * resource/aws_wafregional_size_constraint_set: Support resource import ([#9713](https://github.com/terraform-providers/terraform-provider-aws/issues/9713))
  * resource/aws_wafregional_sql_injection_match_set: Support resource import ([#9717](https://github.com/terraform-providers/terraform-provider-aws/issues/9717))
  BUG FIXES:
  * resource/aws_acm_certificate_validation: Final retries after timeouts creating and checking validation for ACM certificates ([#9661](https://github.com/terraform-providers/terraform-provider-aws/issues/9661))
  * resource/aws_ami: Final retry after timeout reading AMI ([#9674](https://github.com/terraform-providers/terraform-provider-aws/issues/9674))
  * resource/aws_cloudhsm2_cluster: Final retries after timeouts creating, updating, and deleting CloudHSM clusters ([#9675](https://github.com/terraform-providers/terraform-provider-aws/issues/9675))
  * resource/aws_cloudhsm2_hsm: Final retries after timeouts creating and deleting CloudHSM modules ([#9675](https://github.com/terraform-providers/terraform-provider-aws/issues/9675))
  * resource/aws_cloudtrail: Final retries after timeouts creating and updating cloudtrails ([#9678](https://github.com/terraform-providers/terraform-provider-aws/issues/9678))
  * resource/aws_codebuild_project: Final retries after timeouts creating and updating codebuild projects ([#9682](https://github.com/terraform-providers/terraform-provider-aws/issues/9682))
  * resource/aws_codebuild_project: Properly perform drift detection and updates for `secondary_artifacts` configuration block arguments (except `name` which will require a separate fix) ([#9652](https://github.com/terraform-providers/terraform-provider-aws/issues/9652))
  * resource/aws_codedeploy_deployment_group: Final retries after timeouts creating and updating deployment groups ([#9682](https://github.com/terraform-providers/terraform-provider-aws/issues/9682))
  * resource/aws_codepipeline: Final retry after timeout creating codepipeline ([#9682](https://github.com/terraform-providers/terraform-provider-aws/issues/9682))
  * resource/aws_cognito_user_pool: Final retries after timeouts creating and updating Cognito user pools ([#9684](https://github.com/terraform-providers/terraform-provider-aws/issues/9684))
  * resource/aws_db_instance: Fix enabling Performance Insights on update without Performance Insights KMS Key ID ([#9745](https://github.com/terraform-providers/terraform-provider-aws/issues/9745))
  * resource/aws_dms_endpoint: Final retry after timeout creating DMS endpoint ([#9695](https://github.com/terraform-providers/terraform-provider-aws/issues/9695))
  * resource/aws_docdb_cluster_instance: Final retries after timeouts creating and updating DocDB cluster instances ([#9696](https://github.com/terraform-providers/terraform-provider-aws/issues/9696))
  * resource/aws_docdb_cluster_parameter_group: Final retry after timeout deleting DocDB cluster parameter groups ([#9696](https://github.com/terraform-providers/terraform-provider-aws/issues/9696))
  * resource/aws_docdb_subnet_group: Final retry after timeout deleting DocDB subnet groups ([#9696](https://github.com/terraform-providers/terraform-provider-aws/issues/9696))
  * resource/aws_dynamodb_table: Final retries after timeouts creating, updating, and deleting DynamoDB tables ([#9697](https://github.com/terraform-providers/terraform-provider-aws/issues/9697))
  * resource/aws_ebs_snapshot: Final retries after timeouts creating, deleting or waiting for available EBS snapshots ([#9698](https://github.com/terraform-providers/terraform-provider-aws/issues/9698))
  * resource/aws_ebs_snapshot_copy: Final retry after timeout deleting EBS snapshot copies ([#9698](https://github.com/terraform-providers/terraform-provider-aws/issues/9698))
  * resource/aws_ecs_cluster: Final retries after timeouts reading and deleting ECS cluster ([#9704](https://github.com/terraform-providers/terraform-provider-aws/issues/9704))
  * resource/aws_ecs_service: Final retries after timeouts creating, updating, and deleting ECS service ([#9704](https://github.com/terraform-providers/terraform-provider-aws/issues/9704))
  * resource/aws_eip: Final retries after timeouts reading, updating, and deleting EIPs ([#9728](https://github.com/terraform-providers/terraform-provider-aws/issues/9728))
  * resource/aws_eip_association: Final retry after timeout creating EIP association ([#9728](https://github.com/terraform-providers/terraform-provider-aws/issues/9728))
  * resource/aws_eks_cluster: Final retry after timeout creating EKS cluster ([#9729](https://github.com/terraform-providers/terraform-provider-aws/issues/9729))
  * resource/aws_elastic_beanstalk_application: Final retries after timeouts reading and deleting beanstalk applications ([#9731](https://github.com/terraform-providers/terraform-provider-aws/issues/9731))
  * resource/aws_gamelift_build: Final retry after timeout creating gamelift build ([#9752](https://github.com/terraform-providers/terraform-provider-aws/issues/9752))
  * resource/aws_gamelift fleet: Final retry after timeout deleting gamelift fleet ([#9752](https://github.com/terraform-providers/terraform-provider-aws/issues/9752))
  * resource/aws_glue_crawler: Final retry after timeout creating glue crawler ([#9753](https://github.com/terraform-providers/terraform-provider-aws/issues/9753))
  * resource/aws_guardduty_member: Final retry after timeout waiting for email invitation ([#9757](https://github.com/terraform-providers/terraform-provider-aws/issues/9757))
  * resource/aws_lb_target_group_attachment: Perform drift detection on attachments using target health description (trigger resource recreation for manually deregistered attachments) ([#9610](https://github.com/terraform-providers/terraform-provider-aws/issues/9610))
  * resource/aws_vpn_gateway: Retry after timeouts attaching and deleting VPN gateways, and retrying attachment after pending VPN errors ([#9641](https://github.com/terraform-providers/terraform-provider-aws/issues/9641))
* Fri Sep 21 2018 ldevulder@suse.de
- Update to version 1.37.0:
  * Update CHANGELOG for #5948
  * resource/aws_dms_replication_instance: Ensure engine_version upgrades occur correctly
  * Updated lambda w/ req runtime attr
  * Fix changing engine_version attempts to update resource class
  * Update CHANGELOG for #5771
  * tests/resource/aws_launch_template: Minor improvements to ipv6_address_count testing
  * Update to iam_instance_profile
  * Update aws_launch_template schema(ipv6 addr count)
* Thu Jul  5 2018 opensuse-packaging@opensuse.org
- Update to version 1.26.0+git20180704.f86cbff8:
  * Fix the access policy in the ES domain docs
  * Also retrieve AWS instances that are in a state other than running
  * Make EventSourceMapping.starting_position optional.
  * Update documentatoin as well.
  * Add event source mapping tests without a starting_position.
  * Remove the batch size default. It no longer applies as the sqs mapping default is 10.
  * re-added tests
  * use appropriate terraform error helpers.
  * Fix test text duplication.
  * Suppress diffs when batch_size is removed, but keeps the default size.
  * Cleanup.
  * re-added old acceptance tests
  * Added argument for defining instance state names + added test case
  * Add member_clusters to aws_elasticache_replication_group
  * Fix test case + update documentation
  * resource/aws_lambda_event_source_mapping: Remove panic() and update batch_size default documentation
  * Update CHANGELOG for #5024
  * db_event_subscription source_type doc expansion
  * Update CHANGELOG for #4950
  * Update CHANGELOG for #5057
  * db_event_subscription add missing db-snapshot type
  * Address #5056 PR feedback
  * Update CHANGELOG for #5056
  * v1.26.0
  * Cleanup after v1.26.0 release
* Thu Jul  5 2018 ldevulder@suse.com
- Initial release
